function AndorDAT_to_16BitsTIF_for_GUI(Folder,OutputFolder,FileFormat,Display,TIFsolis_Check)

% % Example
% Folder='F:\AlexVilquin\RawDataAndor\01-Motor20000_Plaser50mW_P40mbar_f400fps_NaCl0mgpl0';
% FileFormat='mat'; Display='none';
% % TIFsolis_Check='F:\AlexVilquin\RawDataAndor\TIFsolis\01-Motor20000_Plaser50mW_P40mbar_f400fps_NaCl0mgpl0';
% TIFsolis_Check='none';

%% Frame properties from INI file
% Loading INI file
List_INI=dir([Folder filesep '*.ini']);
if isempty(List_INI)==1
    disp(['No INI file found in ' Folder]);
    Height=input('Enter the image height: ');
    Width=input('Enter the image width: ');
elseif numel(List_INI)==1
    FileID=fopen([Folder filesep List_INI.name]);
    File_INI=textscan(FileID,'%q','Delimiter',',');
    fclose(FileID);
    
    % Extract height
    I=strfind(lower(File_INI{1,1}),'height ');
    J=1;
    while isempty(I{J})==1
        J=J+1;
    end
    K=strfind(File_INI{1,1}{J},'= ');
    Height=str2double(File_INI{1,1}{J}(K+2:end));

    % Extract width
    I=strfind(lower(File_INI{1,1}),'width ');
    J=1;
    while isempty(I{J})==1
        J=J+1;
    end
    K=strfind(File_INI{1,1}{J},'= ');
    Width=str2double(File_INI{1,1}{J}(K+2:end));
elseif numel(List_INI)>1
    disp(['Few INI files found in ' Folder]);
    Height=input('Enter the image height: ');
    Width=input('Enter the image width: ');
end
N=Height*Width;

%% Conversion into 16-bit TIF
List_DAT=dir([Folder filesep '*.dat']);
if isempty(List_DAT)==1
    error(['No DAT file found in ' Folder]);
end
Nfiles=numel(List_DAT);

% Sort files versus times
FileNames=vertcat(List_DAT(:).name);
Ndigits=1;
while length(unique(FileNames(:,Ndigits)))>1
    Ndigits=Ndigits+1;
end
Ndigits=Ndigits-1; NumChar=FileNames(:,Ndigits:-1:1);
NumFiles=str2num(NumChar);
[~,IndexDate]=sortrows(NumFiles); l=1;

if strcmpi(TIFsolis_Check,'none')==0
    List_TIF=dir([TIFsolis_Check filesep '*.tif']);
    NfilesTIF=numel(List_TIF);
end

% Convert and save TIF frames
if strcmpi(Display,'figure')==1
    Fig=figure('name','Display','NumberTitle','off');
    scrsz=get(0,'ScreenSize');
    set(Fig,'Position',scrsz);
end
if strcmpi(FileFormat,'none')==0
    I=strfind(Folder,filesep);
    if strcmpi(OutputFolder,'none')==1
        FolderResults=[Folder(1:I(end)) upper(FileFormat) Folder(I(end):end)];
    else
        %FolderResults=[OutputFolder Folder(I(end-1):I(end)-1) Folder(I(end):end)];
        FolderResults=[OutputFolder Folder(I(end):end) filesep 'TIFF'];
    end
    if exist(FolderResults,'dir')==0
        mkdir(FolderResults);
    end
end
hh = waitbar(0,'tiff conversion...');
for i=1:Nfiles
    if strcmpi(Display,'index')==1
        disp([num2str(i) '/' num2str(Nfiles) ' done']);
    end
    
    FileName=[Folder filesep List_DAT(IndexDate(i)).name];
    FileID = fopen(FileName,'rb');
    data = fread(FileID,'uint16=>uint16');
    fclose(FileID);
    ImagePerFrame=size(data,1)/N;
    if i==1
        NframesApprox=Nfiles*ImagePerFrame;
        Digits=fix(log10(NframesApprox)+1);
    end
    
    for t=1:ImagePerFrame
        Frame=flip(reshape(data((t-1)*N+1:t*N),[Width Height 1])',1);
        if mean(mean(Frame))==0
            NfilesFinal=l-1;
            disp([num2str(NfilesFinal) ' frames converted']);
            break
        else
            if strcmpi(FileFormat,'none')==0 || strcmpi(Display,'figure')==1
                DigitsNre=['%0' num2str(Digits) 'd'];
                FrameName=['im_' sprintf(DigitsNre,l) '.' FileFormat];
            end
            if strcmpi(FileFormat,'none')==0
                if strcmpi(FileFormat,'tif')==1
                    imwrite(Frame,[FolderResults filesep FrameName]);
                elseif strcmpi(FileFormat,'mat')==1                    
                    save([FolderResults filesep FrameName],'Frame');
                end
            end
        end
        
        if strcmpi(TIFsolis_Check,'none')==0
            FrameSolis=imread([TIFsolis_Check filesep List_TIF(l).name]);
            nt=unique(Frame==FrameSolis);
            if nt==1
            else
                error('The two iamges are different');
            end
        end
        
        if strcmpi(Display,'figure')==1
            if strcmpi(TIFsolis_Check,'none')==0
                subplot(1,2,1);
            end
            imagesc(Frame); daspect([1 1 1]); c=colorbar;
            set(c,'TickLabelInterpreter', 'latex');
            ylabel(c,'I','Interpreter','latex');
            set(gca,'TickLabelInterpreter', 'latex');
            title([List_DAT(IndexDate(i)).name '_' num2str((t-1)*N+1) ':' num2str(t*N) ' converted into ' FrameName(1:end-length(FileFormat)-1)],'Interpreter','none','FontName','Times New Roman');
            if strcmpi(TIFsolis_Check,'none')==0
                subplot(1,2,2);
                imagesc(FrameSolis); daspect([1 1 1]); c=colorbar;
                set(c,'TickLabelInterpreter', 'latex');
                ylabel(c,'I','Interpreter','latex');
                set(gca,'TickLabelInterpreter', 'latex');
                title(List_TIF(l).name,'Interpreter','none','FontName','Times New Roman');                
            end
            colormap gray; set(gcf,'Color',[1 1 1]); drawnow;
        end
        l=l+1;
    end
hh = waitbar(i/Nfiles,hh,'tiff conversion...');    
end

close(hh)

end