function [] = ConvergenceStationnarityOneVideo_function(MatFile_path,SaveFig)
%% Program to test data convergence and stationnarity
% This program will test how many frames are required to have a convergence
% of the mean quantities such as velocity profiles
% The second part will test the stationnarity of these quantities for one
% given video

% SaveFig == 1 to save figures

FolderMatlab='C:\Gabriel_PhD\Matlab_codes\Functions';
cd(FolderMatlab); addpath(genpath(FolderMatlab));

%% Load data and get the mean quantities
MatFile_Exp=FindUniqueFileList([MatFile_path],'.mat','Trajectories')

load(MatFile_Exp,'Paths','PathsProperties','Scale','FrameRate','Dmin','Tmin','Tmax','Lmin','MeanStdIntVxVyAll','nx','ny','VelocityIntensity');
AngleCorrection=1;
if AngleCorrection==1
    Vx=VelocityIntensity(:,1); Vy=VelocityIntensity(:,2);
    p=polyfit(Vx,Vy,1);
    AngleFlowRad=atan(p(1));
end
SignMeanVpara=sign(mean(VelocityIntensity(:,1)));

scrsz=get(0,'ScreenSize'); FontSize=12;
figure('name','Trajectory properties','NumberTitle','off');
set(gcf,'Position',scrsz); row=2; col=2; FactorAR=2;
subplot(row,col,1); p=1; % sum dl
[counts,~]=hist(PathsProperties(:,p),2*sqrt(size(PathsProperties,1)));
hist(PathsProperties(:,p),2*sqrt(size(PathsProperties,1))); i=2; % to exlude first bins
axis([0 max(PathsProperties(:,p)) 0 max(counts(i:end))]);
V=axis; AR=(V(4)-V(3))/(V(2)-V(1));
MyFigStyleLaTeXSave('$\sum dl$','$N_{eff}$',0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,2); p=2; % mean dl
hist(PathsProperties(:,p),2*sqrt(size(PathsProperties,1)));
V=axis; axis([0 max(PathsProperties(:,p)) 0 V(4)]); V=axis; AR=(V(4)-V(3))/(V(2)-V(1));
MyFigStyleLaTeXSave('$\left<dl\right>$','$N_{eff}$',0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,3); p=3;  % path duration
hist(PathsProperties(:,p),2*sqrt(size(PathsProperties,1)));
V=axis; axis([0 max(PathsProperties(:,p)) 0 V(4)]); V=axis; AR=(V(4)-V(3))/(V(2)-V(1));
MyFigStyleLaTeXSave('$\Delta t_{path}$','$N_{eff}$',0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,4); p=6;  % path length
hist(PathsProperties(:,p),2*sqrt(size(PathsProperties,1)));
V=axis; axis([0 max(PathsProperties(:,p)) 0 V(4)]); V=axis; AR=(V(4)-V(3))/(V(2)-V(1));
MyFigStyleLaTeXSave('$\sqrt{\left(x_f-x_i\right)^2+\left(y_f-y_i\right)^2}$','$N_{eff}$',0,0,0,0,[1 FactorAR*AR 1],FontSize);

%% Trajectory selection and displacement calculations
Tmin=0;
PathIndex=find(PathsProperties(:,1)>=Dmin & PathsProperties(:,3)>=Tmin...
    & PathsProperties(:,3)<=Tmax & PathsProperties(:,6)>=Lmin);
PathsParticles=horzcat(PathsProperties(PathIndex,:),PathIndex);
Npath=size(PathIndex,1);
AngleCorrection=1; MethodInterp='linear';
Disp_X_Y_LogI=cell(Npath,1);
Method_Intensity='max_gaussian'; % 'max_gaussian' , 'int_gaussian' , 'sum_pixels'
MaxNp=max(PathsParticles(:,3))-1; Disp_X_Y_LogI_TS=cell(Npath,MaxNp);
for i=1:Npath
    
    % Quantities
    j=PathsParticles(i,end); PathPart=Paths{j,1};
    tpath=PathPart(:,1); ti=tpath(1,1); tf=tpath(end,1);
    xpath=PathPart(:,2); ypath=PathPart(:,3)-ny/2;
    ImaxGausspath=PathPart(:,6); ImaxGaussCorrpath=PathPart(:,7);
    IintGausspath=2*pi*PathPart(:,4).^2.*PathPart(:,6);
    IintGaussCorrpath=2*pi*PathPart(:,4).^2.*PathPart(:,7);
    IsumPixpath=PathPart(:,10).*PathPart(:,11);
    IsumPixCorrpath=PathPart(:,10).*PathPart(:,12);
    
    % angle and/or velocity correction
    if AngleCorrection>0
        xpath=xpath*cos(AngleFlowRad)+ypath*sin(AngleFlowRad);
        ypath=-xpath*sin(AngleFlowRad)+ypath*cos(AngleFlowRad);
    end
    if SignMeanVpara<0
        xpath=nx-xpath+1; % For negative velocity!!!!!!!!!!!!!
    end
    
    % interpolation if max_gap_closing > 0
    if size(tpath,1)<tf-ti+1
        tpathi=(ti:tf)';
        xpathi=interp1(tpath,xpath,tpathi,MethodInterp);
        ypathi=interp1(tpath,ypath,tpathi,MethodInterp);
        ImaxGausspathi=interp1(tpath,ImaxGausspath,tpathi,MethodInterp);
        ImaxGaussCorrpathi=interp1(tpath,ImaxGaussCorrpath,tpathi,MethodInterp);
        IintGausspathi=interp1(tpath,IintGausspath,tpathi,MethodInterp);
        IintGaussCorrpathi=interp1(tpath,IintGaussCorrpath,tpathi,MethodInterp);
        IsumPixpathi=interp1(tpath,IsumPixpath,tpathi,MethodInterp);
        IsumPixCorrpathi=interp1(tpath,IsumPixCorrpath,tpathi,MethodInterp);
        
        tpath=tpathi; xpath=xpathi; ypath=ypathi;
        ImaxGausspath=ImaxGausspathi; ImaxGaussCorrpath=ImaxGaussCorrpathi;
        IintGausspath=IintGausspathi; IintGaussCorrpath=IintGaussCorrpathi;
        IsumPixpath=IsumPixpathi; IsumPixCorrpath=IsumPixCorrpathi;
    end
        
    ImaxGausspath=log(ImaxGausspath);
    ImaxGaussCorrpath=log(ImaxGaussCorrpath);
    IintGausspath=log(IintGausspath);
    IintGaussCorrpath=log(IintGaussCorrpath);
    IsumPixpath=log(IsumPixpath);
    IsumPixCorrpath=log(IsumPixCorrpath);
    
    if size(tpath,1)>1
        % displacements for the smallest time step
        I=(1:size(tpath,1)-1)'; J=(2:size(tpath,1))';
        dxpath=xpath(J)-xpath(I);
        dypath=ypath(J)-ypath(I);
        ImaxGauss=(ImaxGausspath(I)+ImaxGausspath(J))/2;
        ImaxGaussCorr=(ImaxGaussCorrpath(I)+ImaxGaussCorrpath(J))/2;
        dImaxGaussCorr=ImaxGaussCorrpath(J)-ImaxGaussCorrpath(I);
        IintGauss=(IintGausspath(I)+IintGausspath(J))/2;
        IintGaussCorr=(IintGaussCorrpath(I)+IintGaussCorrpath(J))/2;
        dIintGaussCorr=IintGaussCorrpath(J)-IintGaussCorrpath(I);
        IsumPix=(IsumPixpath(I)+IsumPixpath(J))/2;
        IsumPixCorr=(IsumPixCorrpath(I)+IsumPixCorrpath(J))/2;
        dIsumPixCorr=IsumPixCorrpath(J)-IsumPixCorrpath(I);

        Disp_X_Y_LogI{i,1}=[tpath(I) dxpath dypath ImaxGaussCorrpath(I)...
            ImaxGaussCorr dImaxGaussCorr IintGaussCorrpath(I)...
            IintGaussCorr dIintGaussCorr IsumPixCorrpath(I) IsumPixCorr...
            dIsumPixCorr];
        
        % displacements for differents time steps
        if strcmpi(Method_Intensity,'max_gaussian')==1
            LogInt=ImaxGaussCorrpath;
        elseif strcmpi(Method_Intensity,'int_gaussian')==1
            LogInt=IintGaussCorrpath;
        elseif strcmpi(Method_Intensity,'sum_pixels')==1
            LogInt=IsumPixCorrpath;
        end
        LogInt=real(LogInt);
        
        time=tpath; positions=[xpath ypath LogInt];
        [PosDisp,DeltaTime]=Traj2AllDisp_TS(time,positions);
        for k=1:length(DeltaTime)
            Disp_X_Y_LogI_TS{j,k}=PosDisp{k};
        end
        
    end
    
end
Disp_X_Y_LogI=vertcat(Disp_X_Y_LogI{:});
I=(Disp_X_Y_LogI(:,5)>0 | Disp_X_Y_LogI(:,8)>0 | Disp_X_Y_LogI(:,11)>0);
Disp_X_Y_LogI=Disp_X_Y_LogI(I==1,:);
Disp_X_Y_LogI_TimeStep=cell(1,MaxNp); Npart_TS=zeros(5,MaxNp);
for j=1:MaxNp
    Disp_X_Y_LogI_TimeStep{j}=vertcat(Disp_X_Y_LogI_TS{:,j});
    MeanLogInt=mean(Disp_X_Y_LogI_TimeStep{j}(:,[3 6 9]),1);
    Npart_TS(:,j)=[j;size(Disp_X_Y_LogI_TimeStep{j},1);MeanLogInt'];
end

%% Figure for the maximal time step
N=10; CoefFit_Npart=polyfit(Npart_TS(1,1:N),log(Npart_TS(2,1:N)),1);
Npart_TS_Fit=exp(Npart_TS(1,:)*CoefFit_Npart(1)+CoefFit_Npart(2));
LimitFit=2;
Gap=100*abs(Npart_TS(2,:)-Npart_TS_Fit)./Npart_TS(2,:); Gap(1)=0;
I=find(Gap>=LimitFit); N0=Npart_TS(2,1); Nmin=Npart_TS(2,I(1));
TSmax=Npart_TS(1,I(1));

Wfig=scrsz(3)*0.9; Hfig=Wfig*0.4; FontSize=22; LW1=1; MS1=12; LW2=3;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Maximal time step','numbertitle','off',...
    'resize','off');

N1=2; AxAll=cell(N1,1); Wf1=0.4*Wfig; Hf1=Wf1*3/4;
Ypos1=0.18*Hfig; Xpos1=linspace(0.08,1-Wf1/Wfig-0.03,N1)*Wfig;
for i=1:N1
    AxAll{i}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
end

axes(AxAll{1}); hold on;
plot(1e3*Npart_TS(1,:)/FrameRate,Npart_TS(2,:),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(1e3*Npart_TS(1,:)/FrameRate,Npart_TS_Fit,'-','LineWidth',LW2,'color','black');
hold off; set(gca,'yscale','log');
axis([0 1e3*MaxNp/FrameRate min(Npart_TS(2,:)) N0]); Ax=axis;
line([Ax(3) Ax(4)],Nmin*[1 1],'LineStyle','--','LineWidth',LW2*2/3,'color','black');
line(1e3*TSmax*[1 1]/FrameRate,[Ax(3) Ax(4)],'LineStyle','--','LineWidth',LW2*2/3,'color','black');
MyFigureStyle('$t$ (ms)','$N_p$',0,0,0,'',FontSize);

axes(AxAll{2}); hold on;
plot(1e3*Npart_TS(1,:)/FrameRate,Npart_TS(3,:),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(1e3*Npart_TS(1,:)/FrameRate,Npart_TS(4,:),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor',[0 0.5 0],'MarkerEdgeColor','black');
plot(1e3*Npart_TS(1,:)/FrameRate,Npart_TS(5,:),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor','r','MarkerEdgeColor','black');
axis([0 1e3*MaxNp/FrameRate min([Npart_TS(3,:) Npart_TS(4,:) Npart_TS(5,:)]) max([Npart_TS(3,:) Npart_TS(4,:) Npart_TS(5,:)])]);
Ax=axis; hold off;
line(1e3*TSmax*[1 1]/FrameRate,[Ax(3) Ax(4)],'LineStyle','--','LineWidth',LW2*2/3,'color','black');
MyFigureStyle('$t$ (ms)','$\left<\log I \right>$',0,0,0,'',FontSize);

%% Mean quantity calculation for the small time step
Nclass=20; FactorPDF=2;
ColX=2; ColY=3; Treshold=0.999;
ListColIntI=[4 7 10]; ListColIntM=ListColIntI+1; ListColdInt=ListColIntI+2;
nc=length(ListColIntI);
MeanStdIntVxVyAll_logIi=cell(nc,1); MeanStdIntVxVyAll_logIm=cell(nc,1);
PDFsloc_dX_logIi=cell(Nclass,nc); PDFsloc_dX_logIm=cell(Nclass,nc);
PDFsloc_dY_logIi=cell(Nclass,nc); PDFsloc_dY_logIm=cell(Nclass,nc);
PDFsloc_dlogI_logIi=cell(Nclass,nc); PDFsloc_dlogI_logIm=cell(Nclass,nc);
for c=1:nc
    
    ColInt=ListColIntI(c); ColdInt=ListColdInt(c);
    
    Disp_X_Y_LogI=sortrows(Disp_X_Y_LogI,ColInt);
    [Iinf,Isup]=Decil(Disp_X_Y_LogI(:,ColInt),1-Treshold,Treshold);
    IntLim=linspace(Iinf,Isup,Nclass+1); IntLim(end)=Isup;
    
    MeanStdIntVxVy=zeros(Nclass-1,9);
    [~,linf]=min(abs(Disp_X_Y_LogI(:,ColInt)-IntLim(1)));
    for i=1:Nclass

        lsup=linf;
        while Disp_X_Y_LogI(lsup,ColInt)<IntLim(i+1)
            lsup=lsup+1;
        end
        
        MeanStdIntVxVy(i,1)=lsup-linf+1;
        MeanStdIntVxVy(i,2)=mean(Disp_X_Y_LogI(linf:lsup,ColX));
        MeanStdIntVxVy(i,3)=std(Disp_X_Y_LogI(linf:lsup,ColX));
        MeanStdIntVxVy(i,4)=mean(Disp_X_Y_LogI(linf:lsup,ColY));
        MeanStdIntVxVy(i,5)=std(Disp_X_Y_LogI(linf:lsup,ColY));
        MeanStdIntVxVy(i,6)=mean(Disp_X_Y_LogI(linf:lsup,ColInt));
        MeanStdIntVxVy(i,7)=std(Disp_X_Y_LogI(linf:lsup,ColInt));
        MeanStdIntVxVy(i,8)=mean(Disp_X_Y_LogI(linf:lsup,ColdInt));
        MeanStdIntVxVy(i,9)=std(Disp_X_Y_LogI(linf:lsup,ColdInt));
        
        data=Disp_X_Y_LogI(linf:lsup,ColX);
        [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
        FactorNorm=sum(counts)*mean(diff(centers));
        PDFsloc_dX_logIi{i,c}=[centers' counts' counts'/FactorNorm];
        
        data=Disp_X_Y_LogI(linf:lsup,ColY);
        [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
        FactorNorm=sum(counts)*mean(diff(centers));
        PDFsloc_dY_logIi{i,c}=[centers' counts' counts'/FactorNorm];
        
        data=Disp_X_Y_LogI(linf:lsup,ColdInt);
        [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
        FactorNorm=sum(counts)*mean(diff(centers));
        PDFsloc_dlogI_logIi{i,c}=[centers' counts' counts'/FactorNorm];
        
        linf=lsup;

    end
    
    MeanStdIntVxVyAll_logIi{c}=MeanStdIntVxVy;

end
for c=1:nc
    
    ColInt=ListColIntM(c); ColdInt=ListColdInt(c);
    
    Disp_X_Y_LogI=sortrows(Disp_X_Y_LogI,ColInt);
    [Iinf,Isup]=Decil(Disp_X_Y_LogI(:,ColInt),1-Treshold,Treshold);
    IntLim=linspace(Iinf,Isup,Nclass+1); IntLim(end)=Isup;
    
    MeanStdIntVxVy=zeros(Nclass-1,8);
    [~,linf]=min(abs(Disp_X_Y_LogI(:,ColInt)-IntLim(1)));
    for i=1:Nclass

        lsup=linf;
        while Disp_X_Y_LogI(lsup,ColInt)<IntLim(i+1)
            lsup=lsup+1;
        end
        
        MeanStdIntVxVy(i,1)=lsup-linf+1;
        MeanStdIntVxVy(i,2)=mean(Disp_X_Y_LogI(linf:lsup,ColX));
        MeanStdIntVxVy(i,3)=std(Disp_X_Y_LogI(linf:lsup,ColX));
        MeanStdIntVxVy(i,4)=mean(Disp_X_Y_LogI(linf:lsup,ColY));
        MeanStdIntVxVy(i,5)=std(Disp_X_Y_LogI(linf:lsup,ColY));
        MeanStdIntVxVy(i,6)=mean(Disp_X_Y_LogI(linf:lsup,ColInt));
        MeanStdIntVxVy(i,7)=std(Disp_X_Y_LogI(linf:lsup,ColInt));
        MeanStdIntVxVy(i,8)=mean(Disp_X_Y_LogI(linf:lsup,ColdInt));
        MeanStdIntVxVy(i,9)=std(Disp_X_Y_LogI(linf:lsup,ColdInt));
        
        data=Disp_X_Y_LogI(linf:lsup,ColX);
        [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
        FactorNorm=sum(counts)*mean(diff(centers));
        PDFsloc_dX_logIm{i,c}=[centers' counts' counts'/FactorNorm];
        
        data=Disp_X_Y_LogI(linf:lsup,ColY);
        [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
        FactorNorm=sum(counts)*mean(diff(centers));
        PDFsloc_dY_logIm{i,c}=[centers' counts' counts'/FactorNorm];
        
        data=Disp_X_Y_LogI(linf:lsup,ColdInt);
        [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
        FactorNorm=sum(counts)*mean(diff(centers));
        PDFsloc_dlogI_logIm{i,c}=[centers' counts' counts'/FactorNorm];
        
        linf=lsup;

    end
    
    MeanStdIntVxVyAll_logIm{c}=MeanStdIntVxVy;

end

%% Mean quantity calculation for several time steps
Nclass=20; Treshold=0.999; FactorPDF=2;
ListColMean=[1 2 3;4 5 6;7 8 9]; nc=size(ListColMean,2);
MeanStd_MeanDisp_TS=cell(nc,TSmax);
PDFsloc_X_TS=cell(nc,1); PDFsloc_dX_TS=cell(nc,1);
PDFsloc_Y_TS=cell(nc,1); PDFsloc_dY_TS=cell(nc,1);
PDFsloc_Int_TS=cell(nc,1); PDFsloc_dInt_TS=cell(nc,1);
for c=1:nc
    
    PDFsloc_dX_TS{c}=cell(Nclass,TSmax);
    for t=1:TSmax
        
        MeanDisp=Disp_X_Y_LogI_TimeStep{t}(:,[ListColMean(c,:) 10 11 12]);
        ColX=1; ColY=2; ColInt=3; ColdX=4; ColdY=5; ColdInt=6;
        
        MeanDisp=sortrows(MeanDisp,ColInt);
        [Iinf,Isup]=Decil(MeanDisp(:,ColInt),1-Treshold,Treshold);
        IntLim=linspace(Iinf,Isup,Nclass+1); IntLim(end)=Isup;
        
        MeanSt_MeanDisp=zeros(Nclass-1,13);
        [~,linf]=min(abs(MeanDisp(:,ColInt)-IntLim(1)));
        for i=1:Nclass

            lsup=linf;
            while MeanDisp(lsup,ColInt)<IntLim(i+1)
                lsup=lsup+1;
            end

            MeanSt_MeanDisp(i,1)=lsup-linf+1; % N
            MeanSt_MeanDisp(i,2)=mean(MeanDisp(linf:lsup,ColX));
            MeanSt_MeanDisp(i,3)=std(MeanDisp(linf:lsup,ColX));
            MeanSt_MeanDisp(i,4)=mean(MeanDisp(linf:lsup,ColdX));
            MeanSt_MeanDisp(i,5)=std(MeanDisp(linf:lsup,ColdX));
            MeanSt_MeanDisp(i,6)=mean(MeanDisp(linf:lsup,ColY));
            MeanSt_MeanDisp(i,7)=std(MeanDisp(linf:lsup,ColY));
            MeanSt_MeanDisp(i,8)=mean(MeanDisp(linf:lsup,ColdY));
            MeanSt_MeanDisp(i,9)=std(MeanDisp(linf:lsup,ColdY));
            MeanSt_MeanDisp(i,10)=mean(MeanDisp(linf:lsup,ColInt));
            MeanSt_MeanDisp(i,11)=std(MeanDisp(linf:lsup,ColInt));
            MeanSt_MeanDisp(i,12)=mean(MeanDisp(linf:lsup,ColdInt));
            MeanSt_MeanDisp(i,13)=std(MeanDisp(linf:lsup,ColdInt));
            
            data=MeanDisp(linf:lsup,ColX);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_X_TS{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColdX);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_dX_TS{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColY);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_Y_TS{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColdY);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_dY_TS{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColInt);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_Int_TS{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColdInt);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_dInt_TS{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            linf=lsup;

        end

        MeanStd_MeanDisp_TS{c,t}=MeanSt_MeanDisp;
        
    end
    
end

%% Figure to compare between Zinitial and Zmean for one time step
Radius_micron=50e-3; c=1;
Dp_exp=119; % experimental penetration depth

LogI_i=MeanStdIntVxVyAll_logIi{c}(:,6);
Vx_i=MeanStdIntVxVyAll_logIi{c}(:,2)*FrameRate/Scale;
Vy_i=MeanStdIntVxVyAll_logIi{c}(:,4)*FrameRate/Scale;
N_i=MeanStdIntVxVyAll_logIi{c}(:,1);
Dx_i=0.5*MeanStdIntVxVyAll_logIi{c}(:,3).^2*FrameRate/Scale^2;
Dy_i=0.5*MeanStdIntVxVyAll_logIi{c}(:,5).^2*FrameRate/Scale^2;
Pe_i=Radius_micron*Vx_i./Dy_i;
VlogI_i=MeanStdIntVxVyAll_logIi{c}(:,8)*FrameRate;
DlogI_i=0.5*MeanStdIntVxVyAll_logIi{c}(:,9).^2*FrameRate;
p=polyfit(LogI_i,Vx_i,1); ShearRate_i=-p(1)/(Dp_exp*1e-3);
LogI0_i=-p(2)/p(1); Z_i=Dp_exp*(LogI0_i-LogI_i);
Vz_i=-VlogI_i*Dp_exp*1e-3; Dz_i=DlogI_i*(Dp_exp*1e-3)^2;
p=polyfit(LogI_i,VlogI_i,1); ShearRateZ_i=p(1);
LogIeqZ=-p(2)/p(1); Z_eq=Dp_exp*(LogI0_i-LogIeqZ);

LogI_m=MeanStdIntVxVyAll_logIm{c}(:,6);
Vx_m=MeanStdIntVxVyAll_logIm{c}(:,2)*FrameRate/Scale;
Vy_m=MeanStdIntVxVyAll_logIm{c}(:,4)*FrameRate/Scale;
N_m=MeanStdIntVxVyAll_logIm{c}(:,1);
Dx_m=0.5*MeanStdIntVxVyAll_logIm{c}(:,3).^2*FrameRate/Scale^2;
Dy_m=0.5*MeanStdIntVxVyAll_logIm{c}(:,5).^2*FrameRate/Scale^2;
Pe_m=Radius_micron*Vx_m./Dy_m;
VlogI_m=MeanStdIntVxVyAll_logIm{c}(:,8)*FrameRate;
DlogI_m=0.5*MeanStdIntVxVyAll_logIm{c}(:,9).^2*FrameRate;
p=polyfit(LogI_m,Vx_m,1); ShearRate_m=-p(1)/(Dp_exp*1e-3);
LogI0_m=-p(2)/p(1); Z_m=Dp_exp*(LogI0_m-LogI_m);
Vz_m=-VlogI_m*Dp_exp*1e-3; Dz_m=DlogI_m*(Dp_exp*1e-3)^2;

%SaveFig=1;
Wfig=scrsz(3)*0.9; Hfig=scrsz(4)*0.8; FontSize=14; FontSizeText=12; LW=1; MS=10;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Quantities versus log I','numbertitle','off',...
    'resize','off');

Wf1=0.18*Wfig; Hf1=Wf1*3/3;
Ypos=[0.6 0.13]*Hfig;
N=4; Xpos=linspace(0.05,1-Wf1/Wfig-0.03,N)*Wfig;
AxAll=cell(length(Xpos),length(Ypos));
for j=1:length(Ypos)
    for i=1:length(Xpos)
        AxAll{i,j} = axes('Units','pixels','Position',[Xpos(i) Ypos(j) Wf1 Hf1]);
    end    
end

axes(AxAll{1,1}); hold on;
plot(Z_m,Vx_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Vx_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Vx_m;Vx_i]) max([Vx_m;Vx_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$v_x$ ($\mu$m.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,...
    '$v_x=\left<\Delta x\right>/\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.85,...
    ['$\tau=' num2str(1e3/FrameRate) '$ ms'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.75,...
    ['$\dot{\gamma}=' num2str(ShearRate_m,3) '$ s$^{-1}$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top','color','b');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.65,...
    ['$\dot{\gamma}=' num2str(ShearRate_i,3) '$ s$^{-1}$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$\tilde{z}=\Pi\log\left(I_0/I\right)$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.15,...
    ['$\Pi=' num2str(Dp_exp) '$ nm'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.25,...
    ['$\log I_0=' num2str(LogI0_i,3) '$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.35,...
    ['$\log I_0=' num2str(LogI0_m,3) '$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom','color','b');

axes(AxAll{2,1}); hold on;
plot(Z_m,Vy_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Vy_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Vy_m;Vy_i]) max([Vy_m;Vy_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$v_y$ ($\mu$m.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,...
    '$v_y=\left<\Delta y\right>/\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');

%%% hereeeeeeeeeeeeee %%%
axes(AxAll{3,1}); hold on;
plot(Z_m,Vz_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Vz_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Vz_m;Vz_i]) max([Vz_m;Vz_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$v_{\tilde{z}}$ ($\mu$m.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.95,...
    '$v_{\tilde{z}}=\left<\Delta\tilde{z}\right>/\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.25,...
    ['$\dot{\gamma}_{\tilde{z}}=' num2str(ShearRateZ_i,3) '$ s$^{-1}$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.15,...
    ['$\log I_{eq}=' num2str(LogIeqZ,3) '$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    ['$\tilde{z}_{eq}=' num2str(Z_eq,3) '$ nm'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','color','r');


axes(AxAll{4,1}); hold on;
plot(Z_m,N_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,N_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([N_m;N_i]) max([N_m;N_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$N$',0,0,0,0,FontSize);

axes(AxAll{1,2}); hold on;
plot(Z_m,Dx_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Dx_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Dx_m;Dx_i]) max([Dx_m;Dx_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$D_x$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$D_x=\sigma^2\left(\Delta x\right)/2\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');

axes(AxAll{2,2}); hold on;
plot(Z_m,Dy_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Dy_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Dy_m;Dy_i]) max([Dy_m;Dy_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$D_y$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$D_y=\sigma^2\left(\Delta y\right)/2\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');

axes(AxAll{3,2}); hold on;
plot(Z_m,Dz_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Dz_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Dz_m;Dz_i]) max([Dz_m;Dz_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$D_{\tilde{z}}$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.5,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$D_{\tilde{z}}=\sigma^2\left(\Delta\tilde{z}\right)/2\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');

axes(AxAll{4,2}); hold on;
plot(Pe_m,Dx_m./Dy_m-1,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Pe_i,Dx_i./Dy_i-1,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; Ax=axis;
MyFigureStyle('$Pe=v_x a/D_y$','$D_x/D_y-1$',0,0,0,0,FontSize);
leg=legend('$I_\mathrm{mean}$','$I_\mathrm{initial}$','Location','SouthEast');
set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);

I=strfind(MatFile_Exp,filesep);
FolderResults=MatFile_Exp(1:I(end)-1);
FigureName='MeanQuantities_Zapp_LogIm';
if SaveFig==1
    saveas(Fig,[FolderResults filesep FigureName '.fig']);
    export_fig([FolderResults filesep FigureName], '-tif');
    export_fig([FolderResults filesep FigureName], '-pdf');
    close(Fig);
end

%% Figure to compare between Zinitial and Zmean for a given time step
t=1;
Tau_frame=Npart_TS(1,t);
Radius_micron=50e-3; % Particle radii in microns
Dp_exp=119; % experimental penetration depth

c=1;
LogI_i=MeanStd_MeanDisp_TS{c,t}(:,10);
Vx_i=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
Vy_i=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
N_i=MeanStd_MeanDisp_TS{c,t}(:,1);
Dx_i=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
Dy_i=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
Pe_i=Radius_micron*Vx_i./Dy_i;
VlogI_i=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
DlogI_i=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
p=polyfit(LogI_i,Vx_i,1); ShearRate_i=-p(1)/(Dp_exp*1e-3);
LogI0_i=-p(2)/p(1); Z_i=Dp_exp*(LogI0_i-LogI_i);
Vz_i=-VlogI_i*Dp_exp*1e-3; Dz_i=DlogI_i*(Dp_exp*1e-3)^2;
p=polyfit(LogI_i,VlogI_i,1); ShearRateZ_i=p(1);
LogIeqZ=-p(2)/p(1); Z_eq=Dp_exp*(LogI0_i-LogIeqZ);

c=2;
LogI_if=MeanStd_MeanDisp_TS{c,t}(:,10);
Vx_if=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
Vy_if=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
N_if=MeanStd_MeanDisp_TS{c,t}(:,1);
Dx_if=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
Dy_if=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
Pe_if=Radius_micron*Vx_if./Dy_if;
VlogI_if=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
DlogI_if=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
p=polyfit(LogI_if,Vx_if,1); ShearRate_if=-p(1)/(Dp_exp*1e-3);
LogI0_if=-p(2)/p(1); Z_if=Dp_exp*(LogI0_if-LogI_if);
Vz_if=-VlogI_if*Dp_exp*1e-3; Dz_if=DlogI_if*(Dp_exp*1e-3)^2;

c=3;
LogI_m=MeanStd_MeanDisp_TS{c,t}(:,10);
Vx_m=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
Vy_m=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
N_m=MeanStd_MeanDisp_TS{c,t}(:,1);
Dx_m=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
Dy_m=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
Pe_m=Radius_micron*Vx_m./Dy_m;
VlogI_m=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
DlogI_m=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
p=polyfit(LogI_m,Vx_m,1); ShearRate_m=-p(1)/(Dp_exp*1e-3);
LogI0_m=-p(2)/p(1); Z_m=Dp_exp*(LogI0_m-LogI_m);
Vz_m=-VlogI_m*Dp_exp*1e-3; Dz_m=DlogI_m*(Dp_exp*1e-3)^2;

%SaveFig=1;
Wfig=scrsz(3)*0.9; Hfig=scrsz(4)*0.8; FontSize=14; FontSizeText=12; LW=1; MS=10;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Quantities versus log I','numbertitle','off',...
    'resize','off');

Wf1=0.18*Wfig; Hf1=Wf1*3/3;
Ypos=[0.6 0.13]*Hfig;
N=4; Xpos=linspace(0.05,1-Wf1/Wfig-0.03,N)*Wfig;
AxAll=cell(length(Xpos),length(Ypos));
for j=1:length(Ypos)
    for i=1:length(Xpos)
        AxAll{i,j} = axes('Units','pixels','Position',[Xpos(i) Ypos(j) Wf1 Hf1]);
    end    
end

axes(AxAll{1,1}); hold on;
plot(Z_m,Vx_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
% plot(Z_if,Vx_if,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',[0 0.5 0],'MarkerEdgeColor','black');
plot(Z_i,Vx_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Vx_m;Vx_i]) max([Vx_m;Vx_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$v_x$ ($\mu$m.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,...
    '$v_x=\left<\Delta x\right>/\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.85,...
    ['$\tau=' num2str(1e3*Tau_frame/FrameRate) '$ ms'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.75,...
    ['$\dot{\gamma}=' num2str(ShearRate_m,3) '$ s$^{-1}$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top','color','b');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.65,...
    ['$\dot{\gamma}=' num2str(ShearRate_i,3) '$ s$^{-1}$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$\tilde{z}=\Pi\log\left(I_0/I\right)$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.15,...
    ['$\Pi=' num2str(Dp_exp) '$ nm'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.25,...
    ['$\log I_0=' num2str(LogI0_i,3) '$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.35,...
    ['$\log I_0=' num2str(LogI0_m,3) '$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom','color','b');

axes(AxAll{2,1}); hold on;
plot(Z_m,Vy_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Vy_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Vy_m;Vy_i]) max([Vy_m;Vy_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$v_y$ ($\mu$m.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,...
    '$v_y=\left<\Delta y\right>/\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');

axes(AxAll{3,1}); hold on;
plot(Z_m,Vz_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Vz_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Vz_m;Vz_i]) max([Vz_m;Vz_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$v_{\tilde{z}}$ ($\mu$m.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.95,...
    '$v_{\tilde{z}}=\left<\Delta\tilde{z}\right>/\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.25,...
    ['$\dot{\gamma}_{\tilde{z}}=' num2str(ShearRateZ_i,3) '$ s$^{-1}$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.15,...
    ['$\log I_{eq}=' num2str(LogIeqZ,3) '$'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','color','r');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    ['$\tilde{z}_{eq}=' num2str(Z_eq,3) '$ nm'],...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','color','r');

axes(AxAll{4,1}); hold on;
plot(Z_m,N_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,N_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([N_m;N_i]) max([N_m;N_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$N$',0,0,0,0,FontSize);

axes(AxAll{1,2}); hold on;
plot(Z_m,Dx_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Dx_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Dx_m;Dx_i]) max([Dx_m;Dx_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$D_x$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$D_x=\sigma^2\left(\Delta x\right)/2\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');

axes(AxAll{2,2}); hold on;
plot(Z_m,Dy_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Dy_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Dy_m;Dy_i]) max([Dy_m;Dy_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$D_y$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$D_y=\sigma^2\left(\Delta y\right)/2\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');

axes(AxAll{3,2}); hold on;
plot(Z_m,Dz_m,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Z_i,Dz_i,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; axis([min([Z_m;Z_i]) max([Z_m;Z_i]) min([Dz_m;Dz_i]) max([Dz_m;Dz_i])]); Ax=axis;
MyFigureStyle('$\tilde{z}$ (nm)','$D_{\tilde{z}}$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.5,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$D_{\tilde{z}}=\sigma^2\left(\Delta\tilde{z}\right)/2\tau$',...
    'FontSize',FontSizeText,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');

axes(AxAll{4,2}); hold on;
plot(Pe_m,Dx_m./Dy_m-1,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(Pe_i,Dx_i./Dy_i-1,'-d','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; Ax=axis;
MyFigureStyle('$Pe=v_x a/D_y$','$D_x/D_y-1$',0,0,0,0,FontSize);
leg=legend('$I_\mathrm{mean}$','$I_\mathrm{initial}$','Location','SouthEast');
set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);

I=strfind(MatFile_Exp,filesep);
FolderResults=MatFile_Exp(1:I(end)-1);
FigureName='MeanQuantities_Zapp_LogIm';
if SaveFig==1
    saveas(Fig,[FolderResults filesep FigureName '.fig']);
    export_fig([FolderResults filesep FigureName], '-tif');
    export_fig([FolderResults filesep FigureName], '-pdf');
    close(Fig);
end

%% Figure for different time steps
c=1; % intensity method
Nt=TSmax; LimN=0.2; 
%SaveFig=1;
Colors_TS=[linspace(1,0,Nt)' zeros(Nt,1) linspace(0,1,Nt)'];
if c==1
    TitleInt='$\log I=\log I_\mathrm{initial}$';
    MethodInt='Ii';
elseif c==2
    TitleInt='$\log I=\left(\log I_\mathrm{initial}+\log I_\mathrm{final}\right)/2$';
    MethodInt='Iif';
elseif c==3
    TitleInt='$\log I=\frac{1}{N+1}\sum\limits_{i=1}^{N+1} \log I_i$';
    MethodInt='Imean';
end

Wfig=scrsz(3)*0.8; Hfig=scrsz(4)*0.8; FontSize=12; FontSizeText=12; LW1=1; MS1=10; LW2=2;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Convergence of quantities','numbertitle','off',...
    'resize','off');

N1=3; N2=3; Wf1=0.23*Wfig; Hf1=Wf1*0.5; AxAll=cell(N1,N2);
Xpos1=linspace(0.05,1-Wf1/Wfig-0.13,N1)*Wfig;
Ypos1=linspace(1-Hf1/Hfig-0.07,0.08,N1)*Hfig;
for i=1:N1
    for j=1:N2
        AxAll{i,j}=axes('Units','pixels','Position',[Xpos1(i) Ypos1(j) Wf1 Hf1]);
    end
end

axes(AxAll{1,1}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    Abs=LogI; Ord=Npart/NpartMax;
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd*1.1]); Ax=axis;
MyFigureStyle('$\log I$','$N$',0,TitleInt,0,0,FontSize);

axes(AxAll{2,1}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    I=Npart/NpartMax>=LimN;
    Abs=LogI(I); Ord=X(I);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
MyFigureStyle('$\log I$','$\left<x\right>$ ($\mu$m)',0,['$0<x<' num2str(nx/Scale,3) '$ $\mu$m'],0,0,FontSize);

axes(AxAll{3,1}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    I=Npart/NpartMax>=LimN;
    Abs=LogI(I); Ord=Y(I);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
MyFigureStyle('$\log I$','$\left<y\right>$ ($\mu$m)',0,['$' num2str(-ny/2/Scale,3) '<y<' num2str(ny/2/Scale,3) '$ $\mu$m'],0,0,FontSize);

SlopesdVxdlogI=zeros(Nt,2);
axes(AxAll{1,2}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    p=polyfit(LogI,Vx,1); SlopesdVxdlogI(t,:)=[Tau_frame/FrameRate p(1)];
    
    I=Npart/NpartMax>=LimN;
    Abs=LogI(I); Ord=Vx(I);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
MyFigureStyle('$\log I$','$v_x$ ($\mu$m.s$^{-1}$)',0,'$v_x=\left<\Delta x\right>/\tau$',0,0,FontSize);
f=0.4; AxSlope=axes('Units','pixels','Position',[Xpos1(1)+Wf1*(1-f) Ypos1(2)+Hf1*(1-f) Wf1*f Hf1*f]);
axes(AxSlope);
plot(SlopesdVxdlogI(:,1)*1e3,SlopesdVxdlogI(:,2),'o','LineWidth',1,'MarkerSize',6,'MarkerFaceColor',[0 0.5 0],'MarkerEdgeColor','black');
axis([min(SlopesdVxdlogI(:,1)*1e3) max(SlopesdVxdlogI(:,1)*1e3) min(SlopesdVxdlogI(:,2)) max(SlopesdVxdlogI(:,2))]); Ax=axis;
MyFigureStyle(0,'$\partial_{\log I} v_x$',0,0,0,0,FontSize*0.8);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,...
    '$\tau$ (ms)',...
    'FontSize',FontSize*0.8,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');

axes(AxAll{2,2}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    I=Npart/NpartMax>=LimN;
    Abs=LogI(I); Ord=Vy(I);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
MaxOrd=max(abs([MinOrd MaxOrd])); MinOrd=-MaxOrd;
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
MyFigureStyle('$\log I$','$v_y$ ($\mu$m.s$^{-1}$)',0,'$v_y=\left<\Delta y\right>/\tau$',0,0,FontSize);

axes(AxAll{3,2}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    I=Npart/NpartMax>=LimN;
    Abs=LogI; Ord=VlogI;
    plot(Abs(I),Ord(I),'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
MyFigureStyle('$\log I$','$v_{\log I}$ (s$^{-1}$)',0,'$v_{\log I}=\left<\Delta \log I\right>/\tau$',0,0,FontSize);

axes(AxAll{1,3}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    I=Npart/NpartMax>=LimN;
    Abs=LogI(I); Ord=Dx(I);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
MyFigureStyle('$\log I$','$D_x$ ($\mu$m$^2$.s$^{-1}$)',0,'$D_x=\left(\left<\Delta x^2\right>-\left<\Delta x\right>^2\right)/2\tau$',0,0,FontSize);

axes(AxAll{2,3}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
    I=Npart/NpartMax>=LimN;
    Abs=LogI(I); Ord=Dy(I);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
MyFigureStyle('$\log I$','$D_y$ ($\mu$m$^2$.s$^{-1}$)',0,'$D_y=\left(\left<\Delta y^2\right>-\left<\Delta y\right>^2\right)/2\tau$',0,0,FontSize);

axes(AxAll{3,3}); hold on;
for t=1:Nt
    
    Tau_frame=Npart_TS(1,t);
    Npart=MeanStd_MeanDisp_TS{c,t}(:,1);    
    X=MeanStd_MeanDisp_TS{c,t}(:,2)/Scale;
    Vx=MeanStd_MeanDisp_TS{c,t}(:,4)/Tau_frame*FrameRate/Scale;
    Dx=MeanStd_MeanDisp_TS{c,t}(:,5).^2/(2*Tau_frame)*FrameRate/Scale^2;
    Y=MeanStd_MeanDisp_TS{c,t}(:,6)/Scale;    
    Vy=MeanStd_MeanDisp_TS{c,t}(:,8)/Tau_frame*FrameRate/Scale;
    Dy=MeanStd_MeanDisp_TS{c,t}(:,9).^2/(2*Tau_frame)*FrameRate/Scale^2;
    LogI=MeanStd_MeanDisp_TS{c,t}(:,10);
    VlogI=MeanStd_MeanDisp_TS{c,t}(:,12)/Tau_frame*FrameRate;
    DlogI=MeanStd_MeanDisp_TS{c,t}(:,13).^2/(2*Tau_frame)*FrameRate;
    NpartMax=max(Npart);
    
%     I=Npart/NpartMax>=LimN;
%     Abs=LogI(I); Ord=DlogI(I);
%     plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors_TS(t,:),'MarkerEdgeColor','black','color',Colors_TS(t,:));
%     
%     if t==1
%         MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%     else
%         MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%         MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
%     end
%     
% end
% hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]); Ax=axis;
% MyFigureStyle('$\log I$','$D_{\log I}$ (s$^{-1}$)',0,'$D_{\log I}=\left(\left<\Delta \log I^2\right>-\left<\Delta \log I\right>^2\right)/2\tau$',0,0,FontSize);
% 
% CB=colorbar; set(CB,'TickLabelInterpreter', 'latex','FontSize',FontSize*1.5);
% ylabel(CB,'$\tau=N\tau_\mathrm{min}$ (ms)','Interpreter','latex','FontSize',FontSize*1.5);
% title(CB,['$\tau_\mathrm{min}=' num2str(1e3/FrameRate) '$ ms'],'Interpreter','latex','FontSize',FontSize*1.5);
% set(CB,'position',[(Xpos1(3)+Wf1)/Wfig+0.03 Ypos1(3)/Hfig 0.025 (Ypos1(1)-Ypos1(3)+Hf1)/Hfig]);
% colormap(Colors_TS); caxis([1 Nt]*1e3/FrameRate);
% 
% LimStr=num2str(LimN); I=strfind(LimStr,'.'); LimStr(I)='u';
% FigureName=['MeanQuantities_Ntmax' num2str(Nt) '_' MethodInt '_MinN' LimStr];
% if SaveFig==1
%     saveas(Fig,[FolderResults filesep FigureName '.fig']);
%     export_fig([FolderResults filesep FigureName], '-tif');
%     export_fig([FolderResults filesep FigureName], '-pdf');
%     close(Fig);
% end
% 
% %% Test the mean quantity convergence
% nint=Nclass;
% Quantities_logI_Time=zeros(tf,nint,9); c=1;
% ColInt=ListColIntI(c); ColdInt=ListColdInt(c);
% [Iinf,Isup]=Decil(Disp_X_Y_LogI(:,ColInt),1-Treshold,Treshold);
% IntLim=linspace(Iinf,Isup,nint+1); IntLim(end)=Isup;
% h = waitbar(0,'Processing');
% for t=1:tf
%     
%     I=Disp_X_Y_LogI(:,1)<=t;
%     Disp_X_Y_LogI_Time=Disp_X_Y_LogI(I==1,:);
%     Disp_X_Y_LogI_Time=sortrows(Disp_X_Y_LogI_Time,ColInt);
%     nt=size(Disp_X_Y_LogI_Time,1);
%     
%     [~,linf]=min(abs(Disp_X_Y_LogI_Time(:,ColInt)-IntLim(1)));
%     for i=1:nint
% 
%         lsup=linf;
%         while Disp_X_Y_LogI_Time(lsup,ColInt)<IntLim(i+1) && lsup<nt
%             lsup=lsup+1;
%         end
%         
%         Quantities_logI_Time(t,i,1)=lsup-linf+1;
%         Quantities_logI_Time(t,i,2)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColX));
%         Quantities_logI_Time(t,i,3)=std(Disp_X_Y_LogI_Time(linf:lsup,ColX));
%         Quantities_logI_Time(t,i,4)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColY));
%         Quantities_logI_Time(t,i,5)=std(Disp_X_Y_LogI_Time(linf:lsup,ColY));
%         Quantities_logI_Time(t,i,6)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColInt));
%         Quantities_logI_Time(t,i,7)=std(Disp_X_Y_LogI_Time(linf:lsup,ColInt));
%         Quantities_logI_Time(t,i,8)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColdInt));
%         Quantities_logI_Time(t,i,9)=std(Disp_X_Y_LogI_Time(linf:lsup,ColdInt));        
%         linf=lsup;
% 
%     end
%     
%     waitbar(t/tf,h);
%     
% end
% close(h);
% IntMin=Iinf; IntMax=Isup;
% 
% CorrelationLS_logI_Time=zeros(tf-1,9); CorrelationLS_logI_Time(:,1)=(2:tf)';
% CorrelationR2_logI_Time=zeros(tf-1,9); CorrelationR2_logI_Time(:,1)=(2:tf)';
% for t=2:tf
%     for i=2:9
%         CorrelationLS_logI_Time(t-1,i)=sum((Quantities_logI_Time(t-1,:,i)-Quantities_logI_Time(t,:,i)).^2);
%         CorrelationR2_logI_Time(t-1,i)=1-corr2(Quantities_logI_Time(t-1,:,i),Quantities_logI_Time(t,:,i));
%     end
% end
% 
% ntmean=20; Tmean=round(linspace(1,tf,ntmean+1))'; Tmean(end)=tf-1;
% Tmean_i=Tmean(1:end-1); Tmean_f=Tmean(2:end);
% CorrelationLS_logI_Time_Mean=zeros(ntmean,9);
% CorrelationR2_logI_Time_Mean=zeros(ntmean,9);
% for t=1:ntmean
%     CorrelationLS_logI_Time_Mean(t,:)=mean(CorrelationLS_logI_Time(Tmean_i(t):Tmean_f(t),:));
% end
% 
% CoefsFitCorr=zeros(8,4);
% for i=1:8
%     I=CorrelationLS_logI_Time(:,i+1)>0;
%     CoefsFitCorr(i,1:2)=polyfit(log(CorrelationLS_logI_Time(I==1,1)),log(CorrelationLS_logI_Time(I==1,i+1)),1);
%     I=CorrelationR2_logI_Time(:,i+1)>0;
%     CoefsFitCorr(i,3:4)=polyfit(log(CorrelationR2_logI_Time(I==1,1)),log(CorrelationR2_logI_Time(I==1,i+1)),1);
% end
% 
% %% Figure for convergence
% %SaveFig=1;
% Wfig=scrsz(3)*0.9; Hfig=scrsz(4)*0.8; FontSize=10; FontSizeText=12; LW1=1; MS1=10; LW2=2;
% Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
%     'menubar','figure','name','Convergence of quantities','numbertitle','off',...
%     'resize','off');
% 
% N1=7; N2=3; AxAll=cell(N1+N2,1);
% Wf1=0.1*Wfig; Hf1=Wf1*2;
% Ypos1=0.5*Hfig; Xpos1=linspace(0.05,1-Wf1/Wfig-0.03,N1)*Wfig;
% Wf2=0.25*Wfig; Hf2=Wf2*0.6;
% Ypos2=0.1*Hfig; Xpos2=linspace(0.05,1-Wf2/Wfig-0.03,N2)*Wfig;
% for i=1:N1
%     AxAll{i}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
% end
% for i=1:N2
%     AxAll{i+N1}=axes('Units','pixels','Position',[Xpos2(i) Ypos2 Wf2 Hf2]);
% end
% 
% ListPlot=[1 2 3 4 5 8 9];
% lim=0.99; Tmin_axis=1/FrameRate; Tmax_axis=2;
% axes(AxAll{1});
% Nnorm_Time=Quantities_logI_Time(:,:,ListPlot(1));
% Nmax=zeros(tf,1);
% for t=1:tf
%     Nmax(t)=max(Quantities_logI_Time(t,:,1));
%     Nnorm_Time(t,:,1)=Quantities_logI_Time(t,:,1)/Nmax(t);
% end
% imagesc(IntMin:IntMax,0:tf/FrameRate,Nnorm_Time);
% axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$N/N_{\mathrm{max}}$',2,'',FontSize);
% 
% axes(AxAll{2});
% Vx_Time=Quantities_logI_Time(:,:,ListPlot(2))*FrameRate/Scale;
% [linf,lsup]=Decil(Vx_Time,1-lim,lim);
% imagesc(IntMin:IntMax,0:tf/FrameRate,Vx_Time,[linf lsup]);
% axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$v_x$ ($\mu$m.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{3});
% Dx_Time=0.5*Quantities_logI_Time(:,:,ListPlot(3)).^2*FrameRate/Scale^2;
% [linf,lsup]=Decil(Dx_Time,1-lim,lim);
% imagesc(IntMin:IntMax,0:tf/FrameRate,Dx_Time,[linf lsup]);
% axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$D_x$ ($\mu$m$^2$.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{4});
% Vy_Time=Quantities_logI_Time(:,:,ListPlot(4))*FrameRate/Scale;
% [linf,lsup]=Decil(Vy_Time,1-lim,lim);
% imagesc(IntMin:IntMax,0:tf/FrameRate,Vy_Time,[linf lsup]);
% axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$v_y$ ($\mu$m.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{5});
% Dy_Time=0.5*Quantities_logI_Time(:,:,ListPlot(5)).^2*FrameRate/Scale^2;
% [linf,lsup]=Decil(Dy_Time,1-lim,lim);
% imagesc(IntMin:IntMax,0:tf/FrameRate,Dy_Time,[linf lsup]);
% axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$D_y$ ($\mu$m$^2$.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{6});
% VlogI_Time=Quantities_logI_Time(:,:,ListPlot(6))*FrameRate;
% [linf,lsup]=Decil(VlogI_Time,1-lim,lim);
% imagesc(IntMin:IntMax,0:tf/FrameRate,VlogI_Time,[linf lsup]);
% axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$v_{\log I}$ (s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{7});
% DlogI_Time=0.5*Quantities_logI_Time(:,:,ListPlot(7)).^2*FrameRate;
% [linf,lsup]=Decil(DlogI_Time,1-lim,lim);
% imagesc(IntMin:IntMax,0:tf/FrameRate,DlogI_Time,[linf lsup]);
% axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$D_{\log I}$ (s$^{-1}$)',2,'',FontSize);
% colormap jet;
% 
% axes(AxAll{8}); FontSize2=13;
% plot((1:tf)'/FrameRate,Nmax,'.','LineWidth',1,'MarkerSize',10,'color','black');
% MyFigureStyle('$t$ (s)','$N_{\mathrm{max}}$',0,0,0,'',FontSize2);
% 
% axes(AxAll{9});
% ColorsCorr=jet(length(ListPlot)-1); hold on;
% for i=1:length(ListPlot)-1
%     Abs=CorrelationLS_logI_Time(:,1)/FrameRate;
%     Ord=CorrelationLS_logI_Time(:,ListPlot(i+1));
%     plot(Abs,Ord,'.','color',ColorsCorr(i,:));
%     
%     if i==1
%         MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%     else
%         MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%         MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
%     end
% end
% AbsFit=linspace(MinAbs,MaxAbs,50)'*FrameRate; Pfit=cell(length(ListPlot)-1);
% for i=2:length(ListPlot)
%     OrdFit=AbsFit.^CoefsFitCorr(ListPlot(i)-1,1)*exp(CoefsFitCorr(ListPlot(i)-1,2));
%     Pfit{i-1}=plot(AbsFit/FrameRate,OrdFit,'-','LineWidth',2,'color',ColorsCorr(i-1,:));
% end
% OrdFit=AbsFit.^(-2)*exp(1);
% plot(AbsFit/FrameRate,OrdFit,'-','LineWidth',3,'color','black');
% hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]);
% set(gca,'xscale','log','yscale','log');
% MyFigureStyle('$t$ (s)','$S_{\mathrm{LS}}$',0,0,0,'',FontSize2);
% leg=legend([vertcat(Pfit{:})],'$v_x$','$D_x$','$v_y$','$D_y$','$v_{\log I}$','$D_{\log I}$','Location','SouthWest');
% set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
% text(AbsFit(fix(end/20))/FrameRate,OrdFit(fix(end/20)),'{\boldmath$-2$}',...
%     'FontSize',FontSize*2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% text(MaxAbs,MaxOrd,'$S_{\mathrm{LS}}=\sum\left(A\left(t+\delta t\right)-A\left(t\right)\right)^2$',...
%     'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% 
% axes(AxAll{10});
% ColorsCorr=jet(length(ListPlot)-1); hold on;
% for i=1:length(ListPlot)-1
%     Abs=CorrelationR2_logI_Time(:,1)/FrameRate;
%     Ord=CorrelationR2_logI_Time(:,ListPlot(i+1));
%     plot(Abs,Ord,'.','color',ColorsCorr(i,:));
%     
%     if i==1
%         MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%     else
%         MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%         MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
%     end
% end
% AbsFit=linspace(MinAbs,MaxAbs,50)'*FrameRate; Pfit=cell(length(ListPlot)-1);
% for i=2:length(ListPlot)
%     OrdFit=AbsFit.^CoefsFitCorr(ListPlot(i)-1,3)*exp(CoefsFitCorr(ListPlot(i)-1,4));
%     Pfit{i-1}=plot(AbsFit/FrameRate,OrdFit,'-','LineWidth',2,'color',ColorsCorr(i-1,:));
% end
% OrdFit=AbsFit.^(-2)*exp(-2);
% plot(AbsFit/FrameRate,OrdFit,'-','LineWidth',3,'color','black');
% hold off; axis([MinAbs MaxAbs MinOrd MaxOrd]);
% set(gca,'xscale','log','yscale','log');
% MyFigureStyle('$t$ (s)','$1-R^2$',0,0,0,'',FontSize2);
% leg=legend([vertcat(Pfit{:})],'$v_x$','$D_x$','$v_y$','$D_y$','$v_{\log I}$','$D_{\log I}$','Location','SouthWest');
% set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
% text(AbsFit(fix(end/20))/FrameRate,OrdFit(fix(end/20)),'{\boldmath$-2$}',...
%     'FontSize',FontSize*2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% text(MaxAbs,MaxOrd,'$R^2=\mathrm{corr2}\left(A\left(t+\delta t\right),A\left(t\right)\right)$',...
%     'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% 
% FigureName='MeanQuantitiesConvergence_LogI_i';
% if SaveFig==1
%     saveas(Fig,[FolderResults filesep FigureName '.fig']);
%     export_fig([FolderResults filesep FigureName], '-tif');
%     export_fig([FolderResults filesep FigureName], '-pdf');
%     close(Fig);
% end
% 
% %% Stationnarity of quantities
% nint=Nclass; wt_s=100; dt_s=1;
% Ti_s=(1:dt_s:tf-wt_s+1)'; Tf_s=Ti_s+wt_s-1;
% Time_s=(Ti_s+Tf_s)/2; nt_s=length(Time_s);
% Quantities_logI_Staionnarity=zeros(nt_s,nint,9); c=1;
% ColInt=ListColIntI(c); ColdInt=ListColdInt(c);
% [Iinf,Isup]=Decil(Disp_X_Y_LogI(:,ColInt),1-Treshold,Treshold);
% IntLim=linspace(Iinf,Isup,nint+1); IntLim(end)=Isup;
% h = waitbar(0,'Processing');
% for t=1:nt_s
%     
%     I=(Disp_X_Y_LogI(:,1)>=Ti_s(t) & Disp_X_Y_LogI(:,1)<=Tf_s(t));
%     Disp_X_Y_LogI_Time=Disp_X_Y_LogI(I==1,:);
%     Disp_X_Y_LogI_Time=sortrows(Disp_X_Y_LogI_Time,ColInt);
%     nt=size(Disp_X_Y_LogI_Time,1);
%     
%     [~,linf]=min(abs(Disp_X_Y_LogI_Time(:,ColInt)-IntLim(1)));
%     for i=1:nint
% 
%         lsup=linf;
%         while Disp_X_Y_LogI_Time(lsup,ColInt)<IntLim(i+1) && lsup<nt
%             lsup=lsup+1;
%         end
%         
%         Quantities_logI_Staionnarity(t,i,1)=lsup-linf+1;
%         Quantities_logI_Staionnarity(t,i,2)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColX));
%         Quantities_logI_Staionnarity(t,i,3)=std(Disp_X_Y_LogI_Time(linf:lsup,ColX));
%         Quantities_logI_Staionnarity(t,i,4)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColY));
%         Quantities_logI_Staionnarity(t,i,5)=std(Disp_X_Y_LogI_Time(linf:lsup,ColY));
%         Quantities_logI_Staionnarity(t,i,6)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColInt));
%         Quantities_logI_Staionnarity(t,i,7)=std(Disp_X_Y_LogI_Time(linf:lsup,ColInt));
%         Quantities_logI_Staionnarity(t,i,8)=mean(Disp_X_Y_LogI_Time(linf:lsup,ColdInt));
%         Quantities_logI_Staionnarity(t,i,9)=std(Disp_X_Y_LogI_Time(linf:lsup,ColdInt));        
%         linf=lsup;
% 
%     end
%     
%     waitbar(t/tf,h);
%     
% end
% close(h);
% IntMin=Iinf; IntMax=Isup;
% 
% %% Figure for stationnarity
% %SaveFig=1;
% Wfig=scrsz(3)*0.9; Hfig=scrsz(4)*0.8; FontSize=10; FontSizeText=12; LW1=1; MS1=10; LW2=2;
% Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
%     'menubar','figure','name','Convergence of quantities','numbertitle','off',...
%     'resize','off');
% 
% N1=7; N2=3; AxAll=cell(N1+2*N2,1);
% Wf1=0.1*Wfig; Hf1=Wf1*2;
% Ypos1=0.55*Hfig; Xpos1=linspace(0.05,1-Wf1/Wfig-0.03,N1)*Wfig;
% Wf2=0.25*Wfig; Hf2=Wf2*0.3;
% Ypos2=[0.3 0.1]*Hfig; Xpos2=linspace(0.05,1-Wf2/Wfig-0.03,N2)*Wfig;
% for i=1:N1
%     AxAll{i}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
% end
% for i=1:N2
%     AxAll{i+N1}=axes('Units','pixels','Position',[Xpos2(i) Ypos2(1) Wf2 Hf2]);
% end
% for i=1:N2
%     AxAll{i+N1+N2}=axes('Units','pixels','Position',[Xpos2(i) Ypos2(2) Wf2 Hf2]);
% end
% 
% ListPlot=[1 2 3 4 5 8 9];
% lim=0.99; Tmin_axis=Time_s(1)/FrameRate; Tmax_axis=Time_s(end)/FrameRate;
% axes(AxAll{1});
% Npart_Time=Quantities_logI_Staionnarity(:,:,ListPlot(1));
% [linf,lsup]=Decil(Npart_Time,1-lim,lim);
% imagesc(IntMin:IntMax,Time_s(1)/FrameRate:Time_s(end)/FrameRate,Npart_Time,[linf lsup]);
% % axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$N$',2,'',FontSize);
% 
% axes(AxAll{2});
% Vx_Time=Quantities_logI_Staionnarity(:,:,ListPlot(2))*FrameRate/Scale;
% [linf,lsup]=Decil(Vx_Time,1-lim,lim);
% imagesc(IntMin:IntMax,Time_s(1)/FrameRate:Time_s(end)/FrameRate,Vx_Time,[linf lsup]);
% % axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$v_x$ ($\mu$m.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{3});
% Dx_Time=0.5*Quantities_logI_Staionnarity(:,:,ListPlot(3)).^2*FrameRate/Scale^2;
% [linf,lsup]=Decil(Dx_Time,1-lim,lim);
% imagesc(IntMin:IntMax,Time_s(1)/FrameRate:Time_s(end)/FrameRate,Dx_Time,[linf lsup]);
% % axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$D_x$ ($\mu$m$^2$.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{4});
% Vy_Time=Quantities_logI_Staionnarity(:,:,ListPlot(4))*FrameRate/Scale;
% [linf,lsup]=Decil(Vy_Time,1-lim,lim);
% imagesc(IntMin:IntMax,Time_s(1)/FrameRate:Time_s(end)/FrameRate,Vy_Time,[linf lsup]);
% % axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$v_y$ ($\mu$m.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{5});
% Dy_Time=0.5*Quantities_logI_Staionnarity(:,:,ListPlot(5)).^2*FrameRate/Scale^2;
% [linf,lsup]=Decil(Dy_Time,1-lim,lim);
% imagesc(IntMin:IntMax,Time_s(1)/FrameRate:Time_s(end)/FrameRate,Dy_Time,[linf lsup]);
% % axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$D_y$ ($\mu$m$^2$.s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{6});
% VlogI_Time=Quantities_logI_Staionnarity(:,:,ListPlot(6))*FrameRate;
% [linf,lsup]=Decil(VlogI_Time,1-lim,lim);
% imagesc(IntMin:IntMax,Time_s(1)/FrameRate:Time_s(end)/FrameRate,VlogI_Time,[linf lsup]);
% % axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$v_{\log I}$ (s$^{-1}$)',2,'',FontSize);
% 
% axes(AxAll{7});
% DlogI_Time=0.5*Quantities_logI_Staionnarity(:,:,ListPlot(7)).^2*FrameRate;
% [linf,lsup]=Decil(DlogI_Time,1-lim,lim);
% imagesc(IntMin:IntMax,Time_s(1)/FrameRate:Time_s(end)/FrameRate,DlogI_Time,[linf lsup]);
% % axis([IntMin IntMax Tmin_axis Tmax_axis]);
% MyFigureStyle('$\log I$','$t$ (s)',0,'$D_{\log I}$ (s$^{-1}$)',2,'',FontSize);
% colormap jet;
% 
% axes(AxAll{8}); FontSize2=10;
% plot(Time_s/FrameRate,mean(Vx_Time,2),'.','LineWidth',1,'MarkerSize',10,'color','black');
% MyFigureStyle(0,'$\left<v_x\right>_{\log I}$ ($\mu$m.s$^{-1}$)',0,0,0,'',FontSize2);
% 
% Title=['$n_f=' num2str(wt_s) '$ frames ; $dt=' num2str(dt_s) '$ frame(s)'];
% axes(AxAll{9});
% plot(Time_s/FrameRate,mean(Vy_Time,2),'.','LineWidth',1,'MarkerSize',10,'color','black');
% MyFigureStyle(0,'$\left<v_y\right>_{\log I}$ ($\mu$m.s$^{-1}$)',0,Title,0,'',FontSize2);
% 
% axes(AxAll{10});
% plot(Time_s/FrameRate,mean(VlogI_Time,2),'.','LineWidth',1,'MarkerSize',10,'color','black');
% MyFigureStyle(0,'$\left<v_{\log I}\right>_{\log I}$ (s$^{-1}$)',0,0,0,'',FontSize2);
% 
% axes(AxAll{11});
% plot(Time_s/FrameRate,mean(Dx_Time,2),'.','LineWidth',1,'MarkerSize',10,'color','black');
% MyFigureStyle('$t$ (s)','$\left<D_x\right>_{\log I}$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,'',FontSize2);
% 
% axes(AxAll{12});
% plot(Time_s/FrameRate,mean(Dy_Time,2),'.','LineWidth',1,'MarkerSize',10,'color','black');
% MyFigureStyle('$t$ (s)','$\left<D_y\right>_{\log I}$ ($\mu$m$^2$.s$^{-1}$)',0,0,0,'',FontSize2);
% 
% axes(AxAll{13});
% plot(Time_s/FrameRate,mean(DlogI_Time,2),'.','LineWidth',1,'MarkerSize',10,'color','black');
% MyFigureStyle('$t$ (s)','$\left<D_{\log I}\right>_{\log I}$ (s$^{-1}$)',0,0,0,'',FontSize2);
% 
% FigureName='MeanQuantitiesStationnarity_LogI_i';
% if SaveFig==1
%     saveas(Fig,[FolderResults filesep FigureName '.fig']);
%     export_fig([FolderResults filesep FigureName], '-tif');
%     export_fig([FolderResults filesep FigureName], '-pdf');
%     close(Fig);
% end

save([MatFile_path,'\Intensity_method_comp.mat'],'MeanStd_MeanDisp_TS')
% bb = dir('C:\Gabriel_PhD\TIRF_Raw_data\2019-11-27-DeadLayer\Results');
% for k = 3:42
%     ConvergenceStationnarityOneVideo_function([bb(k).folder '\' bb(k).name],0)
% end
end

