function [Infos,ColumnNames]=FindInformationsFromName(FileName,Mode)

%% Get informations
Im=strfind(FileName,'-'); I_=strfind(FileName,'_'); Ifs=strfind(FileName,filesep);
IndexSep=sort([Im I_ Ifs]);

% Motor position
SubName=FindNamePart(FileName,'motor',IndexSep);
MotorPosition=str2double(SubName(6:end));

% Laser power
SubName=FindNamePart(FileName,'Plaser',IndexSep);
LaserPower=str2double(SubName(7:end-2));

% Pressure
SubName=FindNamePart(FileName,'mbar',IndexSep);
Pressure=str2double(SubName(2:end-4));

% FrameRate
if length(strfind(FileName,'fps'))>0
    SubName=FindNamePart(FileName,'fps',IndexSep);
    SubName=regexprep(SubName,'u','.');
    FrameRate=str2double(SubName(2:end-3));
elseif length(strfind(FileName,'Hz'))>0
    SubName=FindNamePart(FileName,'Hz',IndexSep);
    SubName=regexprep(SubName,'u','.');
    FrameRate=str2double(SubName(2:end-3));
else
    FrameRate = 400;
end

% Exposure Time
SubName=FindNamePart(FileName,'ET',IndexSep);
if isnan(SubName)==0
    SubName=regexprep(SubName,'ms','.');
end
ExposureTime=str2double(SubName(3:end));

% PEG concentration
SubName=FindNamePart(FileName,'PEG',IndexSep);
if isnan(SubName)==0
    SubName=regexprep(SubName,'u','.');
end
PEGpcWater=str2double(SubName(1:end-3));


%% Build structures
if strcmpi(Mode,'struct')==1
    Infos=struct([]);
    Infos(1).MotorPosition=MotorPosition;
    Infos(1).LaserPower=LaserPower;
    Infos(1).Pressure=Pressure;
    Infos(1).FrameRate=FrameRate;
    Infos(1).ExposureTime=ExposureTime;
    Infos(1).PEGpcWater=PEGpcWater;
elseif strcmpi(Mode,'matrix')==1
    Infos=[MotorPosition LaserPower Pressure FrameRate ExposureTime PEGpcWater];
end

ColumnNames={'MotorPosition','LaserPower','Pressure','FrameRate','ExposureTime','PEGpcWater'};



end

