function [Coefs,FrameFit]=FrameGaussianFit(Frame,StartPoints,Display)

% Background 2d-Gaussian fit

Frame=double(Frame);
[ny,nx]=size(Frame);
Xc1=(1:nx)'; Yc1=(1:ny)'; [X,Y]=meshgrid(Xc1,Yc1);
x=reshape(X,[numel(X) 1 1]); y=reshape(Y,[numel(Y) 1 1]);
z=reshape(double(Frame),[numel(Frame) 1 1]); r=[x y];


if StartPoints==0
    TresholdLoc=0.99;
    [I0,Im]=Decil(double(Frame),1-TresholdLoc,TresholdLoc);
    I=find(z>I0+(Im-I0)*0.9);
    x0=sum(x(I).*z(I))/sum(z(I));
    y0=sum(y(I).*z(I))/sum(z(I));
    a0=sqrt(length(I));
elseif length(StartPoints)==5
    I0=StartPoints(1); Im=StartPoints(2);
    x0=StartPoints(3); y0=StartPoints(4); a0=StartPoints(5);
end

GaussianEq=@(C,r)C(1)+(C(2)-C(1))*exp(-((r(:,1)-C(3)).^2+(r(:,2)-C(4)).^2)/(2*C(5)^2));
C0=[I0 Im-I0 x0 y0 a0];
Cinf=[0 0 x0-nx/2 y0-ny/2 0];
Csup=[I0*2 1.5*max(z)-I0 x0+nx/2 y0+ny/2 sqrt((nx)^2+(ny)^2)];

J=z>0;
C=lsqcurvefit(GaussianEq,C0,r(J,:),z(J),Cinf,Csup);
if strcmpi(Display,'yes')==1
    [Cinf;C0;C;Csup]
end

zfit=GaussianEq(C,r);
FrameFit=reshape(zfit,[ny nx 1]);
Coefs=C;

if strcmpi(Display,'yes')==1
    
    scrsz=get(0,'ScreenSize'); % Problems if you change your screen
    scrsz2=[(scrsz(3)-scrsz(4))/2 scrsz(2) scrsz(4) scrsz(4)];
    FontSize=14;
    [~,Ix]=min(abs(X(1,:)-round(C(3))));
    [~,Iy]=min(abs(Y(:,1)-round(C(4))));
    
    figure('name','Gaussian fit','NumberTitle','off');
    set(gcf,'Position',scrsz2);
    row=2; col=2; FactorAR=round(nx/ny);
    subplot(row,col,1); imagesc(1:nx,1:ny,Frame,[I0 Im]);
    MyFigStyleLaTeXSave('$x$','$y$',0,'Frame',2,'I',[1 1 1],FontSize);
    subplot(row,col,2); imagesc(1:nx,1:ny,FrameFit,[I0 Im]);
    MyFigStyleLaTeXSave('$x$','$y$',0,'Fit',2,'I',[1 1 1],FontSize);
    subplot(row,col,3); plot(X(1,:),Frame(Iy,:),'o',X(1,:),FrameFit(Iy,:),'-','LineWidth',2,'MarkerSize',8);
    axis([1 nx 0 1.1*max(max(Frame(Iy,:)),max(FrameFit(Iy,:)))]); Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    MyFigStyleLaTeXSave('$x$','$I$',0,['$y=' num2str(round(C(4))) '$'],0,0,[1 FactorAR*AR 1],FontSize);
    subplot(row,col,4); plot(Y(:,1),Frame(:,Ix),'o',Y(:,1),FrameFit(:,Ix),'-','LineWidth',2,'MarkerSize',8);
    axis([1 ny 0 1.1*max(max(Frame(:,Ix)),max(FrameFit(:,Ix)))]); Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    MyFigStyleLaTeXSave('$y$','$I$',0,['$x=' num2str(round(C(3))) '$'],0,0,[1 FactorAR*AR 1],FontSize);
    colormap jet;    
    
end


end