function [outputArg1,outputArg2] = MergeMultiTIRFexp_function(MainFolder,II,Method_Intensity,Output_Folder_Name,SaveFig)
%% Program to concatenate statistics of several videos of the same experiments
% This code will collect all the data for all trajectories, calculate all
% the displacements, concatenate and calculate mean quantities,
% distribution, evaluate the stationnarity
% clear all; close all;
% FolderMatlab='C:\Gabriel_PhD\Matlab_codes\Functions';
% addpath(genpath(FolderMatlab));te mean quantities,
% distribution, evaluate the stationnarity

%% Get the subfolders

d = dir([MainFolder filesep 'Results']);
ListSubFolders = d([d(:).isdir]==1);
ListSubFolders = ListSubFolders(~ismember({ListSubFolders(:).name},{'.','..'}));
NfilesAll=numel(ListSubFolders); clear d;

Infos=zeros(NfilesAll,8);
for i = 1 : NfilesAll
    
    % Folder results
    Name = ListSubFolders(i).name;
    Infos(i,1)=contains(Name,'results','IgnoreCase',true);
    
    % Movie number
    I=strfind(Name,'-');
    if isempty(I)==0
        Infos(i,2)=str2double(Name(1:I(1)-1)); % Movie number
    else
        Infos(i,2)=NaN;
    end
    
    % Fluorescein movie
    Infos(i,3)=contains(Name,'fluo','IgnoreCase',true);
    
    % Pressure
    SubName=FindNamePart(Name,'mbar',0);
    if ~isnan(SubName)
        Infos(i,4)=str2double(regexp(SubName,'\d*','Match'));
    else
        Infos(i,4) = NaN;
    end
    
    % Particle size
    SubName=FindNamePart(Name,'NPS',0);
    if ~isnan(SubName)
        P = regexp(SubName,'\d*','Match');
        Infos(i,5)=str2double(P{1});
    else
        Infos(i,5)=110;
    end
    
    % Frame rate in fps
    SubName=FindNamePart(Name,'fps',0);
    if isnan(SubName)==1
        SubName=FindNamePart(Name,'Hz',0);
    end
    if ~isnan(SubName)
        N=regexp(SubName,'\d*','Match');
        if length(N) == 1
            Infos(i,6) = str2double(N);
        elseif length(N) == 2
            Infos(i,6) = str2double([N{1} '.' N{2}]);
        end
    else
        Infos(i,6) = NaN;
    end
    
    % polymer concentration
    SubName=FindNamePart(Name,'cstar',0);
    if ~isnan(SubName)
        P = regexp(SubName,'\d*','Match');
        if size(P,2) == 1
            Infos(i,7)=str2double(P);
        elseif size(P,2) == 2
            Infos(i,7)=str2double([P{1} '.'  P{2}]);
        end
    else
        Infos(i,7) = NaN;
    end
    
    % NaCl
    SubName=FindNamePart(Name,'NaCl',0);
    if ~isnan(SubName)
        P = regexp(SubName,'\d*','Match');
        if size(P,2) == 1
            Infos(i,8)=str2double(P);
        elseif size(P,2) == 2
            Infos(i,8)=str2double([P{1} '.'  P{2}]);
        end
    else
        Infos(i,8) = NaN;
    end
    
end

%% Movies and intensity method selection
% Intensity method selection
% Method_Intensity='max_gaussian'; % 'max_gaussian' , 'int_gaussian' , 'sum_pixels'

% Manually especially to remove a particular video
% I = find(Infos(:,2) >= 67 & Infos(:,2) <= 69); % Movie number!!!!!
% I=[13 15 16 17 18]';

[~,Isort]=sort(Infos(II,2));
Nfiles=length(II); MovieNumbers=cell(1,Nfiles);
FinalSubFolderList=cell(Nfiles,1); FinalInfos=Infos(II,:);
for i= 1 : Nfiles
    MovieNumbers{i}=sprintf('%02d',Infos(II(Isort(i)),2));
    FinalSubFolderList{i}=ListSubFolders(II(Isort(i))).name;
end
MovieNumbers=horzcat(MovieNumbers{:});

% Creation of a directory to save the results
if strcmpi(Method_Intensity,'max_gaussian')==1
    FolderResults=[MainFolder filesep Output_Folder_Name filesep MovieNumbers filesep 'MaxGaussian'];
elseif strcmpi(Method_Intensity,'int_gaussian')==1
    FolderResults=[MainFolder filesep Output_Folder_Name filesep MovieNumbers filesep 'IntGaussian'];
elseif strcmpi(Method_Intensity,'sum_pixels')==1
    FolderResults=[MainFolder filesep Output_Folder_Name filesep MovieNumbers filesep 'SumPixels'];
end
if exist(FolderResults,'dir')==0
    mkdir(FolderResults);
end

clearvars -except MainFolder ListSubFolders Infos Method_Intensity...
    FolderResults MovieNumbers Nfiles FinalSubFolderList FinalInfos SaveFig

%% Data import, trajectory correction and displacement calculations

% Parameters
AngleCorrection = 1; % Correct if the flow is not completely along X
MethodInterp = 'linear'; % interpolate incomplete trajectories
TrajectorySelection = 0; % New parameters Tmin Tmax Dmin Lmin
Ntau_fix = 0; % Max time step for displacement calculation
Nclass = 20; % interval number for mean values

Scales = zeros(Nfiles,1); FrameRates = zeros(Nfiles,1);
SizesFrame = zeros(Nfiles,4);
InfosFile = cell(Nfiles,1); TrackingParameters = zeros(Nfiles,5);
MeanStdIntVxVyAll_Repro = cell(Nfiles,1); 
Disp_X_Y_LogI_TimeStep = cell(Nfiles,1);
Npart_TimeStep = cell(Nfiles,2);
TrajectoryAll = cell(Nfiles,1);
SpatialDistrib = cell(Nfiles,4);
Stationnarity = cell(Nfiles,2);
for n = 1 : Nfiles
    
    % Find and load the mat file containing containing trajectories
    PathName=[MainFolder filesep 'Results' filesep FinalSubFolderList{n}];
    
    MatFileTrajectories=FindUniqueFileList(PathName,'.mat','Trajectories');
    load(MatFileTrajectories,'Paths','PathsProperties','PathsParticles',...
        'VelocityIntensity','MeanStdIntVxVyAll','nx','ny',...
        'max_linking_distance_Xn','max_linking_distance_Xp',...
        'max_linking_distance_Yn','max_linking_distance_Yp',...
        'max_gap_closing','Tmin','Tmax','Dmin','Lmin');
    
    % Collect information and data already available
    Scale=22.9; % OPTIONAL! BE CAREFUL WITH THE MICROSCOPE MAGNIFICATION!!!        
    [InfosFile{n},ColumnNames] = FindInformationsFromName(PathName,'matrix');
%     FrameRate = InfosFile{n}(4);
    FrameRate = FinalInfos(n,6);
    TrackingParameters(n,1) = max_linking_distance_Xn;
    TrackingParameters(n,2) = max_linking_distance_Xp;
    TrackingParameters(n,3) = max_linking_distance_Yn;
    TrackingParameters(n,4) = max_linking_distance_Yp;
    TrackingParameters(n,5) = max_gap_closing;    
    Scales(n) = Scale; FrameRates(n) = FrameRate;
    MeanStdIntVxVyAll_Repro{n,1} = MeanStdIntVxVyAll;
    
    % Displacements
    [Disp_X_Y_LogI_TimeStepOneMovie,Npart_TS,FrameRate,Scale,MaxNp,...
        Trajectories,MeanStd_MeanDisp_TimeStep]=Traj2DispMeanStd(...
        MatFileTrajectories,Method_Intensity,AngleCorrection,...
        MethodInterp,TrajectorySelection,Ntau_fix,Nclass);
    
    % Spatial distribution
    t = 1;
    XiYiLogIidXdYdlogI = Disp_X_Y_LogI_TimeStepOneMovie{t}(:,[1:3 10:12]);
    XiYiLogIidXdYdlogI = sortrows(XiYiLogIidXdYdlogI,1);
    np = size(XiYiLogIidXdYdlogI,1); npx = 2*round(np^(1/4)); npy = npx;
    Xe = linspace(1,nx,npx+1)'; Ye = linspace(-ny/2,ny/2,npy+1)';

    NpartXY = zeros(npy,npx);
    MeanLogIidXdYdlogI = zeros(npy,npx,4); StdLogIidXdYdlogI = zeros(npy,npx,4);
    Ixi = 1;
    for i = 1 : npx

        Ixf = Ixi;
        while XiYiLogIidXdYdlogI(Ixf,1) < Xe(i+1) && Ixf < size(XiYiLogIidXdYdlogI,1)
            Ixf = Ixf + 1;
        end
        YiLogIidXdYdlogI_loc = XiYiLogIidXdYdlogI(Ixi:Ixf,2:end);
        YiLogIidXdYdlogI_loc = sortrows(YiLogIidXdYdlogI_loc,1);

        Iyi = 1;
        for j = 1 : npy

            Iyf = Iyi;
            while YiLogIidXdYdlogI_loc(Iyf,1) < Ye(j+1) && Iyf < size(YiLogIidXdYdlogI_loc,1)
                Iyf = Iyf + 1;
            end
            LogIidXdYdlogI_loc = YiLogIidXdYdlogI_loc(Iyi:Iyf,2:end);

            NpartXY(j,i) = size(LogIidXdYdlogI_loc,1);
            for k = 1 : 4
                MeanLogIidXdYdlogI(j,i,k) = mean(LogIidXdYdlogI_loc(:,k));
                StdLogIidXdYdlogI(j,i,k) = std(LogIidXdYdlogI_loc(:,k));
            end        
            Iyi = Iyf;

        end
        Ixi = Ixf;

    end

    MeanStdRatio = zeros(5,3);
    Map = NpartXY; List = reshape(Map,[numel(Map) 1 1]);
    MeanStdRatio(1,1:2) = [mean(List) std(List)];
    for i = 1 : 4
        Map = MeanLogIidXdYdlogI(:,:,i); List = reshape(Map,[numel(Map) 1 1]);
        MeanStdRatio(i+1,1:2) = [mean(List) std(List)];
    end
    MeanStdRatio(:,3) = MeanStdRatio(:,2)./abs(MeanStdRatio(:,1));
    
    % Stationnarity
    t = 1; % First time step
    c = 1; % Versus log I initial
    nint = Nclass; Treshold=0.999;
    Tau = Npart_TS(1,t)/FrameRate;
    ListColMean=[1 2 3;4 5 6;7 8 9]; nc=size(ListColMean,2);
    ColX=1; ColY=2; ColInt=3; ColdX=4; ColdY=5; ColdInt=6; ColT = 7;
    PosDisp = Disp_X_Y_LogI_TimeStepOneMovie{t}(:,[ListColMean(c,:) 10:13]);
    % Intensity limits
    PosDisp = sortrows(PosDisp,ColInt);
    Ilimits = quantile(PosDisp(:,ColInt),[1-Treshold,Treshold]);
    Iinf = Ilimits(1); Isup = Ilimits(2);
    IntLim=linspace(Iinf,Isup,Nclass+1); IntLim(end)=Isup;
    % Time limits
    PosDisp = sortrows(PosDisp,ColT);
    Tmin = PosDisp(1,ColT); Tmax = PosDisp(end,ColT); nt = Tmax - Tmin + 1;    
    wt_s = 100; dt_s = 1;
    Ti_s = (Tmin : dt_s : Tmax-wt_s+1)'; Tf_s = Ti_s + wt_s-1;
    Time_s = (Ti_s+Tf_s)/2; nt_s = length(Time_s);
    PosDisp = sortrows(PosDisp,ColT);

    Quantities_logI_Staionnarity=zeros(nt_s,nint,9);
    h = waitbar(0,'Processing'); Iti = 1;  Itf = 1;
    for t = 1 : nt_s

        while PosDisp(Iti,ColT) < Ti_s(t) && Iti < size(PosDisp,1)
            Iti = Iti + 1;
        end
        while PosDisp(Itf,ColT) <= Tf_s(t) && Itf < size(PosDisp,1)
            Itf = Itf + 1;
        end
        Itf = Itf - 1;
        PosDisp_loc = PosDisp(Iti:Itf,:);
        
        if isempty(PosDisp_loc) == 0
            
            PosDisp_loc = sortrows(PosDisp_loc,ColInt);

            Iii = 1;
            for i = 1 : nint

                Iif = Iii;
                while PosDisp_loc(Iif,ColInt) < IntLim(i+1) && Iif < size(PosDisp_loc,1)
                    Iif = Iif + 1;
                end
                PosDisp_locTI = PosDisp_loc(Iii:Iif,:);

                Quantities_logI_Staionnarity(t,i,1) = size(PosDisp_locTI,1);
                Quantities_logI_Staionnarity(t,i,2) = mean(PosDisp_locTI(:,ColdX));
                Quantities_logI_Staionnarity(t,i,3) = std(PosDisp_locTI(:,ColdX));
                Quantities_logI_Staionnarity(t,i,4) = mean(PosDisp_locTI(:,ColdY));
                Quantities_logI_Staionnarity(t,i,5) = std(PosDisp_locTI(:,ColdY));
                Quantities_logI_Staionnarity(t,i,6) = mean(PosDisp_locTI(:,ColInt));
                Quantities_logI_Staionnarity(t,i,7) = std(PosDisp_locTI(:,ColInt));
                Quantities_logI_Staionnarity(t,i,8) = mean(PosDisp_locTI(:,ColdInt));
                Quantities_logI_Staionnarity(t,i,9) = std(PosDisp_locTI(:,ColdInt));        
                Iii = Iif;

            end

        else
            Quantities_logI_Staionnarity(t,:,:) = NaN;
        end
        
        waitbar(t/nt_s,h);

    end
    close(h);
    
    % Collect final data for each movie
    TrajectoryAll{n} = Trajectories;
    Disp_X_Y_LogI_TimeStep{n} = Disp_X_Y_LogI_TimeStepOneMovie;
    Npart_TimeStep{n,1} = Npart_TS; Npart_TimeStep{n,2} = MaxNp;
    SizesFrame(n,:) = [nx ny npx npy];
    SpatialDistrib{n,1} = MeanLogIidXdYdlogI; SpatialDistrib{n,2} = StdLogIidXdYdlogI;
    SpatialDistrib{n,3} = NpartXY; SpatialDistrib{n,4} = MeanStdRatio;
    Stationnarity{n,1} = Quantities_logI_Staionnarity;
    Stationnarity{n,2} = Time_s;
    disp(['Movie ' num2str(n) '/' num2str(Nfiles) ' ' FinalSubFolderList{n} ' done'])
    
end
InfosFile = vertcat(InfosFile{:});
TrajectoryAll = vertcat(TrajectoryAll{:,1});

clearvars -except MainFolder ListSubFolders Infos Method_Intensity...
    FolderResults MovieNumbers Nfiles FinalSubFolderList FinalInfos...
    Method_Intensity AngleCorrection MethodInterp TrajectorySelection...
    Ntau_fix Nclass Scales FrameRates InfosFile TrackingParameters...
    MeanStdIntVxVyAll_Repro Disp_X_Y_LogI_TimeStep Npart_TimeStep...
    TrajectoryAll SizesFrame SpatialDistrib Stationnarity SaveFig

%% Optionnal part to save table with trajectories
% Used to compare with simulations
SaveTables = 0;
FormatTables = '.txt';
if SaveTables == 1
    ParamterNames={'n_traj','time_s','x_micron','y_micron','logI','lg_micron'};
    ParameterValues=TrajectoryAll;
    Ttraj=array2table(ParameterValues,'VariableNames',ParamterNames);
    ParamName=['AllTrajectories_' MovieNumbers];
    TableName=[FolderResults filesep ParamName FormatTables];
    writetable(Ttraj,TableName,'Delimiter','\t');
    disp('Trajectories saved!');
end

%% Figure for reproducibility of the mean quantites
scrsz=get(0,'ScreenSize'); % Problems if you change your screen
UnitsSpace='$\mu$m';
UnitsTime='s';
UnitsVelocity=[UnitsSpace '.' UnitsTime '$^{-1}$'];

Fig=figure('name','Reproducibility for different videos','NumberTitle','off');
set(gcf,'Position',scrsz); Legends=cell(Nfiles,1); FontSize=12;
LW=1.5; MS=8; ColorsVideos=jet(Nfiles); FactorAR=4/3;
Rows=[1 2 3]; Cols=[7 2 3 5 6]; row=length(Rows); col=length(Cols);
LabelsAbs=cell(row,1); LabelsAbs{1}='$-\log I_{mg}$'; LabelsAbs{2}='$-\log I_{ig}$'; LabelsAbs{3}='$-\log I_{sp}$';
LabelsOrd=cell(col,1); LabelsOrd{1}='$N_{part}$';
LabelsOrd{2}='$v_{\parallel}$ ($\mu$m\,s$^{-1}$)'; LabelsOrd{3}='$v_{\perp}$ ($\mu$m\,s$^{-1}$)';
LabelsOrd{4}='$D_{\parallel}$ ($\mu$m$^2$\,s$^{-1}$)'; LabelsOrd{5}='$D_{\perp}$ ($\mu$m$^2$\,s$^{-1}$)';
for r=1:row
    for c=1:col
        subplot(row,col,c+(r-1)*col); hold on;
        for i=1:Nfiles
            
            Abs = -MeanStdIntVxVyAll_Repro{i,1}{Rows(r),1}(:,1);
            OrdRaw = MeanStdIntVxVyAll_Repro{i,1}{Rows(r),1}(:,Cols(c));
            Ord = OrdRaw;
            switch c
                case 1
                    Ord = OrdRaw;
                case {2, 3}
                    Ord = OrdRaw*FrameRates(i)/Scales(i);
                case {4, 5}
                    Ord = (OrdRaw/Scales(i)).^2*FrameRates(i)/2;
            end
            plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',ColorsVideos(i,:));

            if i==1
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
            end

            Legends{i}=['Video ' num2str(FinalInfos(i,2))];

        end
        axis([MinAbs MaxAbs MinOrd MaxOrd]);
        Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
        if mod(c,col)==1
            LegendLocation='South';
            leg=legend(Legends{:},'Location',LegendLocation); set(gca,'yscale','lin');
            set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
        end        
        MyFigStyleLaTeXSave(LabelsAbs{r},LabelsOrd{c},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    end
end

if SaveFig==1
    FigName=['Fig1_ReproAD_Videos' MovieNumbers];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Control velocity distribution and tracking parameters
% SaveFig=0;
t=1; % Time step, the first one allows the control of tracking parameters
Fig=figure('name','Global velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); LW=1.5; MS=6; row=1; col=2; Legends=cell(Nfiles,1);
FactorAR=4/3; FontSize=12;
LabelsAbs=cell(2,1); LabelsAbs{1}='$\Delta l_{\parallel}/\tau$ ($\mu$m\,s$^{-1}$)';
LabelsAbs{2}='$\Delta l_{\perp}/\tau$ ($\mu$m\,s$^{-1}$)';
LabelsOrd=cell(2,1); LabelsOrd{1}='$P\left(\Delta l_{\parallel}/\tau\right)$';
LabelsOrd{2}='$P\left(\Delta l_{\perp}/\tau\right)$'; LegendLocation='NorthEast';
for j=1:2
    subplot(row,col,j); hold on;
    for i=1:Nfiles
        
        Tau_frame=Npart_TimeStep{i}(1,t);
        datahist=Disp_X_Y_LogI_TimeStep{i}{t}(:,j+9)/Tau_frame*FrameRates(i)/Scales(i);
        [bin,center]=hist(datahist,fix(sqrt(size(datahist,1))));
        Abs=center; Ord=bin;
    %     Ord=bin/(sum(bin)*mean(diff(Abs)));
        plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',ColorsVideos(i,:));

        if i==1
            MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
        else
            MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
            MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
        end

        Legends{i}=['Video ' num2str(FinalInfos(i,2))];    

    end
    dx=(MaxAbs-MinAbs)*0.1;
    MaxAbs=MaxAbs+dx; MinAbs=MinAbs-dx;
    set(gca,'yscale','log'); axis([MinAbs MaxAbs MinOrd MaxOrd]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    MyFigStyleLaTeXSave(LabelsAbs{j},LabelsOrd{j},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    leg=legend(Legends{:},'Location',LegendLocation); set(gca,'yscale','log');
    set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
        
end

if SaveFig==1
    FigName=['Fig2_ReproPDF-Track_Videos' MovieNumbers];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Figure to ontrol spatial distributions
% SaveFig = 1;
nx = unique(SizesFrame(:,1)); ny = unique(SizesFrame(:,2));
ARfig = nx/ny;
Hfig=scrsz(4)*0.85; Wfig=Nfiles*Hfig*ARfig*0.45;
FontSize=0.016*Hfig; FontSize2=FontSize*0.65;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/3 Wfig Hfig],...
    'menubar','figure','name','SpatialDistribution','numbertitle','off',...
    'resize','off');
set(Fig,'Color',[1 1 1]);

N1=Nfiles; N2=3; AxAll=cell(N2,N1); Hf1=0.25*Hfig; Wf1=Hf1*ARfig; 
Xpos1=linspace(0.08,1-Wf1/Wfig-0.11,N1)*Wfig;
Ypos1=linspace(1-Hf1/Hfig-0.05,0.07,N2)*Hfig;
for i=1:N2
    for j=1:N1
        AxAll{i,j}=axes('Units','pixels','Position',[Xpos1(j) Ypos1(i) Wf1 Hf1]);
    end
end

p = 0.99;
for n = 1 : Nfiles
    
    MeanLogIidXdYdlogI = SpatialDistrib{n,1};
    StdLogIidXdYdlogI = SpatialDistrib{n,2};
    NpartXY = SpatialDistrib{n,3};
    MeanStdRatio = SpatialDistrib{n,4};
    Scale = Scales(n); FrameRate = FrameRates(n);
    
    row=1; col=n; axes(AxAll{row,col});
    Map = NpartXY; List = reshape(Map,[numel(Map) 1 1]);
    LimA = quantile(List,[1-p p]);
    imagesc((1:nx)/Scale,(-1:1)*ny*0.5/Scale,Map,LimA);
    axis([1 nx -ny/2 ny/2]/Scale);
    Title=['$\left<A\right>=' num2str(MeanStdRatio(1,1),3) '$; $\sigma\left(A\right)/\left|A\right|=' num2str(100*MeanStdRatio(1,3),3) '\%$'];
    MyFigureStyle2(0,'$y$ ($\mu$m)',0,Title,0,0,FontSize);
    CB=colorbar; set(CB,'TickLabelInterpreter','latex','FontSize',FontSize);
    ylabel(CB,'$N$','Interpreter','latex','FontSize',FontSize);
    set(CB,'position',[(Xpos1(col)+Wf1)/Wfig+0.01 Ypos1(row)/Hfig 0.1*Wf1/Wfig Hf1/Hfig]);
    set(gca,'xticklabel',[]);
    
    row=2; axes(AxAll{row,col}); i = 1;
    Map = MeanLogIidXdYdlogI(:,:,i); List = reshape(Map,[numel(Map) 1 1]);
    LimA = quantile(List,[1-p p]);
    imagesc((1:nx)/Scale,(-1:1)*ny*0.5/Scale,Map,LimA);
    axis([1 nx -ny/2 ny/2]/Scale);
    Title=['$\left<A\right>=' num2str(MeanStdRatio(i+1,1),3) '$; $\sigma\left(A\right)/\left|A\right|=' num2str(100*MeanStdRatio(i+1,3),3) '\%$'];
    MyFigureStyle2(0,'$y$ ($\mu$m)',0,Title,0,0,FontSize);
    CB=colorbar; set(CB,'TickLabelInterpreter','latex','FontSize',FontSize);
    ylabel(CB,'$\log I_i$','Interpreter','latex','FontSize',FontSize);
    set(CB,'position',[(Xpos1(col)+Wf1)/Wfig+0.01 Ypos1(row)/Hfig 0.1*Wf1/Wfig Hf1/Hfig]);
    set(gca,'xticklabel',[]);
    
    row=3; axes(AxAll{row,col}); i = 2;
    Map = MeanLogIidXdYdlogI(:,:,i)*FrameRate/Scale;
    List = reshape(Map,[numel(Map) 1 1]);
    LimA = quantile(List,[1-p p]);
    imagesc((1:nx)/Scale,(-1:1)*ny*0.5/Scale,Map,LimA);
    axis([1 nx -ny/2 ny/2]/Scale);
    Title=['$\left<A\right>=' num2str(MeanStdRatio(i+1,1),3) '$; $\sigma\left(A\right)/\left|A\right|=' num2str(100*MeanStdRatio(i+1,3),3) '\%$'];
    MyFigureStyle2('$x$ ($\mu$m)','$y$ ($\mu$m)',0,Title,0,0,FontSize);
    CB=colorbar; set(CB,'TickLabelInterpreter','latex','FontSize',FontSize);
    ylabel(CB,'$v_x$ ($\mu$m.s$^{-1}$)','Interpreter','latex','FontSize',FontSize);
    set(CB,'position',[(Xpos1(col)+Wf1)/Wfig+0.01 Ypos1(row)/Hfig 0.1*Wf1/Wfig Hf1/Hfig]);
    
end
colormap jet;

if SaveFig==1
    FigName=['Fig3_SpatialDistrib_Videos' MovieNumbers];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Figure to ontrol stationnariy
% SaveFig = 0;
nx = unique(SizesFrame(:,1)); ny = unique(SizesFrame(:,2));
npx = unique(SizesFrame(:,3)); npy = unique(SizesFrame(:,4));
ARfig = nx/ny;
Wfig = scrsz(3)*0.8; Hfig = Wfig*0.5;
FontSize=0.011*Wfig; FontSize2=FontSize*0.65;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/3 Wfig Hfig],...
    'menubar','figure','name','SpatialDistribution','numbertitle','off',...
    'resize','off');
set(Fig,'Color',[1 1 1]);

N1=2; N2=2; AxAll=cell(N2,N1); Wf1=0.38*Wfig; Hf1=Wf1*0.5; 
Xpos1=linspace(0.08,1-Wf1/Wfig-0.06,N1)*Wfig;
Ypos1=linspace(1-Hf1/Hfig-0.05,0.14,N2)*Hfig;
for i=1:N2
    for j=1:N1
        AxAll{i,j}=axes('Units','pixels','Position',[Xpos1(j) Ypos1(i) Wf1 Hf1]);
    end
end

MS = 0.005*Wfig;
hold(AxAll{1,1},'on'); hold(AxAll{1,2},'on');
hold(AxAll{2,1},'on'); hold(AxAll{2,2},'on');

lim = 0.99;
for n = 1 : Nfiles
    
    Scale = Scales(n); FrameRate = FrameRates(n);
    Time_s = Stationnarity{n,2};
    Quantities_logI_Staionnarity = Stationnarity{n,1};
    Vx_Time=Quantities_logI_Staionnarity(:,:,2)*FrameRate/Scale;
    Vy_Time=Quantities_logI_Staionnarity(:,:,4)*FrameRate/Scale;
    Dx_Time=0.5*Quantities_logI_Staionnarity(:,:,3).^2*FrameRate/Scale^2;
    Dy_Time=0.5*Quantities_logI_Staionnarity(:,:,5).^2*FrameRate/Scale^2;
    
    Tmin_axis=Time_s(1)/FrameRate; Tmax_axis=Time_s(end)/FrameRate;
    
    plot(AxAll{1,1},Time_s/FrameRate,mean(Vx_Time,2),'.-','LineWidth',1,'MarkerSize',MS,'color',ColorsVideos(n,:));
    plot(AxAll{1,2},Time_s/FrameRate,mean(Vy_Time,2),'.-','LineWidth',1,'MarkerSize',MS,'color',ColorsVideos(n,:));
    plot(AxAll{2,1},Time_s/FrameRate,mean(Dy_Time,2),'.-','LineWidth',1,'MarkerSize',MS,'color',ColorsVideos(n,:));
    plot(AxAll{2,2},Time_s/FrameRate,mean(Dx_Time,2),'.-','LineWidth',1,'MarkerSize',MS,'color',ColorsVideos(n,:));
    
end

hold(AxAll{1,1},'off'); hold(AxAll{1,2},'off');
hold(AxAll{2,1},'off'); hold(AxAll{2,2},'off');

axes(AxAll{1,1}); set(AxAll{1,1},'xticklabel',[]);
MyFigureStyle2(0,'$\left<v_x\right>_{\log I}$ ($\mu$m\,s$^{-1}$)',0,0,0,0,FontSize);
axes(AxAll{1,2}); set(AxAll{1,2},'xticklabel',[]);
MyFigureStyle2(0,'$\left<v_y\right>_{\log I}$ ($\mu$m\,s$^{-1}$)',0,0,0,0,FontSize);
axes(AxAll{2,1});
MyFigureStyle2('$t$ (s)','$\left<D_x\right>_{\log I}$ ($\mu$m$^2$\,s$^{-1}$)',0,0,0,0,FontSize);
axes(AxAll{2,2});
MyFigureStyle2('$t$ (s)','$\left<D_y\right>_{\log I}$ ($\mu$m$^2$\,s$^{-1}$)',0,0,0,0,FontSize);

if SaveFig==1
    FigName=['Fig4_Stationnarity_Videos' MovieNumbers];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Concatenation and determination of a maximal time step
% The value of Ntau will depend of video number and particle concentration
% SaveFig = 0;
FrameRate=unique(FrameRates); Scale=unique(Scales);
ListVideo=(1:Nfiles)'; nl=length(ListVideo);
MaxNpartTot=max(vertcat(Npart_TimeStep{ListVideo,2}));
NpartAll=zeros(Nfiles,MaxNpartTot,3);
for i=1:Nfiles
    
    Npart=Npart_TimeStep{i,1}; cmax=Npart_TimeStep{i,2};
    for j=1:4
        NpartAll(i,1:cmax,j)=Npart(1+j,:);
    end
        
end
NpartTotal=zeros(MaxNpartTot,5);
NpartTotal(:,1)=(1:MaxNpartTot)'/unique(FrameRates);
NpartTotal(:,2)=sum(NpartAll(:,:,1),1);
for i=1:3
    NpartTotal(:,2+i)=sum(NpartAll(:,:,1).*NpartAll(:,:,1+i),1)./sum(NpartAll(:,:,1),1);
end

I1=3; I2=10; CoefFit_Npart=polyfit(NpartTotal(I1:I2,1),log(NpartTotal(I1:I2,2)),1);
Npart_TS_Fit=exp(NpartTotal(:,1)*CoefFit_Npart(1)+CoefFit_Npart(2));
LimitFit=2; % Set limit value
Gap=100*abs(NpartTotal(:,2)-Npart_TS_Fit)./NpartTotal(:,2); Gap(1:I1)=0;
I=find(Gap>=LimitFit); N0=NpartTotal(1,2);

Ntau = 40; % MAX TIME STEP SELECTION
% Ntau=I(1);
Ntau_max = min(cell2mat(Npart_TimeStep(:,2)));
if Ntau > Ntau_max
    disp(['Selected Ntau = ' num2str(Ntau) ' is smaller than Ntau_max = ' num2str(Ntau_max) ' so Ntau --> ' num2str(Ntau_max)]);
    Ntau = Ntau_max;
end

Nmin=NpartTotal(Ntau,2); TSmax=NpartTotal(Ntau,1);

Wfig=scrsz(3)*0.9; Hfig=Wfig*0.4; FontSize=22; LW1=1; MS1=12; LW2=3;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Maximal time step','numbertitle','off',...
    'resize','off');

n1=2; AxAll=cell(n1,1); Wf1=0.4*Wfig; Hf1=Wf1*3/4;
Ypos1=0.18*Hfig; Xpos1=linspace(0.08,1-Wf1/Wfig-0.03,n1)*Wfig;
for i=1:n1
    AxAll{i}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
end

axes(AxAll{1}); hold on;
plot(1e3*NpartTotal(:,1),NpartTotal(:,2),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(1e3*NpartTotal(:,1),Npart_TS_Fit,'-','LineWidth',LW2,'color','black');
hold off; set(gca,'yscale','log');
axis([0 1e3*MaxNpartTot/FrameRate min(NpartTotal(:,2)) N0]); Ax=axis;
line([Ax(3) Ax(4)],Nmin*[1 1],'LineStyle','--','LineWidth',LW2*2/3,'color','black');
line(1e3*TSmax*[1 1],[Ax(3) Ax(4)],'LineStyle','--','LineWidth',LW2*2/3,'color','black');
MyFigureStyle('$\tau$ (ms)','$N_p$',0,0,0,0,FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Nmin,['$N_{min}=' num2str(round(Nmin)) '$'],...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1)+(Ax(2)-Ax(1))*0.05,Nmin,['$e<' num2str(Gap(Ntau),3) '\%$'],...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
text(1e3*TSmax,Ax(3),['$T_{max}=' num2str(1e3*TSmax,3) '$ ms'],...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','rotation',90);
text(1e3*TSmax,Ax(4),['$N_\tau=' num2str(Ntau) '$ frames'],...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');

axes(AxAll{2}); hold on;
plot(1e3*NpartTotal(:,1),NpartTotal(:,3),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor','b','MarkerEdgeColor','black');
plot(1e3*NpartTotal(:,1),NpartTotal(:,4),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor',[0 0.5 0],'MarkerEdgeColor','black');
plot(1e3*NpartTotal(:,1),NpartTotal(:,5),'o','LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor','r','MarkerEdgeColor','black');
hold off; OrdAll=[NpartTotal(:,3);NpartTotal(:,4);NpartTotal(:,5)];
axis([0 1e3*MaxNpartTot/FrameRate min(OrdAll) max(OrdAll)]); Ax=axis;
line(1e3*TSmax*[1 1],[Ax(3) Ax(4)],'LineStyle','--','LineWidth',LW2*2/3,'color','black');
MyFigureStyle('$\tau$ (ms)','$\left<\log I\right>$',0,0,0,0,FontSize);
leg=legend('$\log I_\mathrm{initial}$','$\frac{1}{2}\left(\log I_\mathrm{initial}+\log I_\mathrm{final}\right)$',...
    '$\frac{1}{N+1}\sum\limits_{i=1}^{N+1} \log I_i$','Location','NorthWest','Orientation','vertical');
set(leg,'Interpreter','Latex','box','off','FontSize',FontSize*0.8);

if SaveFig==1
    FigName = 'Fig5_MaxTimeStep_Lim';
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Displacement oncatenation for files selected and maximal time step
% Select carefully Ntau before to run this part
Disp_X_Y_LogI_TimeStepTotal=cell(1,Ntau);
for t=1:Ntau
    Disp_X_Y_LogI_TimeStepLoc=cell(nl,1);
    for i=1:nl
        Disp_X_Y_LogI_TimeStepLoc{i}=Disp_X_Y_LogI_TimeStep{ListVideo(i)}{t};
    end
    Disp_X_Y_LogI_TimeStepTotal{t}=vertcat(Disp_X_Y_LogI_TimeStepLoc{:});
end
clear Disp_X_Y_LogI_TimeStepLoc Disp_X_Y_LogI_TimeStep

%% Global velocity profiles
% SaveFig = 0;
Fig=figure('name','Global velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); LegendLocation='South';
index=round(linspace(1,Ntau,4)); n=length(index); FontSize=10;
Legends=cell(n,1); FactorAR=4/3; row=2; col=3; LW=1.5; MS=5;
Colors=[linspace(1,0,n)' zeros(n,1) linspace(0,1,n)'];
TS = 1; Neff = fix(sqrt(size(Disp_X_Y_LogI_TimeStepTotal{TS},1)));
GlobalPDF=zeros(Neff,9);

LabelsAbs=cell(3,1); LabelsAbs{1}=['$\Delta x$ (' UnitsSpace ')'];
LabelsAbs{2}=['$\Delta y$ (' UnitsSpace ')']; LabelsAbs{3}=['$\Delta \log I$'];
LabelsOrd=cell(3,1); LabelsOrd{1}='$P\left(\Delta x\right)$';
LabelsOrd{2}='$P\left(\Delta y\right)$'; LabelsOrd{3}='$P\left(\Delta\log I\right)$';
for p = 1 : 3
    
    subplot(row,col,p); hold on;
    for l=1:n
        i = index(l);
        if p < 3
            data=Disp_X_Y_LogI_TimeStepTotal{i}(:,p+9)/Scale;
        elseif p == 3
            data=Disp_X_Y_LogI_TimeStepTotal{i}(:,p+9);
        end
        [bin,center]=hist(real(data),Neff);
        Abs=center;
        Ord=bin/(sum(bin)*mean(diff(Abs)));
        plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(l,:));
        Legends{l}=['$\tau=' num2str(NpartTotal(i,1)*1e3) '$ ms'];
        
        if i == TS
            GlobalPDF(:,1+(p-1)*3:3*p)=[center' bin' Ord'];
        end
        
        if l==1
            MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
        else
            MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
            MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
        end
    end
    set(gca,'yscale','log');
    axis([MinAbs MaxAbs MinOrd MaxOrd]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    if p==3
        leg=legend(Legends{:},'Location',LegendLocation);
        set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    end
    MyFigStyleLaTeXSave(LabelsAbs{p},LabelsOrd{p},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    
end

LabelsAbs=cell(3,1);
LabelsAbs{1}=['$\Delta \tilde{l}_{\parallel}=\frac{\Delta l_{\parallel}-\left<\Delta l_{\parallel}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{2}=['$\Delta \tilde{l}_{\perp}=\frac{\Delta l_{\perp}-\left<\Delta l_{\perp}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{3}=['$\Delta \tilde{I}=\frac{\Delta \log I-\left<\log I\right>}{\sqrt{\tau}}$ (' UnitsTime '$^{-1/2}$)'];
LabelsOrd=cell(3,1); LabelsOrd{1}='$P\left(\Delta \tilde{l}_{\parallel}\right)$';
LabelsOrd{2}='$P\left(\Delta \tilde{l}_{\perp}\right)$'; LabelsOrd{3}='$P\left(\Delta \tilde{I}\right)$';
for p=1:3
    
    subplot(row,col,p+3); hold on;
    for l=1:n
        i=index(l);
        data=(Disp_X_Y_LogI_TimeStepTotal{i}(:,p+9)-mean(Disp_X_Y_LogI_TimeStepTotal{i}(:,p+9)))/Scale;
        [bin,center]=hist(real(data),fix(sqrt(length(data))));
        Abs=center/sqrt(NpartTotal(i,1));
        Ord=bin/(sum(bin)*mean(diff(Abs)));
        plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(l,:));
        Legends{l}=['$\tau=' num2str(NpartTotal(i,1)*1e3) '$ ms'];

        if l==1
            MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
        else
            MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
            MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
        end    
    end
    set(gca,'yscale','log');
    axis([MinAbs MaxAbs MinOrd MaxOrd]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
%     if p==3
%         leg=legend(Legends{:},'Location',LegendLocation);
%         set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
%     end
    MyFigStyleLaTeXSave(LabelsAbs{p},LabelsOrd{p},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    
end

if SaveFig==1
    FigName=['Fig6_GlobalPDF_disp'];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Global standard deviation and diffusion
% SaveFig = 0;
% STD calculations
GlobalSTD_TimeStep=zeros(Ntau,5);
GlobalSTD_TimeStep(:,1:2)=NpartTotal(1:Ntau,1:2);
for t=1:Ntau
    GlobalSTD_TimeStep(t,3)=std(Disp_X_Y_LogI_TimeStepTotal{t}(:,10))/Scale;
    GlobalSTD_TimeStep(t,4)=std(Disp_X_Y_LogI_TimeStepTotal{t}(:,11))/Scale;
    GlobalSTD_TimeStep(t,5)=std(Disp_X_Y_LogI_TimeStepTotal{t}(:,12));
end

% Fit in log log
FactorNpart=5;
Coefs_GlobalSTD=zeros(3,2); IndexFit=zeros(3,1);
for d=1:3
    I=find(GlobalSTD_TimeStep(:,2)>=GlobalSTD_TimeStep(1,2)/FactorNpart);
    p=polyfit(log(GlobalSTD_TimeStep(I,1)),log(GlobalSTD_TimeStep(I,2+d)),1);
    Coefs_GlobalSTD(d,:)=p; IndexFit(d)=max(I);
end

% Fit perpendicular diffusion
DyEq=@(C,x)C(1)*(1-exp(-(x-C(3))/C(2)));
D0=exp(Coefs_GlobalSTD(2,2))^2/2; Tau=0.25^2/D0; t0=NpartTotal(1,1);
C0=[D0 Tau t0]; Cinf=[0 0 t0-Tau]; Csup=[2*D0 10*Tau t0+Tau];
Abs=GlobalSTD_TimeStep(:,1); Ord=GlobalSTD_TimeStep(:,4).^2./(2*GlobalSTD_TimeStep(:,1));
C=lsqcurvefit(DyEq,C0,Abs(1:IndexFit(2)),Ord(1:IndexFit(2)),Cinf,Csup);
DyInf=C(1); Tp=5*(C(2)-0);
[Cinf;C0;C;Csup]
% Plateau parallel diffusion
[~,I1]=min(abs(Abs-Tp)); I2=IndexFit(1);
if I2 > Ntau
    I2=Ntau;
end
if I1 >= I2
    I1=I2-1;
    disp('check your fit on Dy to get the plateau on Dx');
end
DxInf=mean(GlobalSTD_TimeStep(I1:I2,3).^2./(2*GlobalSTD_TimeStep(I1:I2,1)));

% Figure
n1=3; AR=4/3; Wfig=scrsz(3)*0.95; Hfig=1.1*Wfig/AR/n1;
FontSize=0.011*Wfig; LW1=1; MS1=10; LW2=3; MS2=8;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Maximal time step','numbertitle','off',...
    'resize','off');
set(Fig,'Color',[1 1 1]);

LabelsOrd=cell(3,1); LabelsOrd{1}='x';
LabelsOrd{2}='y'; LabelsOrd{3}='\log I';
Units = cell(3,2); Units{1,1} = '($\mu$m)'; Units{2,1} = '($\mu$m)';
Units{1,3} = ''; Units{1,2} = '($\mu$m$^2$.s$^{-1}$)';
Units{2,2} = '($\mu$m$^2$.s$^{-1}$)'; Units{3,2} = '(s$^{-1}$)';
AxAll=cell(n1,2); Wf1=(1/(n1+1))*Wfig; Hf1=Wf1/AR;
Ypos1=0.2*Hfig; Xpos1=linspace(0.08,1-Wf1/Wfig-0.03,n1)*Wfig;
ri=0.4; Wf2=ri*Wf1; Hf2=ri*Hf1; FontSize2=FontSize*ri*2;
for i=1:n1
    AxAll{i,1}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
    AxAll{i,2}=axes('Units','pixels','Position',[Xpos1(i)+0.98*Wf1-Wf2 Ypos1+0.02*Hf1 Wf2 Hf2],...
        'XAxisLocation','top','YAxisLocation','left','Color','none');
end

for i=1:n1
    
    axes(AxAll{i,1});
    Abs=GlobalSTD_TimeStep(:,1); Ord=GlobalSTD_TimeStep(:,2+i);
    plot(Abs,Ord,'o',...
        'LineWidth',LW1,'MarkerSize',MS1,'MarkerFaceColor','r','MarkerEdgeColor','black');
    set(gca,'xscale','log','yscale','log');
    dy=(max(Ord)-min(Ord))*0;
    axis([min(Abs) max(Abs) min(Ord)-dy max(Ord)+dy]); Ax=axis;
    if i < 3
        hold on; AbsFit=linspace(min(Abs),max(Abs),50)';
        p=Coefs_GlobalSTD(i,:); OrdFit=exp(p(2))*AbsFit.^(p(1));
        plot(AbsFit,OrdFit,'-','LineWidth',LW2,'color','black');
        xi=Abs(1); xf=Abs(IndexFit(i)); yi=exp(p(2))*xi.^(p(1)); yf=exp(p(2))*xf.^(p(1));
        Xp=[xi xf xf xi]; Yp=[yi yf Ax(4) Ax(4)];
        hold on; fill(Xp,Yp,'g','LineStyle','none'); alpha(0.2); hold off;
    end
    MyFigureStyle2('$\tau$ (s)',['$\sigma_{' LabelsOrd{i} '}$ ' Units{i,1}],0,0,0,0,FontSize);
    if i < 3
        text(0.02,0.95,'$\sigma=A\tau^n$ ; $D=A^2/2$','Units','normalized',...
            'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
        text(0.02,0.85,['$n=' num2str(p(1),3) '$'],'Units','normalized',...
            'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
        text(0.02,0.75,['$D_' LabelsOrd{i} '=' num2str(exp(p(2))^2/2,3) '$ $\mu$m$^2$.s$^{-1}$'],'Units','normalized',...
            'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
    end
    
    axes(AxAll{i,2});
    Abs=GlobalSTD_TimeStep(:,1); Ord=GlobalSTD_TimeStep(:,2+i).^2./(2*GlobalSTD_TimeStep(:,1));
    plot(Abs,Ord,'o',...
        'LineWidth',LW1,'MarkerSize',MS2,'MarkerFaceColor','b','MarkerEdgeColor','black');
    dy=(max(Ord)-min(Ord))*0.2;
    axis([min(Abs) max(Abs) min(Ord)-dy max(Ord)+dy]); Ax=axis;
    if i == 1
        xi=Abs(I1); xf=Abs(I2);
        line([Ax(1) Ax(2)],DxInf*[1 1],'LineWidth',LW2,'color','black');
        text(0.98,0.05,['$D_' LabelsOrd{i} '^\infty=' num2str(DxInf,3) '$ $\mu$m$^2$.s$^{-1}$'],'Units','normalized',...
            'FontSize',FontSize2*0.8,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
    elseif i == 2
        xi=Abs(1); xf=Abs(IndexFit(i));
        AbsFit=linspace(min(Abs),max(Abs),50)';
        OrdFit=DyEq(C,AbsFit);
        hold on; plot(AbsFit,OrdFit,'-','LineWidth',LW2,'color','black');
        text(0.98,0.05,['$D_' LabelsOrd{i} '^\infty=' num2str(DyInf,3) '$ $\mu$m$^2$.s$^{-1}$'],'Units','normalized',...
            'FontSize',FontSize2*0.8,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
    end
    if i < 3
        Xp=[xi xf xf xi]; Yp=[Ax(3) Ax(3) Ax(4) Ax(4)];
        hold on; fill(Xp,Yp,'g','LineStyle','none'); alpha(0.2); hold off;
    end
    MyFigureStyle2('$\tau$ (s)',['$D_{' LabelsOrd{i} '}$ ' Units{i,2}],0,0,0,0,FontSize2);
    set(gca,'XAxisLocation','top');
    
end

if SaveFig==1
    FigName=['Fig7_Diffusion_GlobalSTD_' num2str(FactorNpart)];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Mean quantity calculation for several time steps
Nclass=20; Treshold=0.999; FactorPDF=2;
ListColMean=[1 2 3;4 5 6;7 8 9]; nc=size(ListColMean,2);
ColX=1; ColY=2; ColInt=3; ColdX=4; ColdY=5; ColdInt=6;
MeanStd_MeanDisp_TimeStep=cell(nc,1);
PDFsloc_X_TimeStep=cell(nc,1); PDFsloc_dX_TimeStep=cell(nc,1);
PDFsloc_Y_TimeStep=cell(nc,1); PDFsloc_dY_TimeStep=cell(nc,1);
PDFsloc_Int_TimeStep=cell(nc,1); PDFsloc_dInt_TimeStep=cell(nc,1);
for c=1:nc
    
    MeanSt_MeanDisp=zeros(Nclass-1,13,Ntau);
    PDFsloc_dX_TimeStep{c}=cell(Nclass,Ntau);
    for t=1:Ntau
        
        MeanDisp=Disp_X_Y_LogI_TimeStepTotal{t}(:,[ListColMean(c,:) 10 11 12]);
                
        MeanDisp=sortrows(MeanDisp,ColInt);
        [Iinf,Isup]=Decil(MeanDisp(:,ColInt),1-Treshold,Treshold);
        IntLim=linspace(Iinf,Isup,Nclass+1); IntLim(end)=Isup;
                
        [~,linf]=min(abs(MeanDisp(:,ColInt)-IntLim(1)));
        for i=1:Nclass

            lsup=linf;
            while MeanDisp(lsup,ColInt)<IntLim(i+1)
                lsup=lsup+1;
            end
            
            MeanSt_MeanDisp(i,1,t)=lsup-linf+1;
            MeanSt_MeanDisp(i,2,t)=mean(MeanDisp(linf:lsup,ColX));
            MeanSt_MeanDisp(i,3,t)=std(MeanDisp(linf:lsup,ColX));
            MeanSt_MeanDisp(i,4,t)=mean(MeanDisp(linf:lsup,ColdX));
            MeanSt_MeanDisp(i,5,t)=std(MeanDisp(linf:lsup,ColdX));
            MeanSt_MeanDisp(i,6,t)=mean(MeanDisp(linf:lsup,ColY));
            MeanSt_MeanDisp(i,7,t)=std(MeanDisp(linf:lsup,ColY));
            MeanSt_MeanDisp(i,8,t)=mean(MeanDisp(linf:lsup,ColdY));
            MeanSt_MeanDisp(i,9,t)=std(MeanDisp(linf:lsup,ColdY));
            MeanSt_MeanDisp(i,10,t)=mean(MeanDisp(linf:lsup,ColInt));
            MeanSt_MeanDisp(i,11,t)=std(MeanDisp(linf:lsup,ColInt));
            MeanSt_MeanDisp(i,12,t)=mean(MeanDisp(linf:lsup,ColdInt));
            MeanSt_MeanDisp(i,13,t)=std(MeanDisp(linf:lsup,ColdInt));
            
            data=MeanDisp(linf:lsup,ColX);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_X_TimeStep{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColdX);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_dX_TimeStep{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColY);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_Y_TimeStep{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColdY);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_dY_TimeStep{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColInt);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_Int_TimeStep{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            data=MeanDisp(linf:lsup,ColdInt);
            [counts,centers] = hist(data,fix(sqrt(length(data))/FactorPDF));
            FactorNorm=sum(counts)*mean(diff(centers));
            PDFsloc_dInt_TimeStep{c}{i,t}=[centers' counts' counts'/FactorNorm];
            
            linf=lsup;

        end

        MeanStd_MeanDisp_TimeStep{c}=MeanSt_MeanDisp;
        
    end
    
end

%% Figure for local displacement distribution at all z-positions for few time steps
% SaveFig = 0;
c = 1; ModeI = 'initial';
% c = 2; ModeI = 'if';
% c = 3; ModeI = 'mean';
Index_TS=[1 4 10]; n=length(Index_TS); Treshold=0.99;
[Mindl,Maxdl]=Decil(Disp_X_Y_LogI_TimeStepTotal{1}(:,3),1-Treshold,Treshold);
Nv=NpartTotal(1,2); Scale_LogI=linspace(Mindl,Maxdl,round(Nv))';
ColorsLogI=[linspace(0,74/255,round(Nv))' linspace(0,1,round(Nv))' zeros(round(Nv),1)];

LabelsAbs=cell(3,1);
LabelsAbs{1}=['$\Delta \tilde{x}=\left(\Delta x-\left<\Delta x\right>\right)/\sqrt{\tau}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{2}=['$\Delta \tilde{y}=\left(\Delta y-\left<\Delta y\right>\right)/\sqrt{\tau}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{3}=['$\Delta \tilde{I}=\left(\Delta \log I-\left<\Delta \log I\right>\right)/\sqrt{\tau}$ (' UnitsTime '$^{-1/2}$)'];
LabelsOrd=cell(3,1); LabelsOrd{1}='$P\left(\Delta \tilde{x}\right)$';
LabelsOrd{2}='$P\left(\Delta \tilde{y}\right)$'; LabelsOrd{3}='$P\left(\Delta \tilde{I}\right)$';
LabelsInt = cell(3,1); LabelsInt{1} = '$\log I_{i}$';
LabelsInt{2} = '$\left(\log I_{i}+\log I_{f}\right)/2$'; LabelsInt{3} = '$\left<\log I\right>$';

Fig=figure('name','Velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); row=3; col=n; FontSize=12; FactorAR=5/3; LW=1; MS=5;
for i=1:n
    t=Index_TS(i);
    for d=1:3
        subplot(row,col,i+col*(d-1)); k=0; hold on;
        for z=1:Nclass
            if d == 1
                Abs=(PDFsloc_dX_TimeStep{c}{z,t}(:,1)-MeanStd_MeanDisp_TimeStep{c}(z,4,t))/(Scale*sqrt(NpartTotal(t,1)));
                Ord=PDFsloc_dX_TimeStep{c}{z,t}(:,3)*Scale*sqrt(NpartTotal(t,1));
            elseif d == 2
                Abs=(PDFsloc_dY_TimeStep{c}{z,t}(:,1)-MeanStd_MeanDisp_TimeStep{c}(z,8,t))/(Scale*sqrt(NpartTotal(t,1)));
                Ord=PDFsloc_dY_TimeStep{c}{z,t}(:,3)*Scale*sqrt(NpartTotal(t,1));
            elseif d == 3
                Abs=(PDFsloc_dInt_TimeStep{c}{z,t}(:,1)-MeanStd_MeanDisp_TimeStep{c}(z,12,t))/sqrt(NpartTotal(t,1));
                Ord=PDFsloc_dInt_TimeStep{c}{z,t}(:,3)*sqrt(NpartTotal(t,1));
            end
            
            if length(Abs)>4
                [~,I]=min(abs(Scale_LogI(:,1)-MeanStd_MeanDisp_TimeStep{c}(z,10,t)));
                plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
                if k==0
                    MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
                else
                    MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                    MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
                end
                k=k+1;
            end
        end
        % MinAbs=-MaxAbsFix; MaxAbs=MaxAbsFix;
        set(gca,'yscale','log'); colormap(ColorsLogI);
        MaxAbs=min(abs(MinAbs),MaxAbs); MinAbs=-MaxAbs;
        axis([MinAbs MaxAbs MinOrd MaxOrd]);
        Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; caxis([Mindl Maxdl]);
        MyFigStyleLaTeXSave(LabelsAbs{d},LabelsOrd{d},0,['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'],1,LabelsInt{c},[1 FactorAR*AR 1],FontSize);
    end
end

Index_TS_str=num2str(Index_TS); Index_TS_str(Index_TS_str==' ')=[];
if SaveFig==1
    FigName=['Fig8_PDF_allZ_I' ModeI '_IndTS' Index_TS_str '_' MovieNumbers];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Angle control
% SaveFig = 0;
if AngleCorrection == 1
    Title='With angle correction';
elseif AngleCorrection == 0
    Title='Without angle correction';
end

t=1; c=3; ExpPe=2; Lc=100e-3; % Characteristic Length = particle diameter
Fig=figure('name','Velocity profiles','NumberTitle','off');
FactorAR=4/3; FontSize=12; Colors=jet(Nfiles);
set(gcf,'Position',scrsz); row=2; col=3; LW=1.5; MS=8;

CoefsFits_VxLogIm=zeros(Nfiles+1,3);
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    SignV=sign(mean(MeanStdIntVxVyAll_Repro{i,1}{Rows(r),1}(:,2)));
    LogIm=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Vx=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,2)*SignV*FrameRates(i)/Scales(i);
    Npart=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,7);
    p=polyfitweighted(LogIm,Vx,1,sqrt(Npart));
    CoefsFits_VxLogIm(i,:)=[p -p(2)/p(1)];
    
end
LogIm=MeanStd_MeanDisp_TimeStep{c}(:,10,1);
Vx=MeanStd_MeanDisp_TimeStep{c}(:,4,1)/Scale/NpartTotal(t,1);
Npart=MeanStd_MeanDisp_TimeStep{c}(:,1,1);
p=polyfitweighted(LogIm,Vx,1,sqrt(Npart));
CoefsFits_VxLogIm(end,:)=[p -p(2)/p(1)];

subplot(row,col,1); hold on; Col=2;
LogIm0m=CoefsFits_VxLogIm(end,3);
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    SignV=sign(mean(MeanStdIntVxVyAll_Repro{i,1}{Rows(r),1}(:,Col)));
    LogIm=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    LogIm0=CoefsFits_VxLogIm(i,3);
    Abs = -LogIm;
    Ord = MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)*SignV*FrameRates(i)/Scales(i);
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));

    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
    p=CoefsFits_VxLogIm(i,1:2);
    LogImFit=linspace(min(LogIm),LogIm0,50); OrdFit=polyval(p,LogImFit);
    AbsFit=LogIm0m-LogImFit;
    plot(AbsFit,OrdFit,'-','LineWidth',LW,'color',Colors(i,:));

end
Abs = -MeanStd_MeanDisp_TimeStep{c}(:,10,1);
Ord = MeanStd_MeanDisp_TimeStep{c}(:,4,1)/Scale/NpartTotal(t,1);
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
% MinAbs=0; MinOrd=0;
p=CoefsFits_VxLogIm(end,1:2);
LogImFit=linspace(min(LogIm),LogIm0m,50); OrdFit=polyval(p,LogImFit);
AbsFit = -LogImFit;
plot(AbsFit,OrdFit,'-','LineWidth',LW,'color','black');
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$v_{\parallel}$ (' UnitsVelocity ')'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,2); hold on; Col=3;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    Abs = -MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord = MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)*FrameRates(i)/Scales(i);
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));

    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end

end
Ord=MeanStd_MeanDisp_TimeStep{c}(:,8,1)/Scale/NpartTotal(t,1);
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$v_{\perp}$ (' UnitsVelocity ')'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
title(Title,'Interpreter','none','FontName','Times New Roman');
subplot(row,col,[3 6]); Legends=cell(Nfiles+1,1); hold on; Col=7;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    Abs = -MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord = MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)/max(MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col));
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
    Legends{i}=['$N_{max}=' num2str(round(max(MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)))) '$'];
    
    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end

end
Ord=MeanStd_MeanDisp_TimeStep{c}(:,1,1)/max(MeanStd_MeanDisp_TimeStep{c}(:,1,1));
Legends{end}=['$N_{max}=' num2str(round(max(MeanStd_MeanDisp_TimeStep{c}(:,1,1)))) '$'];
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$','$N/N_{max}$',0,0,0,0,[1 FactorAR*AR 1],FontSize);
leg=legend(Legends{:},'Location','South','Orientation','vertical');
set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
subplot(row,col,4); hold on; Col=5;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    Abs = -MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord = (MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)/Scales(i)).^2*FrameRates(i)/2;
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));

    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end

end
Ord = (MeanStd_MeanDisp_TimeStep{c}(:,5,1)/Scale).^2/(2*NpartTotal(t,1));
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$D_{\parallel}$ ($\mu$m$^2$.s$^{-1}$)'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,5); hold on; Col=6;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    Abs = -MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord = (MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)/Scales(i)).^2*FrameRates(i)/2;
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));

    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end

end
Ord=(MeanStd_MeanDisp_TimeStep{c}(:,9,1)/Scale).^2/(2*NpartTotal(t,1));
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$D_{\perp}$ ($\mu$m$^2$.s$^{-1}$)'],0,0,0,0,[1 FactorAR*AR 1],FontSize);

if SaveFig==1
    FigName=['Fig9_AngleControl'];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Particle distribution for <log I> and log Iinitial
MethodFit='weighted'; % 'weighted' or 'roi'
Colors=[linspace(1,0,Ntau)' zeros(Ntau,1) linspace(0,1,Ntau)'];

% SaveFig = 0;
n1=2; AR=4/3; Wfig=scrsz(3)*0.95; Hfig=1.1*Wfig/AR/n1; FontSize=0.013*Wfig; LW1=1; MS1=12; LW2=3;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Maximal time step','numbertitle','off',...
    'resize','off');

AxAll=cell(n1,1); Wf1=0.39*Wfig; Hf1=Wf1/AR;
ri=0.3; Wf2=ri*Wf1; Hf2=ri*Hf1; MS2=10; FontSize2=FontSize*0.7;
Ypos1=0.18*Hfig; Xpos1=linspace(0.08,1-Wf1/Wfig-0.03,n1)*Wfig;
for i=1:n1
    AxAll{i,1}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
    AxAll{i,2}=axes('Units','pixels','Position',[Xpos1(i)+0.1*Wf1 Ypos1+0.1*Hf1 Wf2 Hf2]);
end

c=1;
axes(AxAll{1,1}); hold on;
for t=1:Ntau
    
    Abs=MeanStd_MeanDisp_TimeStep{c}(:,10,t);
    Ord=MeanStd_MeanDisp_TimeStep{c}(:,1,t)/NpartTotal(t,2);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]);
caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
hold off; colormap(Colors);
MyFigureStyle('$\log I$','$N$',0,0,1,'$\tau$ (ms)',FontSize);
text(0.02,0.98,'$\log I=\log I_\mathrm{initial}$','Units','normalized',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
DeltaLogI=MaxAbs-MinAbs;
text(0.5,0.1,['$\Delta\log I=' num2str(DeltaLogI,3) '$'],'Units','normalized',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');

c=3;
CoefsFitsVpara_TS=zeros(Ntau,7);
axes(AxAll{2,1}); hold on;
for t=1:Ntau
        
    if strcmpi(MethodFit,'weighted')==1
        N=MeanStd_MeanDisp_TimeStep{c}(:,1,t); Nmax=max(N);
        I=find(N>0.0*Nmax);
        Abs=MeanStd_MeanDisp_TimeStep{c}(:,10,t);
        Ord=MeanStd_MeanDisp_TimeStep{c}(:,4,t)/Scale/NpartTotal(t,1);
%         Weigth=sqrt(N)./MeanStd_MeanDisp_TimeStep{c}(:,5,t);
        Weigth=sqrt(N);
        p=polyfitweighted(Abs(I),Ord(I),1,Weigth(I));
    elseif strcmpi(MethodFit,'roi')==1
        LogI=MeanStd_MeanDisp_TimeStep{c}(:,10,t);
        I=find(LogI>=LogIi & LogI<=LogIf);
        Abs=MeanStd_MeanDisp_TimeStep{c}(:,10,t);
        Ord=MeanStd_MeanDisp_TimeStep{c}(:,4,t)/Scale/NpartTotal(t,1);
        p=polyfit(Abs(I),Ord(I),1);
    end
    OrdFit=polyval(p,Abs);
    CoefsFitsVpara_TS(t,1:4)=[NpartTotal(t,1) p corr2(Ord,OrdFit)];
    plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
    plot(Abs,OrdFit,'-','LineWidth',LW,'color',Colors(t,:));

    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]);
caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; colormap(Colors);
MyFigureStyle('$\log I$',['$v_{\parallel}$ (' UnitsVelocity ')'],0,0,1,'$\tau$ (ms)',FontSize);
text(0.95,0.95,'$\log I=\frac{1}{N+1}\sum\limits_{i=1}^{N+1} \log I_i$','Units','normalized',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');

axes(AxAll{2,2});
plot(CoefsFitsVpara_TS(:,1)*1e3,-CoefsFitsVpara_TS(:,2),'o','LineWidth',LW1,'MarkerSize',MS2,...
    'MarkerFaceColor',[0 0.5 0],'MArkerEdgeColor','black');
MyFigureStyle(0,0,0,0,0,0,FontSize2);
text(0.5,0.95,'$\tau$ (ms)','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','top');
text(0.95,0.5,'$\partial_{\log I}v_x$)','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom','rotation',90);

if SaveFig==1
    FigName='Fig10_PDFsLogIi_Vx';
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Diffusion coefficients for log initial
Colors=[linspace(1,0,Ntau)' zeros(Ntau,1) linspace(0,1,Ntau)'];

% SaveFig = 0;
n1=2; AR=4/3; Wfig=scrsz(3)*0.95; Hfig=1.1*Wfig/AR/n1; FontSize=0.013*Wfig; LW1=1; MS1=12; LW2=3;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Maximal time step','numbertitle','off',...
    'resize','off');

AxAll=cell(n1,1); Wf1=0.39*Wfig; Hf1=Wf1/AR;
ri=0.3; Wf2=ri*Wf1; Hf2=ri*Hf1; MS2=10; FontSize2=FontSize*0.7;
Ypos1=0.18*Hfig; Xpos1=linspace(0.08,1-Wf1/Wfig-0.03,n1)*Wfig;
for i=1:n1
    AxAll{i,1}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
%     AxAll{i,2}=axes('Units','pixels','Position',[Xpos1(i)+0.1*Wf1 Ypos1+0.1*Hf1 Wf2 Hf2]);
end

c=1;
axes(AxAll{1,1}); hold on;
for t=1:Ntau
    
    N=MeanStd_MeanDisp_TimeStep{c}(:,1,t); Nmax=max(N);
    I=find(N>0.1*Nmax);
    Abs=MeanStd_MeanDisp_TimeStep{c}(I,10,t);
    Ord=(MeanStd_MeanDisp_TimeStep{c}(I,9,t)/Scale).^2/(2*NpartTotal(t,1));
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]);
caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; colormap(Colors);
MyFigureStyle('$\log I$','$D_y$ ($\mu$m$^2$.s$^{-1}$)',0,0,1,'$\tau$ (ms)',FontSize);
text(0.05,0.05,'$\log I=\log I_\mathrm{initial}$','Units','normalized',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom');

Dx_Z_Inf=zeros(Ntau,3);
axes(AxAll{2,1}); hold on;
for t=1:Ntau
    
    N=MeanStd_MeanDisp_TimeStep{c}(:,1,t); Nmax=max(N);
    I=find(N>0.1*Nmax);
    Abs=MeanStd_MeanDisp_TimeStep{c}(I,10,t);
    Ord=(MeanStd_MeanDisp_TimeStep{c}(I,5,t)/Scale).^2/(2*NpartTotal(t,1));
    if length(Ord) >= 4
        Dx_Z_Inf(t,1)=mean(Ord(1:4));
    else
        Dx_Z_Inf(t,1) = NaN;
    end
    if length(Ord) >= 10
        Dx_Z_Inf(t,2)=mean(Ord(5:10));
    else
        Dx_Z_Inf(t,2) = NaN;
    end
    I=find(Abs>=5 & Abs<=5.5);
    if isempty(I) == 0
        Dx_Z_Inf(t,3)=mean(Ord(I));
    else
        Dx_Z_Inf(t,3) = NaN;
    end
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]);
caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; colormap(Colors);
MyFigureStyle('$\log I$','$D_x$ ($\mu$m$^2$.s$^{-1}$)',0,0,1,'$\tau$ (ms)',FontSize);
text(0.05,0.05,'$\log I=\log I_\mathrm{initial}$','Units','normalized',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom');

if SaveFig==1
    FigName=['Fig11_DyDxLocalPlateaux_Tmax' num2str(Ntau)];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Local standard deviation from log Iinitial class
ColInt=3; % 3 for log Iinitial 
t=1; % always first time step
Treshold=0.99; NtauFig=Ntau; TiFit=2; TfFit=10;
[Mindl,Maxdl]=Decil(Disp_X_Y_LogI_TimeStepTotal{t}(:,ColInt),1-Treshold,Treshold);
Nv=100; Scale_LogI=linspace(Mindl,Maxdl,round(Nv))';
ColorsLogI=[linspace(0,74/255,round(Nv))' linspace(0,1,round(Nv))' zeros(round(Nv),1)];

% SaveFig = 1;
n1=2; AR=4/3; Wfig=scrsz(3)*0.9; Hfig=1.0*Wfig/AR/n1; FontSize=0.013*Wfig; LW1=1; MS1=12; LW2=3;
Fig = figure('units','pixels','position',[(scrsz(3)-Wfig)/2 (scrsz(4)-Hfig)/2 Wfig Hfig],...
    'menubar','figure','name','Maximal time step','numbertitle','off',...
    'resize','off');

AxAll=cell(n1,3); Wf1=0.35*Wfig; Hf1=Wf1/AR;
ri=0.35; Wf2=ri*Wf1; Hf2=ri*Hf1; MS2=10; FontSize2=FontSize*0.7;
Ypos1=0.18*Hfig; Xpos1=linspace(0.06,1-Wf1/Wfig-0.08,n1)*Wfig;
for i=1:n1
    AxAll{i,1}=axes('Units','pixels','Position',[Xpos1(i) Ypos1 Wf1 Hf1]);
    AxAll{i,2}=axes('Units','pixels','Position',[Xpos1(i)+0.07*Wf1 Ypos1+0.97*Hf1-Hf2 Wf2 Hf2]);
    AxAll{i,3}=axes('Units','pixels','Position',[Xpos1(i)+0.97*Wf1-Wf2 Ypos1+0.07*Hf1 Wf2 Hf2]);
end

c=1; CoefsSTDFit=zeros(Nclass,7);
axes(AxAll{1,1}); hold on;
for z=1:Nclass
    
    Abs=NpartTotal(1:NtauFig,1);
    Ord=reshape(MeanStd_MeanDisp_TimeStep{c}(z,9,1:NtauFig)/Scale,[NtauFig 1 1]);
    LogI=MeanStd_MeanDisp_TimeStep{c}(z,10,1);
    [~,I]=min(abs(Scale_LogI-LogI));
    plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
    
    AbsLog=log(Abs); OrdLog=log(Ord);
    p=polyfit(AbsLog(TiFit:TfFit),OrdLog(TiFit:TfFit),1);
    OrdFit=exp(p(2))*Abs.^p(1);
    CoefsSTDFit(z,1:4)=[LogI p corr2(OrdLog,log(OrdFit))];
    plot(Abs,OrdFit,'-','LineWidth',LW,'color',ColorsLogI(I,:));
    
    if z==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]);
hold off; caxis([Mindl Maxdl]); colormap(ColorsLogI);
set(gca,'xscale','log','yscale','log');
MyFigureStyle('$\tau$ (ms)','$\sigma_y$ ($\mu$m)',0,0,0,0,FontSize);
CB=colorbar; set(CB,'TickLabelInterpreter','latex','FontSize',FontSize);
ylabel(CB,'$\log I_\mathrm{initial}$','Interpreter','latex','FontSize',FontSize);
set(CB,'position',[(Xpos1(1)+Wf1)/Wfig+0.01 Ypos1/Hfig 0.05*Wf1/Wfig Hf1/Hfig]);
% text(0.95,0.95,'$\log I=\log I_\mathrm{initial}$','Units','normalized',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');

axes(AxAll{1,2});
Abs=-CoefsSTDFit(:,1); Ord=CoefsSTDFit(:,2);
plot(Abs,Ord,'o','LineWidth',1,'MarkerSize',MS2,...
    'MarkerFaceColor',[0 0.5 0],'MarkerEdgeColor','black');
MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=0; MaxOrd=1;
axis([MinAbs MaxAbs MinOrd MaxOrd]);
MyFigureStyle(0,0,0,0,0,0,FontSize2);
text(0.5,0.02,'$-\log I$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');
text(0.02,0.98,'$n$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);

axes(AxAll{1,3});
Abs=-CoefsSTDFit(:,1); Ord=exp(CoefsSTDFit(:,3)).^2/2;
plot(Abs,Ord,'o','LineWidth',1,'MarkerSize',MS2,...
    'MarkerFaceColor',[0 0 0.5],'MarkerEdgeColor','black');
C0=[D0 1 min(Abs)+1]; Cinf=[0 0 min(Abs)-5]; Csup=[2*D0 5 min(Abs)+5];
C=lsqcurvefit(DyEq,C0,Abs,Ord,Cinf,Csup);
DyStdInf=C(1); LogIp=5*C(2);
[Cinf;C0;C;Csup]
OrdFit=DyEq(C,Abs);
hold on; plot(Abs,OrdFit,'-','LineWidth',2,'color','r'); hold off;
MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=0; MaxOrd=max(Ord)*1.5;
axis([MinAbs MaxAbs MinOrd MaxOrd]);
MyFigureStyle(0,0,0,0,0,0,FontSize2);
text(0.5,0.02,'$-\log I$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');
text(0.02,0.98,'$D_y$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
text(0.98,0.98,['$D_y^\infty=' num2str(DyStdInf,3) '$'],'Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','color','r');

axes(AxAll{2,1}); hold on;
for z=1:Nclass
    
    Abs=NpartTotal(1:NtauFig,1);
    Ord=reshape(MeanStd_MeanDisp_TimeStep{c}(z,5,1:NtauFig)/Scale,[NtauFig 1 1]);
    LogI=MeanStd_MeanDisp_TimeStep{c}(z,10,1);
    [~,I]=min(abs(Scale_LogI-LogI));
    plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
    
    AbsLog=log(Abs); OrdLog=log(Ord);
    p=polyfit(AbsLog(TiFit:TfFit),OrdLog(TiFit:TfFit),1);
    OrdFit=exp(p(2))*Abs.^p(1);
    CoefsSTDFit(z,5:7)=[p corr2(OrdLog,log(OrdFit))];
    plot(Abs,OrdFit,'-','LineWidth',LW,'color',ColorsLogI(I,:));
    
    if z==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]);
hold off; caxis([Mindl Maxdl]); colormap(ColorsLogI);
set(gca,'xscale','log','yscale','log');
MyFigureStyle('$\tau$ (ms)','$\sigma_x$ ($\mu$m)',0,0,0,0,FontSize);
CB=colorbar; set(CB,'TickLabelInterpreter','latex','FontSize',FontSize);
ylabel(CB,'$\log I_\mathrm{initial}$','Interpreter','latex','FontSize',FontSize);
set(CB,'position',[(Xpos1(2)+Wf1)/Wfig+0.01 Ypos1/Hfig 0.05*Wf1/Wfig Hf1/Hfig]);

axes(AxAll{2,2});
Abs=-CoefsSTDFit(:,1); Ord=CoefsSTDFit(:,5);
plot(Abs,Ord,'o','LineWidth',1,'MarkerSize',MS2,...
    'MarkerFaceColor',[0 0.5 0],'MarkerEdgeColor','black');
MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=0; MaxOrd=1;
axis([MinAbs MaxAbs MinOrd MaxOrd]);
MyFigureStyle(0,0,0,0,0,0,FontSize2);
text(0.5,0.02,'$-\log I$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');
text(0.02,0.98,'$n$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);

axes(AxAll{2,3});
Abs=-CoefsSTDFit(:,1); Ord=exp(CoefsSTDFit(:,6)).^2/2;
plot(Abs,Ord,'o','LineWidth',1,'MarkerSize',MS2,...
    'MarkerFaceColor',[0 0 0.5],'MarkerEdgeColor','black');
% C0=[D0 1 min(Abs)+1]; Cinf=[0 0 min(Abs)-5]; Csup=[100*D0 5 min(Abs)+5];
% C=lsqcurvefit(DyEq,C0,Abs,Ord,Cinf,Csup);
% DxStdInf=C(1);
% [Cinf;C0;C;Csup]
% OrdFit=DyEq(C,Abs);
I=find(abs(CoefsSTDFit(:,5)-0.6)<0.1);
DxStdInf=mean(Ord(I)); OrdFit=ones(length(Abs))*DxStdInf;
hold on; plot(Abs,OrdFit,'-','LineWidth',2,'color','r'); hold off;
MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=0; MaxOrd=max(Ord)*1.5;
axis([MinAbs MaxAbs MinOrd MaxOrd]);
MyFigureStyle(0,0,0,0,0,0,FontSize2);
text(0.5,0.02,'$-\log I$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');
text(0.02,0.98,'$D_y$','Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
text(0.98,0.98,['$D_x^\infty=' num2str(DxStdInf,3) '$'],'Units','normalized',...
    'FontSize',FontSize2,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','color','r');

if SaveFig==1
    FigName=['Fig11_DyDxFirstIntants_Tmax' num2str(Ntau)];
    saveas(Fig,[FolderResults filesep FigName '.fig']);
    export_fig([FolderResults filesep FigName], '-pdf');
    export_fig([FolderResults filesep FigName], '-tif');
    close(Fig);
end

%% Save Results
I=strfind(MainFolder,filesep);
FileName=[MainFolder(I(end)+1:end) '_' MovieNumbers];
save(fullfile(FolderResults,[FileName '_AllTS2.mat']),'MainFolder',...
    'ListSubFolders','Infos','FolderResults','MovieNumbers','Nfiles',...
    'FinalSubFolderList','FinalInfos','UnitsSpace','UnitsTime',...
    'Method_Intensity','AngleCorrection','MethodInterp','TrajectorySelection',...
    'UnitsVelocity','FinalSubFolderList','SpatialDistrib','Stationnarity',...
    'MovieNumbers','TrackingParameters','Scales','FrameRates',...
    'InfosFile','MeanStdIntVxVyAll_Repro','MeanStdIntVxVyAll_Repro',...
    'Npart_TimeStep','InfosFile','NpartTotal',...
    'Npart_TS_Fit','LimitFit','Gap','Nclass','Ntau','Nmin','TSmax',...
    'Disp_X_Y_LogI_TimeStepTotal','GlobalSTD_TimeStep',...
    'MeanStd_MeanDisp_TimeStep','PDFsloc_X_TimeStep',...
    'PDFsloc_dX_TimeStep','PDFsloc_Y_TimeStep','PDFsloc_dY_TimeStep',...
    'PDFsloc_Int_TimeStep','PDFsloc_dInt_TimeStep');
disp('Variables Saved');
end
