function [CoefFits,FrameFit]=My2dGaussianFit(Frame,Radii,StartPoints,Display)

[ny,nx]=size(Frame);
Xc1=(1:nx)'; Yc1=(1:ny)'; [X,Y]=meshgrid(Xc1,Yc1);

np=size(StartPoints,1); CoefFits=cell(np);
% I0=mode(reshape(double(Frame),[numel(Frame) 1]));
if Display>=1
    scrsz=get(0,'ScreenSize'); % Problems if you change your screen
    scrsz2=[(scrsz(3)-scrsz(4))/2 scrsz(2) scrsz(4) scrsz(4)];
    FrameFit=ones(ny*nx,1); FontSize=10;
end
Xt=reshape(X,[numel(X) 1 1]); Yt=reshape(Y,[numel(Y) 1 1]);
Zt=reshape(double(Frame),[numel(Frame) 1 1]);

GaussianEq=@(C,r)C(1)+C(2)*exp(-((r(:,1)-C(3)).^2+(r(:,2)-C(4)).^2)/(2*C(5))^2);
Iint0=StartPoints(:,1); IintM=StartPoints(:,2);
Xpos=StartPoints(:,3); Ypos=StartPoints(:,4); A0=StartPoints(:,5);

if Display==0
    parfor n=1:np
        
        x0=Xpos(n); y0=Ypos(n); I0=Iint0(n); Im=IintM(n); a0=A0(n);
        dpix=round(Radii(n));
        xi=max(1,fix(x0-dpix)); xf=min(nx,fix(x0+dpix));
        yi=max(1,fix(y0-dpix)); yf=min(ny,fix(y0+dpix));
        nxi=xf-xi+1; nyi=yf-yi+1;
        
        I=(Xt>=xi & Xt<=xf & Yt>=yi & Yt<=yf & Zt>=0);
        x=Xt(I==1); y=Yt(I==1); r=[x y]; z=Zt(I==1);
        
        C0=[I0 Im x0 y0 a0];
        Cinf=[I0/2 I0 x0-nxi/4 y0-nyi/4 0];
        Csup=[I0*2 max(z) x0+nxi/4 y0+nyi/4 sqrt(nxi*nyi)];
        C=lsqcurvefit(GaussianEq,C0,r,z,Cinf,Csup);
        
        CoefFits{n}=C;

    end
elseif Display>=1
    for n=1:np
        
        x0=Xpos(n); y0=Ypos(n); I0=Iint0(n); Im=IintM(n); a0=A0(n);
        dpix=round(Radii(n));
        xi=max(1,fix(x0-dpix)); xf=min(nx,fix(x0+dpix));
        yi=max(1,fix(y0-dpix)); yf=min(ny,fix(y0+dpix));
        nxi=xf-xi+1; nyi=yf-yi+1;
        
        I=(Xt>=xi & Xt<=xf & Yt>=yi & Yt<=yf & Zt>=0);
        x=Xt(I==1); y=Yt(I==1); r=[x y]; z=Zt(I==1);
        
        C0=[I0 Im x0 y0 a0];
        Cinf=[I0/2 I0 x0-nxi/4 y0-nyi/4 0];
        Csup=[I0*2 max(z) x0+nxi/4 y0+nyi/4 sqrt(nxi*nyi)];
        C=lsqcurvefit(GaussianEq,C0,r,z,Cinf,Csup);
    %     [Cinf;C0;C;Csup];

        zfit=GaussianEq(C,r);
        FrameInt=ones(ny*nx,1); FrameInt(I)=zfit;
        J=find(FrameInt>C(1)+0.01*C(2));
        FrameFit(J)=max(FrameFit(J),FrameInt(J));
        CoefFits{n}=C;
        
        if Display==3
            
            Xloc=reshape(x,[nyi nxi 1]); Yloc=reshape(y,[nyi nxi 1]);
            FrameLoc=reshape(z,[nyi nxi 1]);
            FrameLocFit=reshape(zfit,[nyi nxi 1]);

            TresholdLoc=0.999;
            [MinIloc,MaxIloc]=Decil(double(FrameLoc),1-TresholdLoc,TresholdLoc);
            if MinIloc>=MaxIloc
                MaxIloc=max(z); MinIloc=min(z);
            end
            [~,Ix]=min(abs(Xloc(1,:)-round(C(3))));
            [~,Iy]=min(abs(Yloc(:,1)-round(C(4))));

            figure('name',['Particle ' num2str(n)],'NumberTitle','off');
            set(gcf,'Position',scrsz2);
            row=2; col=2; FactorAR=3/3;
            subplot(row,col,1); imagesc(xi:xf,yi:yf,FrameLoc,[MinIloc MaxIloc]);
            MyFigStyleLaTeXSave('$x$','$y$',0,'Frame',2,'I',[1 1 1],FontSize);
            subplot(row,col,2); imagesc(xi:xf,yi:yf,FrameLocFit,[MinIloc MaxIloc]);
            MyFigStyleLaTeXSave('$x$','$y$',0,'Fit',2,'I',[1 1 1],FontSize);
            subplot(row,col,3); plot(Xloc(1,:),FrameLoc(Iy,:),'o',Xloc(1,:),FrameLocFit(Iy,:),'-','LineWidth',2,'MarkerSize',8);
            axis([xi xf C(1) 1.1*max(FrameLoc(Iy,:))]); Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
            MyFigStyleLaTeXSave('$x$','$I$',0,['$y=' num2str(round(C(4))) '$'],0,0,[1 FactorAR*AR 1],FontSize);
            subplot(row,col,4); plot(Yloc(:,1),FrameLoc(:,Ix),'o',Yloc(:,1),FrameLocFit(:,Ix),'-','LineWidth',2,'MarkerSize',8);
            axis([yi yf C(1) 1.1*max(FrameLoc(:,Ix))]); Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
            MyFigStyleLaTeXSave('$y$','$I$',0,['$x=' num2str(round(C(3))) '$'],0,0,[1 FactorAR*AR 1],FontSize);
            colormap jet;

        end
        
    end
end
CoefFits=vertcat(CoefFits{:});

if Display>=1
    
    FrameFit(FrameFit==1)=mean(CoefFits(:,1));
    FrameFit=reshape(FrameFit,[ny nx 1]);
    TresholdLoc=0.999;
    [MinI,MaxI]=Decil(double(Frame),1-TresholdLoc,TresholdLoc);
    
    if Display>=2
        figure('name','All particles','NumberTitle','off');
        set(gcf,'Position',scrsz);
        subplot(1,2,1); imagesc(Frame,[MinI MaxI]);
        MyFigStyleLaTeXSave('$x$','$y$',0,'Frame',2,'I',[1 1 1],FontSize);
        subplot(1,2,2); imagesc(FrameFit,[MinI MaxI]);
        MyFigStyleLaTeXSave('$x$','$y$',0,'Fit',2,'I',[1 1 1],FontSize);
        colormap jet;
    end
    
end


end