function [sigma,xfit,yfit]=NormGaussianFit(xdata,ydata,display,Mode)

c0=sqrt(sum(xdata.^2.*ydata)*mean(diff(xdata))-(sum(xdata.*ydata)*mean(diff(xdata)))^2);
cinf=0; csup=2*c0;

% Fit from linear data
GaussianEq=@(c,x)exp(-(x.^2/(2*c(1)^2)))/sqrt(2*pi*c(1)^2);
clin=lsqcurvefit(GaussianEq,c0,xdata,ydata,cinf,csup);

if Mode==2
    % Fit from log data
    GaussianEqLog=@(c,x)-x.^2/(2*c(1)^2)-log(sqrt(2*pi*c(1)^2));
    clog=lsqcurvefit(GaussianEqLog,c0,xdata(ydata>0),log(ydata(ydata>0)),cinf,csup);
end

% Results
if Mode==1
    sigma=clin;
elseif Mode==2
    sigma=[clin;clog];
end
xfit=linspace(-max(abs(xdata)),max(abs(xdata)),100)';
yfit=GaussianEq(clin,xfit);

if display==1
    [cinf c0 clin csup]
end

%% Figure
if display==1
    
    FontSize=12; FactorAR=4/3; LegendLoc='South';
    figure('name','Velocity profiles','NumberTitle','off');
    scrsz=get(0,'ScreenSize'); set(gcf,'Position',scrsz);
    
    subplot(1,2,1); hold on;
    plot(xdata,ydata,'o','LineWidth',2,'MarkerSize',10,'color','b');
    plot(xfit,GaussianEq(clin,xfit),'-','LineWidth',2,'MarkerSize',10,'color','r');
    if Mode==2
        plot(xfit,exp(GaussianEqLog(clog,xfit)),'--','LineWidth',2,'MarkerSize',10,'color','r');
    end
    axis([min(xdata) max(xdata) min(ydata) max(ydata)*1.3]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.97,'$f\left(x\right)=\frac{2}{\sqrt{2\pi\sigma}}\exp\left(-\frac{x^2}{2\sigma^2}\right)$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.98,'$\int\limits _{-\infty}^{+\infty}f\left(x\right)dx=1$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.85,'$\sigma^{2}=\int\limits _{-\infty}^{+\infty}x^{2}f\left(x\right)dx$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.5,Ax(3)+(Ax(4)-Ax(3))*0.95,['$\sigma_0=' num2str(c0,3) '$'],'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','top');
    leg=legend('data',['$\sigma=' num2str(clin,4) '$'],'Location',LegendLoc);
    set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    MyFigStyleLaTeXSave('$x$','$f\left(x\right)$',0,'Fit from $\left(x, y\right)$',0,0,[1 FactorAR*AR 1],FontSize);
    
    subplot(1,2,2); hold on; set(gca,'yscale','log');
    plot(xdata,ydata,'o','LineWidth',2,'MarkerSize',10,'color','b');
    plot(xfit,GaussianEq(clin,xfit),'-','LineWidth',2,'MarkerSize',10,'color','r');
    if Mode==2
        plot(xfit,exp(GaussianEqLog(clog,xfit)),'--','LineWidth',2,'MarkerSize',10,'color','r');
    end
    axis([min(xdata) max(xdata) min(ydata) max(ydata)*1.3]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    if Mode==2
        leg=legend('data',['$\sigma=' num2str(clog,4) '$'],'Location',LegendLoc);
    end
    set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    MyFigStyleLaTeXSave('$x$','$f\left(x\right)$',0,'Fit from $\left(x, \log y\right)$',0,0,[1 FactorAR*AR 1],FontSize);
    
end



end