function MaxCurvature=PDF_Curvature(x,PDF,FitDegree,Np,Display)


%% Example
% FitDegree=2; Np=50;
% n=1.5; s=3; x0=5; noise=0.01;
% xlim=4*s; x=linspace(x0-xlim,x0+xlim,1000)';
% PDF=sqrt(gamma(3/n+1)/(12*gamma(1/n+1)^3*s^2))*exp(-(((x-x0)/s).^2*gamma(3/n+1)/(3*gamma(1/n+1))).^(n/2))...
%     +noise*2*(rand([length(x) 1])-0.5);
% plot(x,log(PDF),'o');

%% Curvature obtention
I=PDF>0; x=x(I==1); PDF=PDF(I==1);
n=length(PDF); LogPDF=log(PDF);
if Np>=1
    [~,Imax]=max(PDF); Iinf=max(1,Imax-Np); Isup=min(n,Imax+Np);    
elseif Np>=0 && Np<1
    MaxPDF=max(PDF); I=find(PDF>=MaxPDF*Np); Iinf=I(1); Isup=I(end);
end
% p=polyfit(x(Iinf:Isup),LogPDF(Iinf:Isup),FitDegree);
p=MyPolyfit(x(Iinf:Isup),LogPDF(Iinf:Isup),FitDegree);
xminfit=x(Iinf); xsupfit=x(Isup); xfit=linspace(xminfit,xsupfit,100)';
LogPDG_Fit=polyval(p,xfit); [~,ImaxFit]=max(LogPDG_Fit);
d1p=polyder(p); d2p=polyder(d1p);

% Curvature=polyval(d2p,xfit)./(1+polyval(d1p,xfit).^2).^(3/2);
Curvature=polyval(d2p,xfit);
MaxCurvature=Curvature(ImaxFit);

%% Optionnal figure
if Display==1
    LogPDG_FitAll=polyval(p,x);
    title=['$n=' num2str(FitDegree) '$ ; $C=' num2str(MaxCurvature) '$'];
    
    scrsz=get(0,'ScreenSize'); 
    figure('name',['PDF curvature with n = ' num2str(FitDegree) 'and Np = ' num2str(Np)],'NumberTitle','off');
    set(gcf,'Position',scrsz); LW=2; MS=10; FontSize=14; FactorAR=4/3;
    
    subplot(1,2,1);
    plot(x,exp(LogPDF),'o','LineWidth',LW,'MarkerSize',MS,'color','b'); hold on;
    plot(x,exp(LogPDG_FitAll),'--','LineWidth',LW,'MarkerSize',MS,'color','magenta');
    plot(xfit,exp(LogPDG_Fit),'-','LineWidth',LW,'MarkerSize',MS,'color','r');
    plot(xfit(ImaxFit),exp(LogPDG_Fit(ImaxFit)),'x','LineWidth',LW,'MarkerSize',2*MS,'color','r');
    axis([min(x) max(x) 0 max(exp(LogPDF))*1.1]); hold off;
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    if Np>=0 && Np<1
        line([Ax(1) Ax(2)],MaxPDF*Np*[1 1],'LineStyle','--','LineWidth',2,'color','black');
    end
    MyFigStyleLaTeXSave('$x$','$P\left(x\right)$',0,title,0,0,[1 FactorAR*AR 1],FontSize);
    
    subplot(1,2,2);
    plot(x,LogPDF,'o','LineWidth',LW,'MarkerSize',MS,'color','b'); hold on;
    plot(x,LogPDG_FitAll,'--','LineWidth',LW,'MarkerSize',MS,'color','magenta');
    plot(xfit,LogPDG_Fit,'-','LineWidth',LW,'MarkerSize',MS,'color','r');
    plot(xfit(ImaxFit),LogPDG_Fit(ImaxFit),'x','LineWidth',LW,'MarkerSize',2*MS,'color','r');
    axis([min(x) max(x) min(LogPDF) max(LogPDF)*(1+0.5*sign(max(LogPDF)))]); hold off;
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    if Np>=0 && Np<1
        line([Ax(1) Ax(2)],log(MaxPDF*Np)*[1 1],'LineStyle','--','LineWidth',2,'color','black');
    end
    MyFigStyleLaTeXSave('$x$','$\log\left(P\left(x\right)\right)$',0,title,0,0,[1 FactorAR*AR 1],FontSize);
    
end



end
