function [sigma,exponent,xfit,yfit]=PDFexponentN(xdata,ydata,display,Mode)

sigma0=sqrt(sum(xdata.^2.*ydata)*mean(diff(xdata))-(sum(xdata.*ydata)*mean(diff(xdata)))^2);
n0=1.5; c0=[sigma0 n0]; sigmasup=4*sigma0; nsup=10; cinf=[0 0]; csup=[sigmasup nsup];

%% Fit with linear form
if Mode==3
    % Only the exponent
    PDFexpN_Eq_N=@(c,x)sqrt(gamma(3/c(1)+1)/(12*gamma(1/c(1)+1)^3*sigma0^2))*exp(-((x/sigma0).^2*gamma(3/c(1)+1)/(3*gamma(1/c(1)+1))).^(c(1)/2));
    c=lsqcurvefit(PDFexpN_Eq_N,n0,xdata,ydata,0,nsup);
    Cn=[sigma0 c(1)]; n1=c(1);

    % Only the standard deviation
    PDFexpN_Eq_S=@(c,x)sqrt(gamma(3/n1+1)/(12*gamma(1/n1+1)^3*c(1)^2))*exp(-((x/c(1)).^2*gamma(3/n1+1)/(3*gamma(1/n1+1))).^(n1/2));
    c=lsqcurvefit(PDFexpN_Eq_S,sigma0,xdata,ydata,0,sigmasup);
    Cs=[c(1) n1]; s1=c(1);
end

% Exponent and standard deviation
PDFexpN_Eq=@(c,x)sqrt(gamma(3/c(2)+1)/(12*gamma(1/c(2)+1)^3*c(1)^2))*exp(-((x/c(1)).^2*gamma(3/c(2)+1)/(3*gamma(1/c(2)+1))).^(c(2)/2));
c=lsqcurvefit(PDFexpN_Eq,c0,xdata,ydata,cinf,csup);
Cns=c;

%% Fit with log form
if Mode==3
    % Only the exponent
    PDFexpN_EqLog_N=@(c,x)log(sqrt(gamma(3/c(1)+1)/(12*gamma(1/c(1)+1)^3*sigma0^2)))-((x/sigma0).^2*gamma(3/c(1)+1)/(3*gamma(1/c(1)+1))).^(c(1)/2);
    c=lsqcurvefit(PDFexpN_EqLog_N,n0,xdata(ydata>0),log(ydata(ydata>0)),0,nsup);
    CnLog=[sigma0 c(1)]; n1log=c(1);

    % Only the standard deviation
    PDFexpN_EqLog_S=@(c,x)log(sqrt(gamma(3/n1log+1)/(12*gamma(1/n1log+1)^3*c(1)^2)))-((x/c(1)).^2*gamma(3/n1log+1)/(3*gamma(1/n1log+1))).^(n1log/2);
    c=lsqcurvefit(PDFexpN_EqLog_S,sigma0,xdata(ydata>0),log(ydata(ydata>0)),0,sigmasup);
    CsLog=[c(1) n1log]; s1log=c(1);
end

if Mode>1
    % Exponent and standard deviation
    PDFexpN_EqLog=@(c,x)log(sqrt(gamma(3/c(2)+1)/(12*gamma(1/c(2)+1)^3*c(1)^2)))-((x/c(1)).^2*gamma(3/c(2)+1)/(3*gamma(1/c(2)+1))).^(c(2)/2);
    c=lsqcurvefit(PDFexpN_EqLog,c0,xdata(ydata>0),log(ydata(ydata>0)),cinf,csup);
    CnsLog=c;
end

%% Results
if Mode==1
    sigma=Cns(1); exponent=Cns(2);
elseif Mode==2
    sigma=[Cns(1);CnsLog(1)]; exponent=[Cns(2);CnsLog(2)];
elseif Mode==3
    sigma=[Cns(1);Cn(1);Cs(1);CnsLog(1);CnLog(1);CsLog(1)];
    exponent=[Cns(2);Cn(2);Cs(2);CnsLog(2);CnLog(2);CsLog(2)];
end
xfit=linspace(-max(abs(xdata)),max(abs(xdata)),100)';
yfit=PDFexpN_Eq(Cns,xfit);

%% Optional figures
if display==1
    [cinf;c0;Cns;csup]
end

if display==1
    
    FontSize=12; FactorAR=4/3; LegendLoc='South';
    figure('name','Velocity profiles','NumberTitle','off');
    scrsz=get(0,'ScreenSize'); set(gcf,'Position',scrsz);
    
    subplot(1,2,1); hold on;
    plot(xdata,ydata,'o','LineWidth',2,'MarkerSize',10,'color','b');
    plot(xfit,PDFexpN_Eq(Cns,xfit),'-','LineWidth',2,'MarkerSize',10,'color','r');
    if Mode==3
        plot(xfit,PDFexpN_Eq_N(n1,xfit),'-','LineWidth',2,'MarkerSize',10,'color','magenta');
        plot(xfit,PDFexpN_Eq_S(s1,xfit),'-','LineWidth',2,'MarkerSize',10,'color',[0 0.5 0]);
    end
    if Mode>1
        plot(xfit,exp(PDFexpN_EqLog(CnsLog,xfit)),'--','LineWidth',2,'MarkerSize',10,'color','r');
    end
    if Mode==3
        plot(xfit,exp(PDFexpN_EqLog_N(n1log,xfit)),'--','LineWidth',2,'MarkerSize',10,'color','magenta');
        plot(xfit,exp(PDFexpN_EqLog_S(s1log,xfit)),'--','LineWidth',2,'MarkerSize',10,'color',[0 0.5 0]);
    end
    axis([min(xdata) max(xdata) min(ydata) max(ydata)*1.3]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,'$f\left(x\right)=A\exp\left(-\left|\frac{x}{a}\right|^{n}\right)$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.86,'$A=\frac{1}{\sigma}\sqrt{\frac{\Gamma\left(\frac{3}{n}+1\right)}{12\Gamma^{3}\left(\frac{1}{n}+1\right)}}$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.74,'$a=\sigma\sqrt{\frac{3\Gamma\left(\frac{1}{n}+1\right)}{\Gamma\left(\frac{3}{n}+1\right)}}$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.98,'$\int\limits _{-\infty}^{+\infty}f\left(x\right)dx=1$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.85,'$\sigma^{2}=\int\limits _{-\infty}^{+\infty}x^{2}f\left(x\right)dx$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
    text(Ax(1)+(Ax(2)-Ax(1))*0.5,Ax(3)+(Ax(4)-Ax(3))*0.95,['$\sigma_0=' num2str(sigma0,3) '$'],'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','top');
    MyFigStyleLaTeXSave('$x$','$f\left(x\right)$',0,'Fit from $\left(x, y\right)$',0,0,[1 FactorAR*AR 1],FontSize);
    if Mode==1 || Mode==2
        leg=legend('data',['$\sigma=' num2str(Cns(1),3) '$; $n=' num2str(Cns(2),3) '$'],'Location',LegendLoc);
    elseif Mode==3
        leg=legend('data',['$\sigma=' num2str(Cns(1),3) '$; $n=' num2str(Cns(2),3) '$'],...
            ['$\sigma=' num2str(Cn(1),3) '$; $n=' num2str(Cn(2),3) '$'],...
            ['$\sigma=' num2str(Cs(1),3) '$; $n=' num2str(Cs(2),3) '$'],'Location',LegendLoc);
    end
    set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    
    subplot(1,2,2); hold on; set(gca,'yscale','log');
    plot(xdata,ydata,'o','LineWidth',2,'MarkerSize',10,'color','b');
    if Mode>1
        plot(xfit,exp(PDFexpN_EqLog(CnsLog,xfit)),'--','LineWidth',2,'MarkerSize',10,'color','r');
    end
    if Mode==3
        plot(xfit,exp(PDFexpN_EqLog_N(n1log,xfit)),'--','LineWidth',2,'MarkerSize',10,'color','magenta');
        plot(xfit,exp(PDFexpN_EqLog_S(s1log,xfit)),'--','LineWidth',2,'MarkerSize',10,'color',[0 0.5 0]);
    end
    plot(xfit,PDFexpN_Eq(Cns,xfit),'-','LineWidth',2,'MarkerSize',10,'color','r');
    if Mode==3
        plot(xfit,PDFexpN_Eq_N(n1,xfit),'-','LineWidth',2,'MarkerSize',10,'color','magenta');
        plot(xfit,PDFexpN_Eq_S(s1,xfit),'-','LineWidth',2,'MarkerSize',10,'color',[0.5 0.5 0.5]);
    end
    axis([min(xdata) max(xdata) min(ydata(ydata>0)) max(ydata)*2]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    MyFigStyleLaTeXSave('$x$','$f\left(x\right)$',0,'Fit from $\left(x, \log y\right)$',0,0,[1 FactorAR*AR 1],FontSize);
    if Mode==2
        leg=legend('data',['$\sigma=' num2str(CnsLog(1),3) '$; $n=' num2str(CnsLog(2),3) '$'],'Location',LegendLoc);
        set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    elseif Mode==3
        leg=legend('data',['$\sigma=' num2str(CnsLog(1),3) '$; $n=' num2str(CnsLog(2),3) '$'],...
            ['$\sigma=' num2str(CnLog(1),3) '$; $n=' num2str(CnLog(2),3) '$'],...
            ['$\sigma=' num2str(CsLog(1),3) '$; $n=' num2str(CsLog(2),3) '$'],'Location',LegendLoc);
        set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    end
    
end



end