function [CentersMat,CentersMat2dGaussian,nx,ny]=TIRF_Detection(Folder,...
    FrameFormat,Scale,FrameRate,UnitsSpace,UnitsTime,Filtering,...
    MinPixel,MaxPixel,GaussBlur,ThresholdPart,Method,AirMinDetection,...
    TolArea,Display)

%% Objective of the function
% Detect particle positions and intensities from Total Internal Reflexion
% Fluorescence (TIRF) microscopy experiments

% % Parameters
% % Video informations
% Folder='F:\AlexVilquin\2019-04-08-Channel8cm8_SideCam_000PEG_NaCl\17-Motor20000_Plaser50mW_P40mbar_f400fps_NaCl54mgpl0';
% FrameFormat='.tif';
% Scale=22.9; % pixel per units
% FrameRate=0;
% 
% % Filtering (opiotnal)
% Filtering=2; MinPixel=1; MaxPixel=10;
% 
% % RegionProps detection
% GaussBlur=0; ThresholdPart=10; Method=3;
% 
% % 2D gaussian fit
% TolArea=4;

%% Resume parameter information
InfosParametersDetect=['Filt' num2str(Filtering) '-' num2str(MinPixel) '-' num2str(MaxPixel) '_DetectGB'...
    num2str(GaussBlur) 'TP' num2str(ThresholdPart) 'M' num2str(Method) 'Am' num2str(AirMinDetection) '_TolA' num2str(TolArea)];

%% Frame sequence informations
scrsz=get(0,'ScreenSize'); % Problems if you change your screen
if strcmp(Folder,'manual')==1
    Folder=uigetdir;
end
if FrameRate==0
    I=strfind(Folder,'_f'); J=strfind(Folder,'fps');
    FrameRate=str2double(Folder(I+2:J-1));
end
I=strfind(Folder,filesep);
% MainFolder=Folder(1:I(end));
FileName=Folder(I(end)+1:end);
FolderResults=[Folder(1:I(end)) 'Results' filesep FileName];
ListeFrames=dir([Folder filesep '*' FrameFormat]); Nfiles=numel(ListeFrames);
im=imread([Folder filesep ListeFrames(1).name]); [ny,nx]=size(im);
% [MinFrames,MaxFrames,MeanFrames,MeanMedInt]=ZstackFramesFast(Folder,Format,1,0);

%% Tracking centroids and 2D Gaussian Fit for all frames
% Example on one frame
if strcmpi(Display,'all')==1
    i=fix(Nfiles/2);
    
    % Filtering
    Frame=imread([Folder filesep ListeFrames(i).name]);
    if Filtering==1 || Filtering==2
        FrameFilter=bpass(Frame,MinPixel,MaxPixel);
    end
    % Centroid detection
    if Filtering==0
%         centers=MyCentroidDetection(Frame,GaussBlur,Method,ThresholdPart,1);
        [centers,ColumNames,pixels]=MyShapeDetection(Frame,GaussBlur,Method,ThresholdPart,1);
    elseif Filtering==1 || Filtering==2
       [centers,ColumNames,pixels]=MyShapeDetection(FrameFilter,GaussBlur,Method,ThresholdPart,1);
    end
    % Gaussian fit
    if isempty(centers)==0
        np=size(centers,1);
        Radii=max(2,TolArea*(centers(:,5)+centers(:,6))/2.*(centers(:,8)./centers(:,9)));
        if Filtering==0 || Filtering==1
            I0loc=mean(mean(Frame));
            IntMax=Frame2IntMax(Frame,pixels);
            StartPoints=[ones(np,1)*I0loc IntMax centers(:,1) centers(:,2) (centers(:,5)+centers(:,6))/8];
            CoefFits=My2dGaussianFit(Frame,Radii,StartPoints,3);
        elseif Filtering==2
            I0loc=mean(mean(FrameFilter));
            IntMax=centers(:,9)-ones(np,1)*I0loc;
            StartPoints=[ones(np,1)*I0loc IntMax centers(:,1) centers(:,2) (centers(:,5)+centers(:,6))/8];
            CoefFits=My2dGaussianFit(Frame,Radii,StartPoints,3);
        end
    end
    
end

% Centroid detection for all frames
tic; Centers=cell(Nfiles,1); Pixels=cell(Nfiles,1);
parfor i=1:Nfiles
    disp(['Frame ' num2str(i) '/' num2str(Nfiles)]);
    Frame=imread([Folder filesep ListeFrames(i).name]);
    
    if Filtering==1 || Filtering==2
        Frame=bpass(Frame,MinPixel,MaxPixel);
    end
    
%     centers=MyCentroidDetection(Frame,GaussBlur,Method,ThresholdPart,0);
    [centers,~,pixels]=MyShapeDetection(Frame,GaussBlur,Method,ThresholdPart,AirMinDetection,0);
    
    Centers{i,1}=horzcat(i.*ones(size(centers,1),1),centers);
    Pixels{i,1}=pixels;
end
time=toc;

% 2D Gaussian fit for all frames
tic; Coef2dGaussianFits=cell(Nfiles,1);
parfor i=1:Nfiles
    
    disp(['Frame ' num2str(i) '/' num2str(Nfiles)]);
    Frame=imread([Folder filesep ListeFrames(i).name]);
        
    if Filtering==2
        Frame=bpass(Frame,MinPixel,MaxPixel);
    end
    
    if isempty(Centers{i})==0
        centers=Centers{i}; np=size(centers,1); I0loc=mean(mean(Frame));
        centers=centers(:,2:end); pixels=Pixels{i,1};
        Radii=max(2,TolArea*(centers(:,5)+centers(:,6))/2.*(centers(:,8)./centers(:,9)));
        IntMax=Frame2IntMax(Frame,pixels);
        StartPoints=[ones(np,1)*I0loc IntMax centers(:,1) centers(:,2) (centers(:,5)+centers(:,6))/8];
        CoefFits=My2dGaussianFit(Frame,Radii,StartPoints,0);
        Coef2dGaussianFits{i}=CoefFits;        
    end
    
end
time2=toc;

% Final matrix with positions and other quantities
CentersMat=vertcat(Centers{:});
CentersMat2dGaussian=vertcat(Coef2dGaussianFits{:});

disp(['Centroids obtained in ' num2str(time,3) ' s for ' num2str(Nfiles) ' frames']);
disp(['2d-Gaussian fits obtained in ' num2str(time2,3) ' s for ' num2str(Nfiles) ' frames']);

%% Save parameters and results
if exist('FolderResults','dir')==0
    mkdir(FolderResults);
end
save(fullfile(FolderResults,['PositionsIntensities_' InfosParametersDetect '.mat']),...
    'FrameFormat','Folder','ListeFrames','Scale','FrameRate','UnitsSpace',...
    'UnitsTime','Filtering','MinPixel','MaxPixel','GaussBlur','ThresholdPart',...
    'Method','AirMinDetection','TolArea','nx','ny','CentersMat','CentersMat2dGaussian','Nfiles');
disp('Variables Saved');




end