function [PosVelocities,DeltaTime,MSD,AutoCorrelation]=Traj2AllDisp_TS(time,positions)

%% Example
% np=100; dt=1; dl=10;
% t=(1:np)'; x=zeros(np,1); y=zeros(np,1);
% theta=(rand(1)-0.5)*2*pi;
% for i=2:np
%     if mod(i,dt)==0
%         theta=(rand(1)-0.5)*2*pi;
%     end
%     dx=cos(theta)*dl;
%     dy=sin(theta)*dl;
%     x(i)=x(i-1)+dx; y(i)=y(i-1)+dy;    
% end
% time=t; positions=[x y];
% clearvars -except time positions

%% Function
[np,nd]=size(positions);
Mdiff=zeros(np,np,nd);
Mmean=zeros(np,np,nd); Mprod=zeros(np,np,nd);
Mi=zeros(np,np,nd); Mif=zeros(np,np,nd);
for i=1:nd
    Mdiff(:,:,i)=repmat(positions(:,i),[1 np 1])-repmat(positions(:,i)',[np 1 1]);
    Mi(:,:,i)=repmat(positions(:,i)',[np 1 1]);
    Mif(:,:,i)=(repmat(positions(:,i),[1 np 1])+repmat(positions(:,i)',[np 1 1]))/2;
    for r=1:np
        for c=1:np
            if r==c
                Mmean(r,c,i)=0;
            elseif r<c
                Mmean(r,c,i)=sum(positions(r:c,i))/length(positions(r:c,i));
            elseif r>c
                Mmean(r,c,i)=sum(positions(c:r,i))/length(positions(c:r,i));
            end
        end
    end
    
    Mprod(:,:,i)=repmat(positions(:,i),[1 np 1]).*repmat(positions(:,i)',[np 1 1]);
end
T2=repmat(time,[1 np 1])-repmat(time',[np 1 1]);

PosVelocities=cell(1,np-1); DeltaTime=zeros(np-1,1);
MSD=zeros(np-1,nd); AutoCorrelation=zeros(np-1,nd);
for i=1:np-1
    PosVelocities{i}=zeros(np-i,nd*2);
    if length(unique(diag(T2(i+1:end,1:end-i))))==1
        DeltaTime(i)=unique(diag(T2(i+1:end,1:end-i)));
    elseif length(unique(diag(T2(i+1:end,1:end-i))))>1
        MeanTau=mean(diag(T2(i+1:end,1:end-i)));
        StdTau=std(diag(T2(i+1:end,1:end-i)));
        if 100*StdTau/MeanTau<1e-3
            DeltaTime(i)=mean(diag(T2(i+1:end,1:end-i)));
        else
            error(['tau = ' num2str(DeltaTime(i)) ' pm ' num2str(std(diag(T2(i+1:end,1:end-i))))]);
        end
    end
    for j=1:nd
        Mdiffpart=Mdiff(i+1:end,1:end-i,j);
        Mipart=Mi(i+1:end,1:end-i,j);
        Mifpart=Mif(i+1:end,1:end-i,j);
        Mmeanpart=Mmean(i+1:end,1:end-i,j);
        Mprodpart=Mprod(i+1:end,1:end-i,j);
        PosVelocities{i}(:,j)=diag(Mipart);
        PosVelocities{i}(:,j+nd)=diag(Mifpart);
        PosVelocities{i}(:,j+2*nd)=diag(Mmeanpart);
        PosVelocities{i}(:,j+3*nd)=diag(Mdiffpart);
        MSD(i,j)=mean(diag(Mdiffpart.^2));
        AutoCorrelation(i,j)=mean(diag(Mprodpart));
    end
end



end