function [Disp_X_Y_LogI_TimeStepOneMovie,Npart_TS,FrameRate,Scale,MaxNp,...
    Trajectories,MeanStd_MeanDisp_TimeStep]=Traj2DispMeanStd(...
    MatFileTrajectories,Method_Intensity,AngleCorrection,...
    MethodInterp,TrajectorySelection,Ntau_fix,Nclass)

%% Description
% Function to calcul cross correlation terms from the MultiVideo file 
% Disp_X_Y_LogI_TimeStepTotal

%% Example
% MatFileTrajectories='F:\Manips\2019-12-06-NPs110nmConcentration\Results\40-Motor35500_C03uL0p1mL_Plaser150mW_50mbar_f400fps\Trajectories_Filt2-1-10_DetectGB0TP30M3Am5_TolA4_PartAi40As300Imin5Rmin0u6EP6_TrajMLD-4_30_-12_12MGC0_SelecDm10Tm5TM250Lm3.mat';
% Method_Intensity='max_gaussian'; % 'max_gaussian' , 'int_gaussian' , 'sum_pixels'
% AngleCorrection = 1; % Correct if the flow is not completely along X
% MethodInterp = 'linear'; % interpolate incomplete trajectories
% TrajectorySelection = 0; % New parameters Tmin Tmax Dmin Lmin

%% Calculate displacements from trajectories
load(MatFileTrajectories,'Paths','PathsProperties','PathsParticles',...
    'VelocityIntensity','MeanStdIntVxVyAll','nx','ny',...
    'max_linking_distance_Xn','max_linking_distance_Xp',...
    'max_linking_distance_Yn','max_linking_distance_Yp',...
    'max_gap_closing','Tmin','Tmax','Dmin','Lmin','ThresholdPart',...
    'Scale','FrameRate');

% Optionnal new trajectory selection    
if length(TrajectorySelection) == 4
    % Optionnal new parameters for trajectory selection
    Tmin = TrajectorySelection(1);
    Tmax = TrajectorySelection(2);
    Dmin = TrajectorySelection(3);
    Lmin = TrajectorySelection(4);
    PathIndex=find(PathsProperties(:,1)>=Dmin & PathsProperties(:,3)>=Tmin...
        & PathsProperties(:,3)<=Tmax & PathsProperties(:,6)>=Lmin);
    PathsParticles=horzcat(PathsProperties(PathIndex,:),PathIndex);
end

% Determination of eventual angle
SignMeanVpara=sign(mean(VelocityIntensity(:,1)));
if AngleCorrection == 1
    Vx=VelocityIntensity(:,1); Vy=VelocityIntensity(:,2);
    p=polyfit(Vx,Vy,1);
    AngleFlowRad=atan(p(1)); Angles=[AngleFlowRad AngleFlowRad*180/pi];
elseif AngleCorrection == 2
    Vx=VelocityIntensity(:,1); Vy=VelocityIntensity(:,2);
    nv=length(Vx);
    np=1000; ng=fix(nv/np); MaxVxVy=zeros(ng,1);
    Index=round(linspace(1,nv,ng+1));
    for j=1:ng
        VxLoc=Vx(Index(j):Index(j+1)); VyLoc=Vy(Index(j):Index(j+1));
        [hist_vx,I_bins_vx]=hist(VxLoc,round(sqrt(length(VxLoc))));
        p=polyfit(I_bins_vx,hist_vx,6); hist_vx_fit=polyval(p,I_bins_vx);
        [hist_vy,I_bins_vy]=hist(VyLoc,round(sqrt(length(VyLoc))));
        p=polyfit(I_bins_vy,hist_vy,6); hist_vy_fit=polyval(p,I_bins_vy);
        [~,I]=max(hist_vx_fit); [~,J]=max(hist_vy_fit);
        MaxVxVy(j)=I_bins_vy(J)/I_bins_vx(I);
    end
    AngleFlowRad=mean(atan(MaxVxVy)); Angles=[AngleFlowRad AngleFlowRad*180/pi];        
end

% For displacement calculation for each trajectory
Npath=size(PathsParticles,1); MaxNp=max(PathsParticles(:,3))-1;
Disp_X_Y_LogI=cell(Npath,1); Disp_X_Y_LogI_TS=cell(Npath,MaxNp);
Trajectories=cell(Npath,1); Ntraj = 1;
for j = 1 : Npath
    
    % Quantities
    k=PathsParticles(j,end); PathPart=Paths{k,1};
    % Frame xg yg L I0 Imaxg Imaxg_corr xc yc Area Icmean Isumc_corr
    tpath=PathPart(:,1); ti=tpath(1,1); tf=tpath(end,1);
    xpath=PathPart(:,2); ypath=PathPart(:,3)-ny/2;
    lpath=PathPart(:,4); Apath=PathPart(:,10);
    ImaxGausspath=PathPart(:,6); ImaxGaussCorrpath=PathPart(:,7);
    IintGausspath=2*pi*PathPart(:,4).^2.*PathPart(:,6);
    IintGaussCorrpath=2*pi*PathPart(:,4).^2.*PathPart(:,7);
    IsumPixpath=PathPart(:,10).*PathPart(:,11);
    IsumPixCorrpath=PathPart(:,10).*PathPart(:,12);

    % angle and/or velocity correction
    if AngleCorrection>0
        xpath=xpath*cos(AngleFlowRad)+ypath*sin(AngleFlowRad);
        ypath=-xpath*sin(AngleFlowRad)+ypath*cos(AngleFlowRad);
    end
    if SignMeanVpara<0
        xpath=nx-xpath+1; % For negative velocity!!!!!!!!!!!!!
    end

    % interpolation if max_gap_closing > 0
    if size(tpath,1)<tf-ti+1
        tpathi=(ti:tf)';
        xpathi=interp1(tpath,xpath,tpathi,MethodInterp);
        ypathi=interp1(tpath,ypath,tpathi,MethodInterp);
        lpathi=interp1(tpath,lpath,tpathi,MethodInterp);
        Apathi=interp1(tpath,Apath,tpathi,MethodInterp);
        ImaxGausspathi=interp1(tpath,ImaxGausspath,tpathi,MethodInterp);
        ImaxGaussCorrpathi=interp1(tpath,ImaxGaussCorrpath,tpathi,MethodInterp);
        IintGausspathi=interp1(tpath,IintGausspath,tpathi,MethodInterp);
        IintGaussCorrpathi=interp1(tpath,IintGaussCorrpath,tpathi,MethodInterp);
        IsumPixpathi=interp1(tpath,IsumPixpath,tpathi,MethodInterp);
        IsumPixCorrpathi=interp1(tpath,IsumPixCorrpath,tpathi,MethodInterp);

        tpath=tpathi; xpath=xpathi; ypath=ypathi; lpath=lpathi; Apath=Apathi;
        ImaxGausspath=ImaxGausspathi; ImaxGaussCorrpath=ImaxGaussCorrpathi;
        IintGausspath=IintGausspathi; IintGaussCorrpath=IintGaussCorrpathi;
        IsumPixpath=IsumPixpathi; IsumPixCorrpath=IsumPixCorrpathi;
    end

    ImaxGausspath=log(ImaxGausspath);
    ImaxGaussCorrpath=log(ImaxGaussCorrpath);
    IintGausspath=log(IintGausspath);
    IintGaussCorrpath=log(IintGaussCorrpath);
    IsumPixpath=log(IsumPixpath);
    IsumPixCorrpath=log(IsumPixCorrpath);

    if size(tpath,1)>1
        % displacements for the smallest time step
        I=(1:size(tpath,1)-1)'; J=(2:size(tpath,1))';
        dxpath=xpath(J)-xpath(I);
        dypath=ypath(J)-ypath(I);
        ImaxGauss=(ImaxGausspath(I)+ImaxGausspath(J))/2;
        ImaxGaussCorr=(ImaxGaussCorrpath(I)+ImaxGaussCorrpath(J))/2;
        dImaxGaussCorr=ImaxGaussCorrpath(J)-ImaxGaussCorrpath(I);
        IintGauss=(IintGausspath(I)+IintGausspath(J))/2;
        IintGaussCorr=(IintGaussCorrpath(I)+IintGaussCorrpath(J))/2;
        dIintGaussCorr=IintGaussCorrpath(J)-IintGaussCorrpath(I);
        IsumPix=(IsumPixpath(I)+IsumPixpath(J))/2;
        IsumPixCorr=(IsumPixCorrpath(I)+IsumPixCorrpath(J))/2;
        dIsumPixCorr=IsumPixCorrpath(J)-IsumPixCorrpath(I);

        Disp_X_Y_LogI{j,1}=[tpath(I) dxpath dypath ImaxGaussCorrpath(I)...
            ImaxGaussCorr dImaxGaussCorr IintGaussCorrpath(I)...
            IintGaussCorr dIintGaussCorr IsumPixCorrpath(I) IsumPixCorr...
            dIsumPixCorr];

        % displacements for differents time steps
        if strcmpi(Method_Intensity,'max_gaussian')==1
            LogInt=ImaxGaussCorrpath;
        elseif strcmpi(Method_Intensity,'int_gaussian')==1
            LogInt=IintGaussCorrpath;
        elseif strcmpi(Method_Intensity,'sum_pixels')==1
            LogInt=IsumPixCorrpath;
        end
        LogInt=real(LogInt);

        time=tpath; positions=[xpath ypath LogInt];
        [PosDisp,DeltaTime]=Traj2AllDisp_TSfix(time,positions);
        for l=1:length(DeltaTime)
            Disp_X_Y_LogI_TS{j,l}=PosDisp{l};
        end

        ntraj=Ntraj*ones(size(tpath,1),1);
        Trajectories{j,1}=[ntraj tpath xpath xpath LogInt lpath Apath];
%         time_SI=tpath/FrameRate;
%         x_SI=xpath/Scale; y_SI=ypath/Scale;
%         l_SI=lpath/Scale; A_SI=Apath/Scale^2;
%         TrajectoryAll{j,1}=[ntraj time_SI x_SI y_SI LogInt l_SI A_SI];
        Ntraj = Ntraj + 1;

    end

end
Trajectories=vertcat(Trajectories{:});
Disp_X_Y_LogI=vertcat(Disp_X_Y_LogI{:});
I = (Disp_X_Y_LogI(:,5)>0 | Disp_X_Y_LogI(:,8)>0 | Disp_X_Y_LogI(:,11)>0);
Disp_X_Y_LogI=Disp_X_Y_LogI(I==1,:);
Disp_X_Y_LogI_TimeStepOneMovie=cell(1,MaxNp); Npart_TS=zeros(5,MaxNp);
for j = 1 : MaxNp
    Disp_X_Y_LogI_TimeStepOneMovie{j}=vertcat(Disp_X_Y_LogI_TS{:,j});
    MeanLogInt=mean(Disp_X_Y_LogI_TimeStepOneMovie{j}(:,[3 6 9]),1);
    Npart_TS(:,j)=[j;size(Disp_X_Y_LogI_TimeStepOneMovie{j},1);MeanLogInt'];
end

% Keep only what you need
clearvars -except MatFileTrajectories Disp_X_Y_LogI_TimeStepOneMovie...
    Npart_TS FrameRate Scale Trajectories MaxNp Ntau_fix Nclass

%% Mean quantity calculation for several time steps
if Ntau_fix == 0
    Ntau_fix = MaxNp;
end
Ntau = min(Ntau_fix,MaxNp);
Treshold=0.999;
ListColMean=[1 2 3;4 5 6;7 8 9]; nc=size(ListColMean,2);
ColX=1; ColY=2; ColInt=3; ColdX=4; ColdY=5; ColdInt=6;
MeanStd_MeanDisp_TimeStep=cell(nc,1);
for c = 1 : nc
   
   MeanSt_MeanDisp=zeros(Nclass-1,13,Ntau);
   for t = 1 : Ntau
       
       MeanDisp=Disp_X_Y_LogI_TimeStepOneMovie{t}(:,[ListColMean(c,:) 10 11 12]);
       MeanDisp=sortrows(MeanDisp,ColInt);
%        [Iinf,Isup]=Decil(MeanDisp(:,ColInt),1-Treshold,Treshold);
       Ilimits = quantile(MeanDisp(:,ColInt),[1-Treshold,Treshold]);
       Iinf = Ilimits(1); Isup = Ilimits(2);
       IntLim=linspace(Iinf,Isup,Nclass+1); IntLim(end)=Isup;
       [~,linf]=min(abs(MeanDisp(:,ColInt)-IntLim(1)));
       
       for i = 1 : Nclass
           
           lsup=linf;
           while MeanDisp(lsup,ColInt) < IntLim(i+1)
               lsup=lsup+1;
           end
           
           MeanSt_MeanDisp(i,1,t)=lsup-linf+1;
           MeanSt_MeanDisp(i,2,t)=mean(MeanDisp(linf:lsup,ColX));
           MeanSt_MeanDisp(i,3,t)=std(MeanDisp(linf:lsup,ColX));
           MeanSt_MeanDisp(i,4,t)=mean(MeanDisp(linf:lsup,ColdX));
           MeanSt_MeanDisp(i,5,t)=std(MeanDisp(linf:lsup,ColdX));
           MeanSt_MeanDisp(i,6,t)=mean(MeanDisp(linf:lsup,ColY));
           MeanSt_MeanDisp(i,7,t)=std(MeanDisp(linf:lsup,ColY));
           MeanSt_MeanDisp(i,8,t)=mean(MeanDisp(linf:lsup,ColdY));
           MeanSt_MeanDisp(i,9,t)=std(MeanDisp(linf:lsup,ColdY));
           MeanSt_MeanDisp(i,10,t)=mean(MeanDisp(linf:lsup,ColInt));
           MeanSt_MeanDisp(i,11,t)=std(MeanDisp(linf:lsup,ColInt));
           MeanSt_MeanDisp(i,12,t)=mean(MeanDisp(linf:lsup,ColdInt));
           MeanSt_MeanDisp(i,13,t)=std(MeanDisp(linf:lsup,ColdInt));
           
           linf=lsup;
           
       end
       
       MeanStd_MeanDisp_TimeStep{c}=MeanSt_MeanDisp;
       
   end
   
end


% t=1;
% c=1; 
% LogIi=MeanStd_MeanDisp_TimeStep{c}(:,10,t);
% DeltaX_Ii=MeanStd_MeanDisp_TimeStep{c}(:,4,t);
% Ni=MeanStd_MeanDisp_TimeStep{c}(:,1,t);
% c=3;
% LogIm=MeanStd_MeanDisp_TimeStep{c}(:,10,t);
% DeltaX_Im=MeanStd_MeanDisp_TimeStep{c}(:,4,t);
% Nm=MeanStd_MeanDisp_TimeStep{c}(:,1,t);
% 
% pI=polyfitweighted(LogIi,DeltaX_Ii,1,Ni); LogIi0=-pI(2)/pI(1);
% pM=polyfitweighted(LogIm,DeltaX_Im,1,Nm); LogIm0=-pM(2)/pM(1);

end
