function [] = VelocityProfilesMultiMovies_function(MainFolder,II,Method_Intensity,Output_Folder_Name,SaveFig)

scrsz=get(0,'ScreenSize'); % Problems if you change your screen
scrsz2=[(scrsz(3)-scrsz(4))/2 scrsz(2) scrsz(4) scrsz(4)];
UnitsSpace='$\mu$m';
UnitsTime='s';
UnitsVelocity=[UnitsSpace '.' UnitsTime '$^{-1}$'];

if exist([MainFolder filesep Output_Folder_Name])==0
    mkdir([MainFolder filesep Output_Folder_Name])
end

d=dir([MainFolder filesep 'Results']); 
ListSubFolders = d([d(:).isdir]==1);
ListSubFolders = ListSubFolders(~ismember({ListSubFolders(:).name},{'.','..'}));
Infos=zeros(size(ListSubFolders,1),2);
clear d
for i=1:size(ListSubFolders)
    
    Name=ListSubFolders(i).name;
    Infos(i,1)=ListSubFolders(i).isdir;
    
    I=strfind(Name,'-');
    if isempty(I)==0 && Infos(i,1)==1;
        Infos(i,2)=str2double(Name(1:I(1)-1)); % Movie number
    else
        Infos(i,2)=NaN;
    end
    
end


Nfiles=length(II); FinalSubFolderList=cell(Nfiles,1); FinalInfos=Infos(II,:);
for i=1:Nfiles
    FinalSubFolderList{i}=ListSubFolders(II(i)).name;
end
MovieNumbers=num2str(horzcat(Infos(II,2)'));
I=find(isspace(MovieNumbers)==0); MovieNumbers=MovieNumbers(I);

%% Parameters for particle detection
FileFormat='.mat';
% Filtering (optionnal)
Filtering=2; MinPixel=1; MaxPixel=10;

% RegionProps detection
GaussBlur=0; ThresholdPart=10; Method=3; AirMinDetection=10;

% 2D gaussian fit
TolArea=4;

%% Builds trajectories
% Particle selection
ROI='full';
AirInf=30; AirSup=400;
ImaxInf=6; Rmin=1.5;
ErrorPos=5;

% Build trajectories
ColXpos=2; ColYpos=3;
max_linking_distance_Xn = -3;
max_linking_distance_Xp = 43;
max_linking_distance_Yn = -12;
max_linking_distance_Yp = 12;
max_gap_closing = 0;

% Trajectory selection
Dmin=10; Tmin=5; Tmax=250; Lmin=3;

%% Data import
if strcmpi(Method_Intensity,'max_gaussian')==1
    FolderResults=[MainFolder filesep Output_Folder_Name filesep 'Results' MovieNumbers filesep 'MaxGaussian'];
elseif strcmpi(Method_Intensity,'int_gaussian')==1
    FolderResults=[MainFolder filesep Output_Folder_Name filesep 'Results' MovieNumbers filesep 'IntGaussian'];
elseif strcmpi(Method_Intensity,'sum_pixels')==1
    FolderResults=[MainFolder filesep Output_Folder_Name filesep 'Results' MovieNumbers filesep 'SumPixels'];
end
if exist(FolderResults,'dir')==0
    mkdir(FolderResults);
end


AngleCorrection=1; MethodInterpInt='linear';
VelocityIntensityAll=cell(Nfiles,1); Angles=zeros(Nfiles,2);
Scales=zeros(Nfiles,1); FrameRates=zeros(Nfiles,1);
PosVelocity_TimeStep=cell(Nfiles,1); NpartVelocities=cell(Nfiles,2);
MeanStdIntVxVyAll_Repro=cell(Nfiles,1); TrackingParameters=zeros(Nfiles,5);
InfosFile=cell(Nfiles,1);
for i=1:Nfiles
    
    PathName=[MainFolder filesep 'Results' filesep FinalSubFolderList{i}];
    
    % Find files with trajectories
    %     MatFileTrajectories=TIRF_FindMatFileTrajectories(PathName,...
    %         Filtering,MinPixel,MaxPixel,GaussBlur,ThresholdPart,Method,AirMinDetection,...
    %         TolArea,AirInf,AirSup,ErrorPos,ImaxInf,Rmin,max_linking_distance_Xn,...
    %         max_linking_distance_Xp,max_linking_distance_Yn,...
    %         max_linking_distance_Yp,max_gap_closing,Dmin,Tmin,Tmax,Lmin);
    
    MatFileTrajectories=FindUniqueFileList(PathName,'.mat','Trajectories');
    
    % Load trajectories
    load(MatFileTrajectories);
    SignMeanVpara=sign(mean(VelocityIntensity(:,1)));
    if AngleCorrection==1
        Vx=VelocityIntensity(:,1); Vy=VelocityIntensity(:,2);
        %         AngleFlowRad=atan(mean(Vy./Vx));
        p=polyfit(Vx,Vy,1);
        AngleFlowRad=atan(p(1)); Angles(i,:)=[AngleFlowRad AngleFlowRad*180/pi];
    elseif AngleCorrection==2
        Vx=VelocityIntensity(:,1); Vy=VelocityIntensity(:,2);
        nv=length(Vx);
        np=1000; ng=fix(nv/np); MaxVxVy=zeros(ng,1);
        Index=round(linspace(1,nv,ng+1));
        for j=1:ng
            VxLoc=Vx(Index(j):Index(j+1)); VyLoc=Vy(Index(j):Index(j+1));
            [hist_vx,I_bins_vx]=hist(VxLoc,round(sqrt(length(VxLoc))));
            p=polyfit(I_bins_vx,hist_vx,6); hist_vx_fit=polyval(p,I_bins_vx);
            [hist_vy,I_bins_vy]=hist(VyLoc,round(sqrt(length(VyLoc))));
            p=polyfit(I_bins_vy,hist_vy,6); hist_vy_fit=polyval(p,I_bins_vy);
            [~,I]=max(hist_vx_fit); [~,J]=max(hist_vy_fit);
            MaxVxVy(j)=I_bins_vy(J)/I_bins_vx(I);
        end
        AngleFlowRad=mean(atan(MaxVxVy)); Angles(i,:)=[AngleFlowRad AngleFlowRad*180/pi];
    end
    
    % Find informations
    Scale=22.9; % OPTIONAL! BE CAREFUL WITH THE MICROSCOPE MAGNIFICATION!!!
    [InfosFile{i},ColumnNames]=FindInformationsFromName(PathName,'matrix');
    FrameRate=InfosFile{i}(4);
    
    % For each trajectory
    Npath=size(PathsParticles,1); MaxNp=max(PathsParticles(:,3))-1;
    PosVelocityTS=cell(Npath,MaxNp); VelocityIntensity=cell(Npath,1);
    for j=1:Npath
        
        k=PathsParticles(j,end); PathPart=Paths{k,1};
        
        Index=(PathPart(:,7)>0 & PathPart(:,12)>0);
        PathPart=PathPart(Index==1,:);
        
        tpath=PathPart(:,1); ti=tpath(1,1); tf=tpath(end,1);
        xpath=PathPart(:,2); ypath=PathPart(:,3);
        ImaxGausspath=PathPart(:,6); ImaxGaussCorrpath=PathPart(:,7);
        IintGausspath=2*pi*PathPart(:,4).^2.*PathPart(:,6);
        IintGaussCorrpath=2*pi*PathPart(:,4).^2.*PathPart(:,7);
        IsumPixpath=PathPart(:,10).*PathPart(:,11);
        IsumPixCorrpath=PathPart(:,10).*PathPart(:,12);
        
        if AngleCorrection>0
            xpath=xpath*cos(AngleFlowRad)+ypath*sin(AngleFlowRad);
            ypath=xpath*sin(AngleFlowRad)-ypath*cos(AngleFlowRad);
        end
        if SignMeanVpara<0
            xpath=nx-xpath+1; % For negative velocity!!!!!!!!!!!!!
        end
        
        % interpolation if max_gap_closing > 0
        if size(tpath,1)<tf-ti+1
            tpathi=(ti:tf)';
            xpathi=interp1(tpath,xpath,tpathi,MethodInterpInt);
            ypathi=interp1(tpath,ypath,tpathi,MethodInterpInt);
            ImaxGausspathi=interp1(tpath,ImaxGausspath,tpathi,MethodInterpInt);
            ImaxGaussCorrpathi=interp1(tpath,ImaxGaussCorrpath,tpathi,MethodInterpInt);
            IintGausspathi=interp1(tpath,IintGausspath,tpathi,MethodInterpInt);
            IintGaussCorrpathi=interp1(tpath,IintGaussCorrpath,tpathi,MethodInterpInt);
            IsumPixpathi=interp1(tpath,IsumPixpath,tpathi,MethodInterpInt);
            IsumPixCorrpathi=interp1(tpath,IsumPixCorrpath,tpathi,MethodInterpInt);
            
            tpath=tpathi; xpath=xpathi; ypath=ypathi;
            ImaxGausspath=ImaxGausspathi; ImaxGaussCorrpath=ImaxGaussCorrpathi;
            IintGausspath=IintGausspathi; IintGaussCorrpath=IintGaussCorrpathi;
            IsumPixpath=IsumPixpathi; IsumPixCorrpath=IsumPixCorrpathi;
        end
        
        % Intensity selection
        if strcmpi(Method_Intensity,'max_gaussian')==1
            LogInt=log(ImaxGaussCorrpath);
        elseif strcmpi(Method_Intensity,'int_gaussian')==1
            LogInt=log(IintGaussCorrpath);
        elseif strcmpi(Method_Intensity,'sum_pixels')==1
            LogInt=log(IsumPixCorrpath);
        end
        
        if size(tpath,1)>1
            vxpath=diff(xpath); vypath=diff(ypath);
            I=(1:size(tpath,1)-1)'; J=(2:size(tpath,1))';
            ImaxGauss=(ImaxGausspath(I)+ImaxGausspath(J))/2;
            ImaxGaussCorr=(ImaxGaussCorrpath(I)+ImaxGaussCorrpath(J))/2;
            IintGauss=(IintGausspath(I)+IintGausspath(J))/2;
            IintGaussCorr=(IintGaussCorrpath(I)+IintGaussCorrpath(J))/2;
            IsumPix=(IsumPixpath(I)+IsumPixpath(J))/2;
            IsumPixCorr=(IsumPixCorrpath(I)+IsumPixCorrpath(J))/2;
            
            VelocityIntensity{j,1}=[vxpath vypath ImaxGauss ImaxGaussCorr IintGauss IintGaussCorr IsumPix IsumPixCorr];
        end
        
        LogInt=real(LogInt);
        
        % Velocities for differents time steps
        time=tpath/FrameRate; positions=[xpath/Scale ypath/Scale LogInt];
        [PosVelocities,DeltaTime]=Traj2Velocities_TS(time,positions);
        for k=1:length(DeltaTime)
            PosVelocityTS{j,k}=PosVelocities{k};
        end
        
    end
    
    VelocityIntensity=vertcat(VelocityIntensity{:});
    I=find(VelocityIntensity(:,4)>0 | VelocityIntensity(:,6)>0 | ...
        VelocityIntensity(:,8)>0);
    VelocityIntensity=VelocityIntensity(I,:);
    
    PosVelocityTSallpath=cell(1,MaxNp); Npart=zeros(1,MaxNp);
    for j=1:MaxNp
        PosVelocityTSallpath{j}=vertcat(PosVelocityTS{:,j});
        Npart(j)=size(PosVelocityTSallpath{j},1);
    end
    clear PosVelocityTS
    PosVelocity_TimeStep{i}=PosVelocityTSallpath;
    NpartVelocities{i,1}=Npart; NpartVelocities{i,2}=MaxNp;
    clear PosVelocityTSallpath Npart
    
    VelocityIntensity(:,1:2)=VelocityIntensity(:,1:2).*FrameRate/Scale;
    
    Scales(i)=Scale; FrameRates(i)=FrameRate;
    VelocityIntensityAll{i}=VelocityIntensity;
    
    MeanStdIntVxVyAll_Repro{i,1}=MeanStdIntVxVyAll;
    TrackingParameters(i,1)=max_linking_distance_Xn;
    TrackingParameters(i,2)=max_linking_distance_Xp;
    TrackingParameters(i,3)=max_linking_distance_Yn;
    TrackingParameters(i,4)=max_linking_distance_Yp;
    TrackingParameters(i,5)=max_gap_closing;
    
    disp(['Movie ' num2str(i) '/' num2str(Nfiles) ' ' FinalSubFolderList{i} ' done'])
    
end
InfosFile=vertcat(InfosFile{:});

clearvars -except scrsz scrsz2 MainFolder ListSubFolders Infos...
    FolderResults MovieNumbers Nfiles FinalSubFolderList FinalInfos...
    FileName VelocityIntensityAll Scales FrameRates UnitsSpace UnitsTime...
    Filtering MinPixel MaxPixel GaussBlur ThresholdPart Method...
    AirMinDetection TolArea ROI AirInf AirSup ErrorPos ImaxInf Rmin ColXpos ColYpos...
    max_linking_distance_Xn max_linking_distance_Xp max_linking_distance_Yn...
    max_linking_distance_Yp max_gap_closing Dmin Tmin Tmax Lmin...
    UnitsVelocity PosVelocity_TimeStep NpartVelocities...
    MeanStdIntVxVyAll_Repro TimeStepMax TrackingParameters MaxDistTracking...
    MaxGapClosing Method_Intensity MethodInterpInt InfosFile

%% Figure for reproducibility
Fig=figure('name','Reproducibility for different videos','NumberTitle','off');
set(gcf,'Position',scrsz); Legends=cell(Nfiles,1); FontSize=12;
LW=1.5; MS=8; Colors=jet(Nfiles); FactorAR=4/3;
Rows=[1 2 3]; Cols=[7 2 5 3]; row=length(Rows); col=length(Cols);
LabelsAbs=cell(4,1); LabelsAbs{1}='$\log I_{mg}$'; LabelsAbs{2}='$\log I_{ig}$'; LabelsAbs{3}='$\log I_{sp}$';
LabelsOrd=cell(4,1); LabelsOrd{1}='$N_{part}$';
LabelsOrd{2}='$v_{\parallel}$ (px/frame)'; LabelsOrd{3}='$\sigma_{\parallel}$ (px/frame)';
LabelsAbs{4}='$\log I_{mg}$'; LabelsOrd{4}='$v_{\perp}$ (px/frame)';
for r=1:row
    for c=1:col
        subplot(row,col,c+(r-1)*col); hold on;
        for i=1:Nfiles
            
            Abs=MeanStdIntVxVyAll_Repro{i,1}{Rows(r),1}(:,1);
            Ord=MeanStdIntVxVyAll_Repro{i,1}{Rows(r),1}(:,Cols(c));
            plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
            
            if i==1
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
            end
            
            Legends{i}=['Video ' num2str(FinalInfos(i,2))];
            
        end
        axis([MinAbs MaxAbs MinOrd MaxOrd]);
        Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
        if mod(c,col)==1
            LegendLocation='South';
            leg=legend(Legends{:},'Location',LegendLocation); set(gca,'yscale','log');
            set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
        end
        MyFigStyleLaTeXSave(LabelsAbs{r},LabelsOrd{c},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    end
end

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'Repro_Videos' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'Repro_Videos' MovieNumbers], '-pdf');
    close(Fig);
end

%% Figure for diffusion anisotropy reproducibility
ExpPe=2; Lc=100e-3; % Characteristic Length = particle diameter
Ttiles=cell(3,1); Titles{1}='max Gaussian';
Titles{2}='int Gaussian';  Titles{3}='sum pixels';
Fig=figure('name','Reproducibility for different videos','NumberTitle','off');
set(gcf,'Position',scrsz);
Legends=cell(Nfiles,1); FontSize=12;
LW=1; MS=8; Colors=jet(Nfiles); FactorAR=4/3;
row=1; col=3;
for c=1:3
    subplot(row,col,c); hold on;
    for i=1:Nfiles
        
        U=MeanStdIntVxVyAll_Repro{i,1}{c,1}(:,2)*FrameRates(i)/Scales(i);
        Dx=MeanStdIntVxVyAll_Repro{i,1}{c,1}(:,5).^2*FrameRates(i)/Scales(i)^2;
        Dy=MeanStdIntVxVyAll_Repro{i,1}{c,1}(:,6).^2*FrameRates(i)/Scales(i)^2;
        Pe=Lc*U./Dy; Abs=Pe.^ExpPe; Ord=Dx./Dy-1;
        
        plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors(i,:),'MarkerEdgeColor','black');
        
        if i==1
            MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
            if max(Abs)<inf
                MaxAbs=max(Abs)
            else
                MaxAbs = 1;
            end
        else
            MinAbs=min(MinAbs,min(Abs));
            if max(Abs)<inf
                MaxAbs=max(MaxAbs,max(Abs))
            end
            MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
        end
        disp(Abs')
        Legends{i}=['Video ' num2str(FinalInfos(i,2))];
        
    end
    axis([MinAbs MaxAbs MinOrd MaxOrd]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    LegendLocation='SouthEast';
    leg=legend(Legends{:},'Location',LegendLocation);
    set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    MyFigStyleLaTeXSave(['$Pe^' num2str(ExpPe) '$'],'$D_{\parallel}/D_{\perp}-1$',0,Titles{c},0,0,[1 FactorAR*AR 1],FontSize);
end

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'ReproAD_Videos' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'ReproAD_Videos' MovieNumbers], '-pdf');
    close(Fig);
end

%% Control velocity distribution and tracking parameters
Fig=figure('name','Global velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); LW=1.5; MS=6; row=1; col=2; Legends=cell(Nfiles,1);
Colors=jet(Nfiles); FactorAR=4/3; FontSize=12;
LabelsAbs=cell(2,1); LabelsAbs{1}='$\Delta l_{\parallel}$'; LabelsAbs{2}='$\Delta l_{\perp}$';
LabelsOrd=cell(2,1); LabelsOrd{1}='$P\left(\Delta l_{\parallel}\right)$';
LabelsOrd{2}='$P\left(\Delta l_{\perp}\right)$'; LegendLocation='NorthEast';
for j=1:2
    subplot(row,col,j); hold on;
    for i=1:Nfiles
        
        datahist=VelocityIntensityAll{i,1}(:,j)*Scales(i)/FrameRates(i);
        [bin,center]=hist(datahist,fix(sqrt(size(datahist,1))));
        Abs=center; Ord=bin;
        %     Ord=bin/(sum(bin)*mean(diff(Abs)));
        plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
        
        if i==1
            MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
        else
            MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
            MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
        end
        
        Legends{i}=['Video ' num2str(FinalInfos(i,2))];
        
    end
    MaxAbs=MaxAbs+1; MinAbs=MinAbs-1;
    set(gca,'yscale','log'); axis([MinAbs MaxAbs MinOrd MaxOrd]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    MyFigStyleLaTeXSave(LabelsAbs{j},LabelsOrd{j},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    leg=legend(Legends{:},'Location',LegendLocation); set(gca,'yscale','log');
    set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    
end

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'ReproPDF-Track_Videos' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'ReproPDF-Track_Videos' MovieNumbers], '-pdf');
    close(Fig);
end

%% Build particle number and velocities
MaxNpartTot=max(vertcat(NpartVelocities{:,2}));
NpartAll=zeros(Nfiles,MaxNpartTot);
PosVelocity_TimeStepAll=cell(Nfiles,MaxNpartTot);
for i=1:Nfiles
    
    Npart=NpartVelocities{i,1}; cmax=NpartVelocities{i,2};
    NpartAll(i,1:cmax)=Npart;
    
    for j=1:length(PosVelocity_TimeStep{i,1})
        PosVelocity_TimeStepAll{i,j}=PosVelocity_TimeStep{i,1}{1,j};
    end
    
end
NpartTotal=zeros(MaxNpartTot,2);
NpartTotal(:,1)=(1:MaxNpartTot)'/unique(FrameRates);
NpartTotal(:,2)=sum(NpartAll)';

PosVelocity_TimeStepTot=cell(1,MaxNpartTot);
for j=1:MaxNpartTot
    PosVelocity_TimeStepTot{j}=vertcat(PosVelocity_TimeStepAll{:,j});
end
clear PosVelocity_TimeStepAll PosVelocity_TimeStep

%% Global velocity profiles
Fig=figure('name','Global velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); LegendLocation='South';
index=[1 2 5 10 20]; n=length(index); FontSize=10;
Legends=cell(n,1); FactorAR=4/3; row=2; col=3; LW=1.5; MS=5;
Colors=[linspace(1,0,n)' zeros(n,1) linspace(0,1,n)'];

LabelsAbs=cell(3,1); LabelsAbs{1}=['$\Delta l_{\parallel}$ (' UnitsSpace ')'];
LabelsAbs{2}=['$\Delta l_{\perp}$ (' UnitsSpace ')']; LabelsAbs{3}=['$\Delta \log I$'];
LabelsOrd=cell(3,1); LabelsOrd{1}='$P\left(\Delta l_{\parallel}\right)$';
LabelsOrd{2}='$P\left(\Delta l_{\perp}\right)$'; LabelsOrd{3}='$P\left(\Delta \log I\right)$';
for p=1:3
    
    subplot(row,col,p); hold on;
    for l=1:n
        i=index(l);
        [bin,center]=hist(real(PosVelocity_TimeStepTot{i}(:,p+3)),fix(sqrt(size(PosVelocity_TimeStepTot{i},1))));
        Abs=center;
        Ord=bin/(sum(bin)*mean(diff(Abs)));
        plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(l,:));
        Legends{l}=['$\tau=' num2str(NpartTotal(i,1)*1e3) '$ ms'];
        
        if l==1
            MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
        else
            MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
            MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
        end
    end
    set(gca,'yscale','log');
    axis([MinAbs MaxAbs MinOrd MaxOrd]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    if p==3
        leg=legend(Legends{:},'Location',LegendLocation);
        set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    end
    MyFigStyleLaTeXSave(LabelsAbs{p},LabelsOrd{p},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    
end

LabelsAbs=cell(3,1);
LabelsAbs{1}=['$\Delta \tilde{l}_{\parallel}=\frac{\Delta l_{\parallel}-\left<\Delta l_{\parallel}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{1/2}$)'];
LabelsAbs{2}=['$\Delta \tilde{l}_{\perp}=\frac{\Delta l_{\perp}-\left<\Delta l_{\perp}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{1/2}$)'];
LabelsAbs{3}=['$\Delta \tilde{I}=\frac{\Delta \log I-\left<\log I\right>}{\sqrt{\tau}}$'];
LabelsOrd=cell(3,1); LabelsOrd{1}='$P\left(\Delta \tilde{l}_{\parallel}\right)$';
LabelsOrd{2}='$P\left(\Delta \tilde{l}_{\perp}\right)$'; LabelsOrd{3}='$P\left(\Delta \tilde{I}\right)$';
for p=1:3
    
    subplot(row,col,p+3); hold on;
    for l=1:n
        i=index(l);
        [bin,center]=hist(PosVelocity_TimeStepTot{i}(:,p+3)-mean(PosVelocity_TimeStepTot{i}(:,p+3)),fix(sqrt(size(PosVelocity_TimeStepTot{i},1))));
        Abs=center/sqrt(NpartTotal(i,1));
        Ord=bin/(sum(bin)*mean(diff(Abs)));
        plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(l,:));
        Legends{l}=['$\tau=' num2str(NpartTotal(i,1)*1e3) '$ ms'];
        
        if l==1
            MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
        else
            MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
            MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
        end
    end
    set(gca,'yscale','log');
    axis([MinAbs MaxAbs MinOrd MaxOrd]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    %     if p==3
    %         leg=legend(Legends{:},'Location',LegendLocation);
    %         set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
    %     end
    MyFigStyleLaTeXSave(LabelsAbs{p},LabelsOrd{p},0,0,0,0,[1 FactorAR*AR 1],FontSize);
    
end

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'GlobalPDFtot' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'GlobalPDFtot' MovieNumbers], '-pdf');
    close(Fig);
end

%% Distributions and PDFs versus distance from surface
% With method 2 log I = cst
NpartMin=2e3;
i=1; while NpartTotal(i,2)>NpartMin; i=i+1; end; Ntau=i;
Nclass=20; ColLogI=3; ColVpara=4; ColVperp=5; ColVwall=6; Treshold=0.999; N=1.5;
PDF_Pos_TS=cell(Nclass,Ntau); MeanStdIntCorrVxVy_TS=cell(1,Ntau);
for t=1:Ntau
    
    Positions=PosVelocity_TimeStepTot{t}; Positions=sortrows(Positions,ColLogI);
    [Iinf,Isup]=Decil(Positions(:,ColLogI),1-Treshold,Treshold);
    IntLim=linspace(Iinf,Isup,Nclass+1); IntLim(end)=Isup;
    
    MeanStdIntCorrVxVy_TS{t}=zeros(Nclass-1,10);
    [~,linf]=min(abs(Positions(:,ColLogI)-IntLim(1)));
    for i=1:Nclass
        
        lsup=linf;
        while Positions(lsup,ColLogI)<IntLim(i+1) && lsup<size(Positions,1)
            lsup=lsup+1;
        end
        
        MeanStdIntCorrVxVy_TS{t}(i,1)=mean(Positions(linf:lsup,ColLogI)); % Mean Log I
        MeanStdIntCorrVxVy_TS{t}(i,2)=mean(Positions(linf:lsup,ColVpara)); % Mean Vpara
        MeanStdIntCorrVxVy_TS{t}(i,3)=mean(Positions(linf:lsup,ColVperp)); % Mean Vperp
        MeanStdIntCorrVxVy_TS{t}(i,4)=mean(Positions(linf:lsup,ColVwall)); % Mean Vz
        MeanStdIntCorrVxVy_TS{t}(i,5)=std(Positions(linf:lsup,ColLogI)); % Std log
        MeanStdIntCorrVxVy_TS{t}(i,6)=std(Positions(linf:lsup,ColVpara)); % Std Vpara
        MeanStdIntCorrVxVy_TS{t}(i,7)=std(Positions(linf:lsup,ColVperp)); % Std Vperp
        MeanStdIntCorrVxVy_TS{t}(i,8)=std(Positions(linf:lsup,ColVwall)); % Std Vz
        MeanStdIntCorrVxVy_TS{t}(i,9)=lsup-linf+1; % Npart
        MeanStdIntCorrVxVy_TS{t}(i,10)=NpartTotal(t,1); % Tau
        
        PDF_Pos_TS{i,t}=cell(4,1);
        [counts,centers] = hist(Positions(linf:lsup,ColLogI),fix(sqrt(lsup-linf+1)/N));
        PDF_Pos_TS{i,t}{1}=[centers' counts' counts'./(sum(counts)*mean(diff(centers)))];
        [counts,centers] = hist(Positions(linf:lsup,ColVpara),fix(sqrt(lsup-linf+1)/N));
        PDF_Pos_TS{i,t}{2}=[centers' counts' counts'./(sum(counts)*mean(diff(centers)))];
        [counts,centers] = hist(Positions(linf:lsup,ColVperp),fix(sqrt(lsup-linf+1)/N));
        PDF_Pos_TS{i,t}{3}=[centers' counts' counts'./(sum(counts)*mean(diff(centers)))];
        [counts,centers] = hist(Positions(linf:lsup,ColVwall),fix(sqrt(lsup-linf+1)/N));
        PDF_Pos_TS{i,t}{4}=[centers' counts' counts'./(sum(counts)*mean(diff(centers)))];
        
        linf=lsup;
        
    end
    
end

% Linear fit for parallel velocity profiles
% LogIinf=4; LogIsup=7;
ThresholdLogI=0.95;
[LogIinf,LogIsup]=Decil(MeanStdIntCorrVxVy_TS{1}(:,1),1-ThresholdLogI,ThresholdLogI);
CoefsFitsVpara_TS=zeros(Ntau,4);
for t=1:Ntau
    
    Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
    Ord=MeanStdIntCorrVxVy_TS{t}(:,2)/NpartTotal(t,1);
    
    %     [LogIinf,LogIsup]=Decil(Abs,1-ThresholdLogI,ThresholdLogI);
    I=find(Abs>=LogIinf & Abs<LogIsup);
    CoefsFitsVpara_TS(t,:)=[NpartTotal(t,1) NpartTotal(t,2) polyfit(Abs(I),Ord(I),1)];
    
end

%% Angle control
t=1; ExpPe=2; Lc=100e-3; % Characteristic Length = particle diameter
Fig=figure('name','Velocity profiles','NumberTitle','off');
FactorAR=4/3; FontSize=12; Colors=jet(Nfiles); SaveFig=1;
set(gcf,'Position',scrsz); row=2; col=3; LW=1.5; MS=8;

subplot(row,col,1); hold on; Col=2;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    SignV=sign(mean(MeanStdIntVxVyAll_Repro{i,1}{Rows(r),1}(:,Col)));
    Abs=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)*SignV*FrameRates(i)/Scales(i);
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
    
    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
Ord=MeanStdIntCorrVxVy_TS{t}(:,2)/NpartTotal(t,1);
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$v_{\parallel}$ (' UnitsVelocity ')'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,2); hold on; Col=3;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    Abs=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)*FrameRates(i)/Scales(i);
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
    
    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
Ord=MeanStdIntCorrVxVy_TS{t}(:,3)/NpartTotal(t,1);
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$v_{\perp}$ (' UnitsVelocity ')'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,4); hold on; Col=5;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    Abs=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)*FrameRates(i)/Scales(i);
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
    
    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
Ord=MeanStdIntCorrVxVy_TS{t}(:,6)/NpartTotal(t,1);
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$\sigma_{\parallel}$ (' UnitsVelocity ')'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,5); hold on; Col=6;
for i=1:Nfiles
    switch Method_Intensity
        case 'max_gaussian'
            Row=1;
        case 'int_gaussian'
            Row=2;
        case 'sum_pixels'
            Row=3;
    end
    Abs=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,1);
    Ord=MeanStdIntVxVyAll_Repro{i,1}{Row,1}(:,Col)*FrameRates(i)/Scales(i);
    plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
    
    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
Ord=MeanStdIntCorrVxVy_TS{t}(:,7)/NpartTotal(t,1);
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$\log I$',['$\sigma_{\perp}$ (' UnitsVelocity ')'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
subplot(row,col,[3 6]); hold on;
for i=1:Nfiles
    
    U=MeanStdIntVxVyAll_Repro{i,1}{c,1}(:,2)*FrameRates(i)/Scales(i);
    Dx=MeanStdIntVxVyAll_Repro{i,1}{c,1}(:,5).^2*FrameRates(i)/Scales(i)^2;
    Dy=MeanStdIntVxVyAll_Repro{i,1}{c,1}(:,6).^2*FrameRates(i)/Scales(i)^2;
    Pe=Lc*U./Dy; Abs=Pe.^ExpPe; Ord=Dx./Dy-1;
    
    plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(i,:));
    
    if i==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
    end
    
end
U=MeanStdIntCorrVxVy_TS{t}(:,2)/NpartTotal(t,1);
Dx=MeanStdIntCorrVxVy_TS{t}(:,6).^2/NpartTotal(t,1);
Dy=MeanStdIntCorrVxVy_TS{t}(:,7).^2/NpartTotal(t,1);
Peclet=Lc*U./Dy; Abs=Peclet.^ExpPe; Ord=(Dx./Dy-1);
plot(Abs,Ord,'o','LineWidth',LW*1.5,'MarkerSize',MS,'color','black');
MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
MyFigStyleLaTeXSave('$Pe^2$',['$D_{\parallel}/D_{\perp}-1$ (' UnitsVelocity ')'],0,0,0,0,[1 FactorAR*AR 1],FontSize);
mtit('Whit angle correction','Interpreter','none','FontName','Times New Roman');

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'AngleControl' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'AngleControl' MovieNumbers], '-pdf');
    close(Fig);
end


%% Figures for mean velocities versus z-position
Colors=[linspace(1,0,Ntau)' zeros(Ntau,1) linspace(0,1,Ntau)'];

SaveFig=1;
Fig=figure('name','Velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); row=1; col=2; LW=1.5; MS=8; FontSize=14;
FactorAR=4/3; PosLeft=0.05; PosRight=0.55; FactorSize=1.1;

s1=subplot(row,col,1); hold on;
for t=1:Ntau
    
    Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
    Ord=MeanStdIntCorrVxVy_TS{t}(:,2)/NpartTotal(t,1);
    p=CoefsFitsVpara_TS(t,3:4);
    plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
    plot(Abs,polyval(p,Abs),'-','LineWidth',LW,'color',Colors(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]);
caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; colormap(Colors);
MyFigStyleLaTeXSave('$\log I$',['$v_{\parallel}$ (' UnitsVelocity ')'],0,0,1,'$\tau$ (ms)',[1 FactorAR*AR 1],FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.2,Ax(3)+(Ax(4)-Ax(3))*0.2,['Fit for $' num2str(LogIinf) '<\log I<' num2str(LogIsup) '$'],...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','middle');

ax2=axes('Position',[.22 .59 .22 .22]); LW2=1.5; MS2=6;
semilogx(CoefsFitsVpara_TS(:,1)*1e3,CoefsFitsVpara_TS(:,3),'o','LineWidth',LW2,'MarkerSize',MS2,'color','black');
axis([min(CoefsFitsVpara_TS(:,1)*1e3) max(CoefsFitsVpara_TS(:,1)*1e3) min(CoefsFitsVpara_TS(:,3)) max(CoefsFitsVpara_TS(:,3))]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.01,Ax(3)+(Ax(4)-Ax(3))*0.7,'$p=\frac{\partial v_{\parallel}}{\partial \log I}$',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','middle');
text(Ax(1)+(Ax(2)-Ax(1))*0.98,Ax(3),'$\tau$ (ms)',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.98,'$p$',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);

s2=subplot(row,col,2); hold on;
for t=1:Ntau
    
    Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
    Ord=MeanStdIntCorrVxVy_TS{t}(:,9)/CoefsFitsVpara_TS(t,2);
    plot(Abs,Ord,'-o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
    
    if t==1
        MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
    else
        MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
        MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
    end
end
axis([MinAbs MaxAbs MinOrd MaxOrd]); set(gca,'yscale','log');
caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; colormap(Colors);
MyFigStyleLaTeXSave('$\log I$','$N_{part}/N_{tot}$',0,0,1,'$\tau$ (ms)',[1 FactorAR*AR 1],FontSize);

ax2=axes('Position',[.68 .33 .22 .22]); LW2=1.5; MS2=6; hold on; FontSize2=8;
plot(NpartTotal(:,1)*1e3,NpartTotal(:,2),'o','LineWidth',LW2,'MarkerSize',MS2,'color',0.5*[1 1 1]);
plot(CoefsFitsVpara_TS(:,1)*1e3,CoefsFitsVpara_TS(:,2),'o','LineWidth',LW2,'MarkerSize',MS2,'color','black');
set(gca,'yscale','log'); hold off;
axis([min(NpartTotal(:,1)*1e3) max(NpartTotal(:,1)*1e3) min(NpartTotal(:,2)) max(NpartTotal(:,2))]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3),'$\tau$ (ms)',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.3,'$N_{tot}$',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
line([1 1]*max(CoefsFitsVpara_TS(:,1))*1e3,[Ax(3) Ax(4)],'LineStyle','--','LineWidth',LW,'color','black');
text(max(CoefsFitsVpara_TS(:,1))*1e3,Ax(3),['$\tau_{max}=' num2str(max(CoefsFitsVpara_TS(:,1))*1e3) '$ ms'],'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','bottom','rotation',90);
line([Ax(1) Ax(2)],[1 1]*NpartMin,'LineStyle','--','LineWidth',LW,'color','black');
text(Ax(2),NpartMin,['$N_{min}=' num2str(NpartMin) '$'],'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');

s1Pos=get(s1,'Position'); s2Pos=get(s2,'Position');
s1Pos(1)=PosLeft; s2Pos(1)=PosRight;
s1Pos(3:4)=FactorSize*s1Pos(3:4); s2Pos(3:4)=FactorSize*s2Pos(3:4);
set(s1,'Position',s1Pos); set(s2,'Position',s2Pos);

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'MeanVpara_Npart_TS' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'MeanVpara_Npart_TS' MovieNumbers], '-pdf');
    close(Fig);
end

%% Figures for velocity distribution at all z-positions for few time steps
Index_TS=[1 4 10]; n=length(Index_TS); Treshold=0.99;
[Mindl,Maxdl]=Decil(PosVelocity_TimeStepTot{1}(:,3),1-Treshold,Treshold);
Nv=NpartTotal(1,2); Scale_LogI=linspace(Mindl,Maxdl,round(Nv))';
ColorsLogI=[linspace(0,74/255,round(Nv))' linspace(0,1,round(Nv))' zeros(round(Nv),1)];

LabelsAbs=cell(3,1);
LabelsAbs{1}=['$\Delta \tilde{l}_{\parallel}=\frac{\Delta l_{\parallel}-\left<\Delta l_{\parallel}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{2}=['$\Delta \tilde{l}_{\perp}=\frac{\Delta l_{\perp}-\left<\Delta l_{\perp}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{3}=['$\Delta \tilde{I}=\frac{\Delta \log I-\left<\log I\right>}{\sqrt{\tau}}$ (' UnitsTime '$^{-1/2}$)'];
LabelsOrd=cell(3,1); LabelsOrd{1}='$P\left(\Delta \tilde{l}_{\parallel}\right)$';
LabelsOrd{2}='$P\left(\Delta \tilde{l}_{\perp}\right)$'; LabelsOrd{3}='$P\left(\Delta \tilde{I}\right)$';

SaveFig=1;
Fig=figure('name','Velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); row=3; col=n; FontSize=12; FactorAR=5/3; LW=1; MS=5;
for i=1:n
    t=Index_TS(i);
    for d=2:4
        subplot(row,col,i+col*(d-2)); hold on;
        for z=1:Nclass
            Abs=(PDF_Pos_TS{z,t}{d}(:,1)-MeanStdIntCorrVxVy_TS{t}(z,d))/sqrt(NpartTotal(t));
            Ord=PDF_Pos_TS{z,t}{d}(:,3)*sqrt(NpartTotal(t));
            [~,I]=min(abs(Scale_LogI(:,1)-MeanStdIntCorrVxVy_TS{t}(z,1)));
            plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
            if z==1
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
            end
        end
        % MinAbs=-MaxAbsFix; MaxAbs=MaxAbsFix;
        set(gca,'yscale','log');
        MaxAbs=min(abs(MinAbs),MaxAbs); MinAbs=-MaxAbs;
        %axis([MinAbs MaxAbs MinOrd MaxOrd]);
        colormap(ColorsLogI);
        Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; caxis([Mindl Maxdl]);
        MyFigStyleLaTeXSave(LabelsAbs{d-1},LabelsOrd{d-1},0,['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'],1,'$\left<\log I\right>$',[1 FactorAR*AR 1],FontSize);
    end
end

Index_TS_str=num2str(Index_TS); Index_TS_str(Index_TS_str==' ')=[];
if SaveFig==1
    saveas(Fig,[FolderResults filesep 'PDF_allZ_IndTS' Index_TS_str '_' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'PDF_allZ_IndTS' Index_TS_str '_' MovieNumbers], '-pdf');
    close(Fig);
end

%% Figures for velocity distribution at all time steps for few z-positions
Index_Z=[20 11 2]; n=length(Index_Z);
TimeStepsFig=(1:10); nt=length(TimeStepsFig);
nc=1000; Scale_tau=linspace(NpartTotal(TimeStepsFig(1)),NpartTotal(TimeStepsFig(nt)),nc)';
Colors=[linspace(1,0,nc)' zeros(nc,1) linspace(0,1,nc)'];
LabelsAbs=cell(3,1);
LabelsAbs{1}=['$\Delta \tilde{l}_{\parallel}=\frac{\Delta l_{\parallel}-\left<\Delta l_{\parallel}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{2}=['$\Delta \tilde{l}_{\perp}=\frac{\Delta l_{\perp}-\left<\Delta l_{\perp}\right>}{\sqrt{\tau}}$ (' UnitsSpace '.' UnitsTime '$^{-1/2}$)'];
LabelsAbs{3}=['$\Delta \tilde{I}=\frac{\Delta \log I-\left<\log I\right>}{\sqrt{\tau}}$ (' UnitsTime '$^{-1/2}$)'];
LabelsOrd=cell(3,1); LabelsOrd{1}='$P\left(\Delta \tilde{l}_{\parallel}\right)$';
LabelsOrd{2}='$P\left(\Delta \tilde{l}_{\perp}\right)$'; LabelsOrd{3}='$P\left(\Delta \tilde{I}\right)$';

SaveFig=1;
Fig=figure('name','Velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); row=3; col=n; FontSize=10; FactorAR=5/3; LW=1; MS=5;
for i=1:n
    z=Index_Z(i);
    for d=2:4
        subplot(row,col,i+col*(d-2)); hold on;
        for j=1:nt
            t=TimeStepsFig(j);
            Abs=(PDF_Pos_TS{z,t}{d}(:,1)-MeanStdIntCorrVxVy_TS{t}(z,d))/sqrt(NpartTotal(t));
            Ord=PDF_Pos_TS{z,t}{d}(:,3)*sqrt(NpartTotal(t));
            [~,I]=min(abs(Scale_tau(:,1)-NpartTotal(t)));
            plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(I,:));
            if j==1
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
                MinLogI=MeanStdIntCorrVxVy_TS{t}(z,1); MaxLogI=MeanStdIntCorrVxVy_TS{t}(z,1);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
                MinLogI=min(MinLogI,min(MeanStdIntCorrVxVy_TS{t}(z,1)));
                MaxLogI=max(MaxLogI,max(MeanStdIntCorrVxVy_TS{t}(z,1)));
            end
        end
        % MinAbs=-MaxAbsFix; MaxAbs=MaxAbsFix;
        set(gca,'yscale','log');
        MaxAbs=min(abs(MinAbs),MaxAbs); MinAbs=-MaxAbs;
        %axis([MinAbs MaxAbs MinOrd MaxOrd]);
        colormap(Colors);
        Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
        caxis([NpartTotal(TimeStepsFig(1)) NpartTotal(TimeStepsFig(nt))]*1e3);
        MyFigStyleLaTeXSave(LabelsAbs{d-1},LabelsOrd{d-1},0,['$' num2str(MinLogI,3) '<\left<\log I\right><' num2str(MaxLogI,3) '$'],1,'$\tau$ (ms)',[1 FactorAR*AR 1],FontSize);
        
        ax2=axes('Position',[.165+(i-1)*0.85/col .745-(d-2)*0.9/row .1 .1]);
        LW2=1; MS2=6; FactorAR2=1; hold on;
        for j=1:nt
            t=TimeStepsFig(j);
            Abs=NpartTotal(t)*1e3; Ord=MeanStdIntCorrVxVy_TS{t}(z,1);
            [~,I]=min(abs(Scale_tau(:,1)-NpartTotal(t)));
            plot(Abs,Ord,'o','LineWidth',LW2,'MarkerSize',MS2,'MarkerFaceColor',Colors(I,:),'MarkerEdgeColor','black');
            %             [~,I]=min(abs(Scale_LogI(:,1)-Ord));
            %             plot(Abs,Ord,'o','LineWidth',LW2,'MarkerSize',MS2,'MarkerFaceColor',ColorsLogI(I,:),'MarkerEdgeColor','black');
            if j==1
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
            end
        end
        axis([MinAbs MaxAbs MinOrd MaxOrd]); hold off;
        Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
        MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR2*AR 1],FontSize);
        text(Ax(1)+(Ax(2)-Ax(1))*0.5,Ax(3),'$\tau$ (ms)',...
            'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom');
        text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.5,'$\left<\log I\right>$',...
            'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','top','rotation',90);
    end
end

Index_Z_str=num2str(Index_Z); Index_Z_str(Index_Z_str==' ')=[];
TimeStepsFig_str=num2str(TimeStepsFig); TimeStepsFig_str(TimeStepsFig_str==' ')=[];
if SaveFig==1
    saveas(Fig,[FolderResults filesep 'PDF_IndZ' Index_Z_str '_IndTS' TimeStepsFig_str '_' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'PDF_IndZ' Index_Z_str '_IndTS' TimeStepsFig_str '_' MovieNumbers], '-pdf');
    close(Fig);
end

%% Dependance of standard deviation
Nmin=1000; NpFit=8; L_min=NpFit; CoefsSTDFit=zeros(Nclass,7,3);
STD_Neff_Maps_ZTS=zeros(Nclass,Ntau,3); Zmap=zeros(Nclass,1);
LinearEq=@(c,x)c(1)*x;
for d=1:3
    for z=1:Nclass
        
        % Log Log fit
        Abs=zeros(Ntau,1); Ord=zeros(Ntau,1); Zpos=zeros(Ntau,1);
        for t=1:Ntau
            if MeanStdIntCorrVxVy_TS{t}(z,9)>=Nmin
                Abs(t)=MeanStdIntCorrVxVy_TS{t}(z,10);
                Ord(t)=MeanStdIntCorrVxVy_TS{t}(z,5+d);
                Zpos(t)=MeanStdIntCorrVxVy_TS{t}(z,1);
            else
                Abs(t)=NaN; Ord(t)=NaN; Zpos(t)=NaN;
            end
        end
        Zmap(z)=nanmean(Zpos); STD_Neff_Maps_ZTS(z,:,d)=Ord';
        Abs=Abs(isnan(Ord)==0); Ord=Ord(isnan(Ord)==0);
        
        if isempty(Abs)==0 && length(Abs)>=L_min
            pf=min(length(Abs),NpFit);
            p=polyfit(log(Abs(1:pf)),log(Ord(1:pf)),1);
            CoefsSTDFit(z,1:4,d)=[z Zmap(z) p(1) exp(p(2))];
            
            % Linear fit
            Abs=sqrt(NpartTotal(:,1));
            Abs=Abs(isnan(Ord)==0);
            
            p=polyfit(Abs(1:pf),Ord(1:pf),1);
            c0=p(1); cinf=0; csup=5*p(1);
            c=lsqcurvefit(LinearEq,c0,Abs(1:pf),Ord(1:pf),cinf,csup);
            CoefsSTDFit(z,5:7,d)=[p c];
        else
            CoefsSTDFit(z,:)=NaN;
        end
        
    end
end

%% Figures for standard deviation versus time step
[MinC,MaxC]=Decil(PosVelocity_TimeStepTot{1}(:,3),1-Treshold,Treshold);
Nv=NpartTotal(1,2); Scale_LogI=linspace(MinC,MaxC,round(Nv))';
ColorsLogI=[linspace(0,74/255,round(Nv))' linspace(0,1,round(Nv))' zeros(round(Nv),1)];

ModeFit=2; SaveFig=1;
LabelsOrd=cell(3,1); LabelsOrd{1}='$\sigma_{\parallel}$ ($\mu$m)';
LabelsOrd{2}='$\sigma_{\perp}$ ($\mu$m)'; LabelsOrd{3}='$\sigma_{\delta}$';
Fig=figure('name','Fit Std','NumberTitle','off');
set(gcf,'Position',scrsz); row=2; col=3; FactorAR=1;
LW=1.5; MS=8; LW2=1; MS2=5; FontSize=10;
for d=1:3
    zI=find(isnan(CoefsSTDFit(:,:,d))==0,1);
    
    subplot(row,col,d); hold on
    for z=1:Nclass
        
        if isnan(CoefsSTDFit(z,1,d))==0
            Abs=zeros(Ntau,1); Ord=zeros(Ntau,1);
            for t=1:Ntau
                if MeanStdIntCorrVxVy_TS{t}(z,9)>=Nmin
                    Abs(t)=MeanStdIntCorrVxVy_TS{t}(z,10);
                    Ord(t)=MeanStdIntCorrVxVy_TS{t}(z,5+d);
                else
                    Abs(t)=NaN; Ord(t)=NaN; Zpos(t)=NaN;
                end
            end
            Abs=Abs(isnan(Ord)==0); Ord=Ord(isnan(Ord)==0);
            
            if z==zI
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
            end
            
            AbsFit=linspace(0,max(Abs),50)';
            p=CoefsSTDFit(z,3:4,d);
            OrdFit=p(2)*AbsFit.^p(1);
            
            [~,I]=min(abs(Scale_LogI(:,1)-Zmap(z)));
            plot(Abs,Ord,'o',AbsFit,OrdFit,'-','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
        end
        
    end
    set(gca,'xscale','log','yscale','log');
    %axis([MinAbs MaxAbs MinOrd MaxOrd]);
    caxis([Mindl Maxdl]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    MyFigStyleLaTeXSave('$\tau$ (s)',LabelsOrd{d},0,0,1,'$\log I$',[1 FactorAR*AR 1],FontSize);
    text(Ax(1)+(Ax(2)-Ax(1))*0.1,Ax(3)+(Ax(4)-Ax(3))*0.05,'$\sigma=C_1\tau^k$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','middle');
    
    ax2=axes('Position',[.195+(d-1)*0.84/col .62 .13 .13]);
    Abs=CoefsSTDFit(:,2,d); Ord=CoefsSTDFit(:,3,d); Mean=nanmean(Ord);
    plot(Abs,Ord,'o','LineWidth',LW2,'MarkerSize',MS2,'MarkerFaceColor','r','MarkerEdgeColor','black');
    MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    MinOrd=0; MaxOrd=max(2*Mean,MaxOrd);
    %axis([MinAbs MaxAbs MinOrd MaxOrd]); caxis([Mindl Maxdl]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    line([Ax(1) Ax(2)],Mean.*[1 1],'LineWidth',LW,'color','black');
    MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
    text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3),'$\log I$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
    text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.95,'$k$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
    
    ax3=axes('Position',[.11+(d-1)*0.84/col .78 .13 .13]);
    Abs=CoefsSTDFit(:,2,d); Ord=CoefsSTDFit(:,4,d); Mean=nanmean(Ord);
    plot(Abs,Ord,'s','LineWidth',LW2,'MarkerSize',MS2,'MarkerFaceColor','b','MarkerEdgeColor','black');
    MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    MinOrd=0; MaxOrd=max(2*Mean,MaxOrd);
    %axis([MinAbs MaxAbs MinOrd MaxOrd]); caxis([Mindl Maxdl]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    line([Ax(1) Ax(2)],Mean.*[1 1],'LineWidth',LW,'color','black');
    MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
    text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3),'$\log I$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
    text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.95,'$C_1$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
    
    subplot(row,col,d+col); hold on
    for z=1:Nclass
        
        if isnan(CoefsSTDFit(z,1,d))==0
            Abs=zeros(Ntau,1); Ord=zeros(Ntau,1);
            for t=1:Ntau
                if MeanStdIntCorrVxVy_TS{t}(z,9)>=Nmin
                    Abs(t)=MeanStdIntCorrVxVy_TS{t}(z,10);
                    Ord(t)=MeanStdIntCorrVxVy_TS{t}(z,5+d);
                else
                    Abs(t)=NaN; Ord(t)=NaN; Zpos(t)=NaN;
                end
            end
            Abs=sqrt(Abs);
            Abs=Abs(isnan(Ord)==0); Ord=Ord(isnan(Ord)==0);
            
            if z==zI
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
            end
            
            AbsFit=linspace(0,max(Abs),50)';
            if ModeFit==1
                c=CoefsSTDFit(z,7,d); OrdFit=LinearEq(c,AbsFit);
            elseif ModeFit==2
                p=CoefsSTDFit(z,5:6,d); OrdFit=polyval(p,AbsFit);
            end
            
            [~,I]=min(abs(Scale_LogI(:,1)-Zmap(z)));
            plot(Abs,Ord,'o',AbsFit,OrdFit,'-','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
        end
        
    end
    MinAbs=0; MinOrd=0;
    %axis([MinAbs MaxAbs MinOrd MaxOrd]);
    caxis([Mindl Maxdl]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
    MyFigStyleLaTeXSave('$\sqrt{\tau}$ (s$^{-1/2}$)',LabelsOrd{d},0,0,1,'$\log I$',[1 FactorAR*AR 1],FontSize);
    text(Ax(1)+(Ax(2)-Ax(1))*0.3,Ax(3)+(Ax(4)-Ax(3))*0.05,'$\sigma=C_2\sqrt{\tau}$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','middle');
    
    ax2=axes('Position',[.19+(d-1)*0.84/col .15 .13 .13]);
    Abs=CoefsSTDFit(:,2,d); Ord=CoefsSTDFit(:,4,d); Mean1=nanmean(Ord); hold on;
    plot(Abs,Ord,'o','LineWidth',LW2,'MarkerSize',MS2,'MarkerFaceColor','b','MarkerEdgeColor','black');
    Abs=CoefsSTDFit(:,2,d); Ord=CoefsSTDFit(:,5,d); Mean2=nanmean(Ord);
    plot(Abs,Ord,'^','LineWidth',LW2,'MarkerSize',MS2,'MarkerFaceColor',[0 0.5 0],'MarkerEdgeColor','black');
    MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
    MinOrd=0; MaxOrd=max(2*Mean2,MaxOrd);
    %axis([MinAbs MaxAbs MinOrd MaxOrd]); caxis([Mindl Maxdl]);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
    line([Ax(1) Ax(2)],Mean1.*[1 1],'LineWidth',LW,'color','b');
    line([Ax(1) Ax(2)],Mean2.*[1 1],'LineWidth',LW,'color',[0 0.5 0]);
    MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
    leg=legend('$C_1$','$C_2$','Location','North');
    set(leg,'Interpreter','Latex','box','off','FontSize',FontSize,'Orientation','horizontal','Position',[.22+(d-1)*0.84/col,.24,0.07,0.1]);
    text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3),'$\log I$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
    text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.95,'$C$',...
        'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
    
end
colormap(ColorsLogI);

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'STD_raw_TS_' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'STD_raw_TS_' MovieNumbers], '-pdf');
    close(Fig);
end


%% Figures for standard deviation versus z-position
Colors=[linspace(1,0,Ntau)' zeros(Ntau,1) linspace(0,1,Ntau)'];

SaveFig=1;
Fig=figure('name','Velocity profiles','NumberTitle','off');
set(gcf,'Position',scrsz); row=2; col=3; LW=1; MS=6; FontSize=12;
FactorAR=3/3;

LabelsOrd=cell(4,1); LabelsOrd{1}='$\sigma_{\parallel}/\sqrt{\tau}$ ($\mu$m.s$^{-1/2}$)';
LabelsOrd{2}='$\sigma_{\perp}/\sqrt{\tau}$ ($\mu$m.s$^{-1/2}$)'; LabelsOrd{3}='$\sigma_{\delta}$';
LabelsOrd{4}='$\sigma_{\perp}\tau^{-1/2}\sigma_{\delta}^{-1}$ ($\mu$m.s$^{-1/2}$)';
LabelsOrd{5}=['$v_{\parallel}$ (' UnitsVelocity ')']; LabelsOrd{6}='$N_{part}/N_{tot}$';
VparaSlopes=zeros(Ntau,1); VparaSlopes(:)=NaN;
for d=1:6
    
    subplot(row,col,d); hold on;
    for t=1:Ntau
        
        I=find(MeanStdIntCorrVxVy_TS{t}(:,9)>=Nmin);
        if isempty(I)==0
            Abs=MeanStdIntCorrVxVy_TS{t}(I,1);
            if d==1 || d==2
                Ord=MeanStdIntCorrVxVy_TS{t}(I,5+d)/sqrt(NpartTotal(t,1));
            elseif d==3
                Ord=MeanStdIntCorrVxVy_TS{t}(I,5+d);
            elseif d==4
                Ord=(MeanStdIntCorrVxVy_TS{t}(I,7)/sqrt(NpartTotal(t,1)))./MeanStdIntCorrVxVy_TS{t}(I,8);
            elseif d==5
                Ord=MeanStdIntCorrVxVy_TS{t}(I,2)/NpartTotal(t,1);
                p=polyfit(Abs,Ord,1); VparaSlopes(t)=p(1);
            elseif d==6
                Ord=MeanStdIntCorrVxVy_TS{t}(I,9)/NpartTotal(t,2);
                set(gca,'yscale','log');
            end
            plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
            
            if t==1
                MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
            else
                MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
                MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
            end
        end
        
    end
    MinOrd=0;
    %axis([MinAbs MaxAbs MinOrd MaxOrd]);
    caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
    Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off; colormap(Colors);
    MyFigStyleLaTeXSave('$\log I$',LabelsOrd{d},0,0,1,'$\tau$ (ms)',[1 FactorAR*AR 1],FontSize);
    %     text(Ax(1)+(Ax(2)-Ax(1))*0.2,Ax(3)+(Ax(4)-Ax(3))*0.2,['Fit for $' num2str(LogIinf) '<\log I<' num2str(LogIsup) '$'],...
    %         'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','middle');
    
end

ax2=axes('Position',[.4 .15 .15 .15]); LW2=1.5; MS2=6;
Abs=NpartTotal(1:Ntau,1)*1e3; Ord=VparaSlopes(:);
semilogx(Abs,Ord,'o','LineWidth',LW2,'MarkerSize',MS2,'color','black');
MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%axis([MinAbs MaxAbs MinOrd MaxOrd]);
Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
text(Ax(1)+(Ax(2)-Ax(1))*0.01,Ax(3)+(Ax(4)-Ax(3))*0.7,'$p=\frac{\partial v_{\parallel}}{\partial \log I}$',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','middle');
text(Ax(1)+(Ax(2)-Ax(1))*0.98,Ax(3),'$\tau$ (ms)',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.98,'$p$',...
    'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);

if SaveFig==1
    saveas(Fig,[FolderResults filesep 'STD_raw_Zpos_' MovieNumbers '.fig']);
    export_fig([FolderResults filesep 'STD_raw_Zpos_' MovieNumbers], '-pdf');
    close(Fig);
end

% %% Standard deviation for PDFs versus z and time steps
% display=0;
% Std_Exp_TS_Eff=zeros(Nclass,Ntau,1);
% Std_TS_GaussLin=zeros(Nclass,Ntau,3); Std_TS_GaussLog=zeros(Nclass,Ntau,3);
% Std_TS_ExpNLin=zeros(Nclass,Ntau,3); Exp_TS_ExpNLin=zeros(Nclass,Ntau,3);
% Std_TS_ExpNLog=zeros(Nclass,Ntau,3); Exp_TS_ExpNLog=zeros(Nclass,Ntau,3);
% Std_TS_ExpNfixLin=zeros(Nclass,Ntau,3); Exp_TS_ExpNfixLin=zeros(Nclass,Ntau,3);
% Std_TS_ExpNfixLog=zeros(Nclass,Ntau,3); Exp_TS_ExpNfixLog=zeros(Nclass,Ntau,3);
% for z=1:Nclass
%     for t=1:Ntau
%         for d=2:4
%             
%             xdata=(PDF_Pos_TS{z,t}{d}(:,1)-MeanStdIntCorrVxVy_TS{t}(z,d));
%             ydata=PDF_Pos_TS{z,t}{d}(:,3);
%             nloc=length(xdata); Std_Exp_TS_Eff(z,t)=nloc;
%             
%             if nloc>=10
%                 sigma_gauss=NormGaussianFit(xdata,ydata,display,2);
%                 [sigma,exponent]=PDFexponentN(xdata,ydata,display,3);
%                 
%                 Std_TS_GaussLin(z,t,d-1)=sigma_gauss(1);
%                 Std_TS_GaussLog(z,t,d-1)=sigma_gauss(2);
%                 
%                 Std_TS_ExpNLin(z,t,d-1)=sigma(1);
%                 Exp_TS_ExpNLin(z,t,d-1)=exponent(1);
%                 Std_TS_ExpNLog(z,t,d-1)=sigma(4);
%                 Exp_TS_ExpNLog(z,t,d-1)=exponent(4);
%                 
%                 Std_TS_ExpNfixLin(z,t,d-1)=sigma(2);
%                 Exp_TS_ExpNfixLin(z,t,d-1)=exponent(2);
%                 Std_TS_ExpNfixLog(z,t,d-1)=sigma(5);
%                 Exp_TS_ExpNfixLog(z,t,d-1)=exponent(5);
%             else
%                 Std_TS_GaussLin(z,t,d-1)=NaN;
%                 Std_TS_GaussLog(z,t,d-1)=NaN;
%                 
%                 Std_TS_ExpNLin(z,t,d-1)=NaN;
%                 Exp_TS_ExpNLin(z,t,d-1)=NaN;
%                 Std_TS_ExpNLog(z,t,d-1)=NaN;
%                 Exp_TS_ExpNLog(z,t,d-1)=NaN;
%                 
%                 Std_TS_ExpNfixLin(z,t,d-1)=NaN;
%                 Exp_TS_ExpNfixLin(z,t,d-1)=NaN;
%                 Std_TS_ExpNfixLog(z,t,d-1)=NaN;
%                 Exp_TS_ExpNfixLog(z,t,d-1)=NaN;
%             end
%         end
%     end
%     disp(['Position ' num2str(z) '/' num2str(Nclass) ' done']);
% end

% %% Figures for the fit control
% % Choose data
% z=10; t=1; d=3;
% xdata=(PDF_Pos_TS{z,t}{d}(:,1)-MeanStdIntCorrVxVy_TS{t}(z,d));
% ydata=PDF_Pos_TS{z,t}{d}(:,3); sigma0=MeanStdIntCorrVxVy_TS{t}(z,4+d);
% sigma_gauss=Std_TS_GaussLin(z,t,d-1);
% sigma=Std_TS_ExpNLin(z,t,d-1); exponent=Exp_TS_ExpNLin(z,t,d-1);
% sigma_gauss_log=Std_TS_GaussLog(z,t,d-1);
% sigma_log=Std_TS_ExpNLog(z,t,d-1); exponent_log=Exp_TS_ExpNLog(z,t,d-1);
% 
% % Fit creation
% GaussianEq=@(c,x)exp(-(x.^2/(2*c(1)^2)))/sqrt(2*pi*c(1)^2);
% PDFexpN_Eq=@(c,x)sqrt(gamma(3/c(2)+1)/(12*gamma(1/c(2)+1)^3*c(1)^2))*exp(-((x/c(1)).^2*gamma(3/c(2)+1)/(3*gamma(1/c(2)+1))).^(c(2)/2));
% PDF_GaussianFit=GaussianEq(sigma_gauss,xdata);
% PDF_ExpNFit=PDFexpN_Eq([sigma exponent],xdata);
% PDF_GaussianFit_log=GaussianEq(sigma_gauss_log,xdata);
% PDF_ExpNFit_log=PDFexpN_Eq([sigma_log exponent_log],xdata);
% 
% % Figure
% FontSize=12; FactorAR=4/3; LegendLoc='South'; Color1='r'; Color2='magenta';
% figure('name','Velocity profiles','NumberTitle','off');
% scrsz=get(0,'ScreenSize'); set(gcf,'Position',scrsz);
% 
% subplot(1,2,1); hold on;
% plot(xdata,ydata,'o','LineWidth',2,'MarkerSize',10,'color','b');
% plot(xdata,PDF_GaussianFit,'-','LineWidth',2,'MarkerSize',10,'color',Color1);
% plot(xdata,PDF_ExpNFit,'-','LineWidth',2,'MarkerSize',10,'color',Color2);
% plot(xdata,PDF_GaussianFit_log,'--','LineWidth',2,'MarkerSize',10,'color',Color1);
% plot(xdata,PDF_ExpNFit_log,'--','LineWidth',2,'MarkerSize',10,'color',Color2);
% axis([min(xdata) max(xdata) min(ydata) max(ydata)*1.3]);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.97,'$f\left(x\right)=\frac{2}{\sqrt{2\pi\sigma}}\exp\left(-\frac{x^2}{2\sigma^2}\right)$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','color',Color1);
% text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,'$f\left(x\right)=A\exp\left(-\left|\frac{x}{a}\right|^{n}\right)$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top','color',Color2);
% text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.86,'$A=\frac{1}{\sigma}\sqrt{\frac{\Gamma\left(\frac{3}{n}+1\right)}{12\Gamma^{3}\left(\frac{1}{n}+1\right)}}$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top','color',Color2);
% text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.74,'$a=\sigma\sqrt{\frac{3\Gamma\left(\frac{1}{n}+1\right)}{\Gamma\left(\frac{3}{n}+1\right)}}$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top','color',Color2);
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.88,'$\int\limits _{-\infty}^{+\infty}f\left(x\right)dx=1$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.75,'$\sigma^{2}=\int\limits _{-\infty}^{+\infty}x^{2}f\left(x\right)dx$','FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% leg=legend(['$\sigma_0=' num2str(sigma0,4) '$'],['$\sigma_g=' num2str(sigma_gauss,4) '$; $n=2$'],['$\sigma_n=' num2str(sigma,4) '$; $n=' num2str(exponent,3) '$'],'Location',LegendLoc);
% set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
% MyFigStyleLaTeXSave('$x$','$f\left(x\right)$',0,'Fit from $\left(x, y\right)$',0,0,[1 FactorAR*AR 1],FontSize);
% 
% subplot(1,2,2); hold on; set(gca,'yscale','log');
% plot(xdata,ydata,'o','LineWidth',2,'MarkerSize',10,'color','b');
% plot(xdata,PDF_GaussianFit_log,'--','LineWidth',2,'MarkerSize',10,'color',Color1);
% plot(xdata,PDF_ExpNFit_log,'--','LineWidth',2,'MarkerSize',10,'color',Color2);
% plot(xdata,PDF_GaussianFit,'-','LineWidth',2,'MarkerSize',10,'color',Color1);
% plot(xdata,PDF_ExpNFit,'-','LineWidth',2,'MarkerSize',10,'color',Color2);
% axis([min(xdata) max(xdata) min(ydata) max(ydata)*1.3]);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
% leg=legend(['$\sigma_0=' num2str(sigma0,4) '$'],['$\sigma_g=' num2str(sigma_gauss_log,4) '$; $n=2$'],['$\sigma_n=' num2str(sigma_log,4) '$; $n=' num2str(exponent_log,3) '$'],'Location',LegendLoc);
% set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
% MyFigStyleLaTeXSave('$x$','$f\left(x\right)$',0,'Fit from $\left(x, \log y\right)$',0,0,[1 FactorAR*AR 1],FontSize);

% %% Figures for PDF shape properties
% Colors=[linspace(1,0,Ntau)' zeros(Ntau,1) linspace(0,1,Ntau)'];
% 
% SaveFig=1;
% Fig=figure('name','Velocity profiles','NumberTitle','off');
% set(gcf,'Position',scrsz); row=2; col=3; LW=1; MS=6; FontSize=10;
% FactorAR=3/3;
% 
% LabelsOrd=cell(3,1); LabelsOrd{1}='$n_{\parallel}$';
% LabelsOrd{2}='$n_{\perp}$'; LabelsOrd{3}='$n_{\delta}$';
% Title1='Fit from $\left(x, y\right)$'; Title2='Fit from $\left(x, \log y\right)$';
% LabelsAbs2=cell(3,1); LabelsAbs2{1}='$\sigma_{0,\parallel}$ ($\mu$m)';
% LabelsAbs2{2}='$\sigma_{0,\perp}$ ($\mu$m)'; LabelsAbs2{3}='$\sigma_{0,\delta}$';
% LabelsOrd2=cell(3,1); LabelsOrd2{1}='$\sigma_{n,\parallel}$ ($\mu$m)';
% LabelsOrd2{2}='$\sigma_{n,\perp}$ ($\mu$m)'; LabelsOrd2{3}='$\sigma_{n,\delta}$';
% 
% colormap(Colors);
% for d=1:3
%     
%     subplot(row,col,d); hold on;
%     for t=1:Ntau
%         
%         I=find(MeanStdIntCorrVxVy_TS{t}(:,9)>=Nmin);
%         if isempty(I)==0
%             Abs=MeanStdIntCorrVxVy_TS{t}(I,1);
%             Ord=Exp_TS_ExpNLin(I,t,d);
%             plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
%             
%             if t==1
%                 MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
%             else
%                 MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%                 MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
%             end
%         end
%         
%     end
%     MinOrd=0;
%     %axis([MinAbs MaxAbs MinOrd MaxOrd]);
%     caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
%     Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
%     MyFigStyleLaTeXSave('$\log I$',LabelsOrd{d},0,Title1,1,'$\tau$ (ms)',[1 FactorAR*AR 1],FontSize);
%     line([MinAbs MaxAbs],nanmean(nanmean(Exp_TS_ExpNLin(:,:,d),2))*[1 1],'LineStyle','--','LineWidth',1.5,'color','black');
%     
%     ax2=axes('Position',[.12+(d-1)*0.84/col .62 .13 .13]); LW2=1; MS2=5; hold on;
%     for t=1:Ntau
%         
%         I=find(MeanStdIntCorrVxVy_TS{t}(:,9)>=Nmin);
%         if isempty(I)==0
%             Abs=MeanStdIntCorrVxVy_TS{t}(I,5+d);
%             Ord=Std_TS_ExpNLin(I,t,d);
%             plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
%             
%             if t==1
%                 MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
%             else
%                 MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%                 MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
%             end
%         end
%         
%     end
%     MinAbs=min(MinAbs,MinOrd); MinOrd=MinAbs; MaxAbs=max(MaxAbs,MaxOrd); MaxOrd=MaxAbs;
%     axis([MinAbs MaxAbs MinOrd MaxOrd]);
%     caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
%     Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
%     line([MinAbs MaxAbs],[MinOrd MaxOrd],'LineStyle','--','LineWidth',1.5,'color','black');
%     MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
%     text(Ax(1)+(Ax(2)-Ax(1))*0.98,Ax(3),LabelsAbs2{d},...
%         'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
%     text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.98,LabelsOrd2{d},...
%         'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
%     
%     subplot(row,col,d+col); hold on;
%     for t=1:Ntau
%         
%         I=find(MeanStdIntCorrVxVy_TS{t}(:,9)>=Nmin);
%         if isempty(I)==0
%             Abs=MeanStdIntCorrVxVy_TS{t}(I,1);
%             Ord=Exp_TS_ExpNLog(I,t,d);
%             plot(Abs,Ord,'o-','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
%             
%             if t==1
%                 MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
%             else
%                 MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%                 MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
%             end
%         end
%         
%     end
%     MinOrd=0;
%     axis([MinAbs MaxAbs MinOrd MaxOrd]);
%     caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
%     Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
%     MyFigStyleLaTeXSave('$\log I$',LabelsOrd{d},0,Title2,1,'$\tau$ (ms)',[1 FactorAR*AR 1],FontSize);
%     line([MinAbs MaxAbs],nanmean(nanmean(Exp_TS_ExpNLog(:,:,d),2))*[1 1],'LineStyle','--','LineWidth',1.5,'color','black');
%     
%     ax2=axes('Position',[.12+(d-1)*0.84/col .145 .13 .13]); LW2=1; MS2=5; hold on;
%     for t=1:Ntau
%         
%         I=find(MeanStdIntCorrVxVy_TS{t}(:,9)>=Nmin);
%         if isempty(I)==0
%             Abs=MeanStdIntCorrVxVy_TS{t}(I,5+d);
%             Ord=Std_TS_ExpNLog(I,t,d);
%             plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',Colors(t,:));
%             
%             if t==1
%                 MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord(Ord>0)); MaxOrd=max(Ord);
%             else
%                 MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%                 MinOrd=min(MinOrd,min(Ord(Ord>0))); MaxOrd=max(MaxOrd,max(Ord));
%             end
%         end
%         
%     end
%     MinAbs=min(MinAbs,MinOrd); MinOrd=MinAbs; MaxAbs=max(MaxAbs,MaxOrd); MaxOrd=MaxAbs;
%     axis([MinAbs MaxAbs MinOrd MaxOrd]);
%     caxis([min(NpartTotal(1:Ntau,1)) max(NpartTotal(1:Ntau,1))]*1e3);
%     Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
%     line([MinAbs MaxAbs],[MinOrd MaxOrd],'LineStyle','--','LineWidth',1.5,'color','black');
%     MyFigStyleLaTeXSave(0,0,0,0,0,0,[1 FactorAR*AR 1],FontSize);
%     text(Ax(1)+(Ax(2)-Ax(1))*0.98,Ax(3),LabelsAbs2{d},...
%         'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
%     text(Ax(1),Ax(3)+(Ax(4)-Ax(3))*0.98,LabelsOrd2{d},...
%         'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top','rotation',90);
%     
% end
% 
% if SaveFig==1
%     saveas(Fig,[FolderResults filesep 'Exponents_TS_' MovieNumbers '.fig']);
%     export_fig([FolderResults filesep 'Exponents_TS_' MovieNumbers], '-pdf');
%     close(Fig);
% end

% %% Calculations for PDF shape curvatures
% FitDegree=4; Np=1/10; Display=0;
% MaxCurvatures=zeros(Nclass,Ntau,3);
% for z=1:Nclass
%     % for z=10
%     for t=1:Ntau
%         %     for t=1
%         for d=2:4
%             %         for d=3
%             
%             xdata=(PDF_Pos_TS{z,t}{d}(:,1)-MeanStdIntCorrVxVy_TS{t}(z,d));
%             ydata=PDF_Pos_TS{z,t}{d}(:,3);
%             nloc=length(xdata); Std_Exp_TS_Eff(z,t)=nloc;
%             
%             if nloc>=10
%                 %                 Np=max(5,fix(nloc/5));
%                 MaxCurvatures(z,t,d-1)=PDF_Curvature(xdata,ydata,FitDegree,Np,Display);
%             else
%                 MaxCurvatures(z,t,d-1)=NaN;
%             end
%         end
%     end
%     disp(['Position ' num2str(z) '/' num2str(Nclass) ' done']);
% end

% %% Figures for PDF shape curvatures
% SaveFig=0;
% Fig=figure('name','Velocity curvatures','NumberTitle','off');
% set(gcf,'Position',scrsz); row=2; col=3; FontSize=12;
% FactorAR=3/3;
% 
% % LabelsBar=cell(3,1); LabelsBar{1}='$C_{\parallel}$';
% % LabelsBar{2}='$C_{\perp}$'; LabelsBar{3}='$C_{z}$';
% % for d=1:3
% %     subplot(row,col,d);
% %     AbsMin=min(NpartTotal(1:Ntau,1))*1e3;
% %     AbsMax=max(NpartTotal(1:Ntau,1))*1e3;
% %     OrdMin=min(MeanStdIntCorrVxVy_TS{1}(:,1));
% %     OrdMax=max(MeanStdIntCorrVxVy_TS{1}(:,1));
% %     imagesc(AbsMin:AbsMax,OrdMin:OrdMax,MaxCurvatures(:,:,d));
% %     MyFigStyleLaTeXSave('$\tau$ (ms)','$\log I$',0,0,1,LabelsBar{d},0,FontSize);
% % end
% % colormap jet;
% 
% [MinC,MaxC]=Decil(PosVelocity_TimeStepTot{1}(:,3),1-Treshold,Treshold);
% Nv=NpartTotal(1,2); Scale_LogI=linspace(MinC,MaxC,round(Nv))';
% ColorsLogI=[linspace(0,74/255,round(Nv))' linspace(0,1,round(Nv))' zeros(round(Nv),1)];
% 
% LabelsOrd=cell(3,1); LabelsOrd{1}='$1/C_{\parallel}$ ($\mu$m)';
% LabelsOrd{2}='$1/C_{\perp}$ ($\mu$m)'; LabelsOrd{3}='$1/C_{\delta}$';
% FactorAR=1; LW=1.5; MS=8; LW2=1; MS2=5; FontSize=10;
% for d=1:3
%     zI=find(isnan(CoefsSTDFit(:,:,d))==0,1);
%     
%     subplot(row,col,d); hold on
%     for z=1:Nclass
%         
%         if isnan(CoefsSTDFit(z,1,d))==0
%             Abs=zeros(Ntau,1); Ord=zeros(Ntau,1);
%             for t=1:Ntau
%                 if MeanStdIntCorrVxVy_TS{t}(z,9)>=Nmin
%                     Abs(t)=MeanStdIntCorrVxVy_TS{t}(z,10);
%                     Ord(t)=-1/MaxCurvatures(z,t,d);
%                 else
%                     Abs(t)=NaN; Ord(t)=NaN; Zpos(t)=NaN;
%                 end
%             end
%             Abs=Abs(isnan(Ord)==0); Ord=Ord(isnan(Ord)==0);
%             
%             if z==zI
%                 MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%             else
%                 MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%                 MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
%             end
%             
%             %             AbsFit=linspace(0,max(Abs),50)';
%             %             p=CoefsSTDFit(z,3:4,d);
%             %             OrdFit=p(2)*AbsFit.^p(1);
%             %
%             [~,I]=min(abs(Scale_LogI(:,1)-Zmap(z)));
%             %             plot(Abs,Ord,'o',AbsFit,OrdFit,'-','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
%             plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'color',ColorsLogI(I,:));
%         end
%         
%     end
%     set(gca,'xscale','log','yscale','log');
%     axis([MinAbs MaxAbs MinOrd MaxOrd]); caxis([Mindl Maxdl]);
%     Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
%     MyFigStyleLaTeXSave('$\tau$ (s)',LabelsOrd{d},0,0,1,'$\log I$',[1 FactorAR*AR 1],FontSize);
%     
% end
% colormap(ColorsLogI);
% 
% t=1;
% Markers=cell(3,1); Markers{1}='o'; Markers{2}='s'; Markers{3}='^';
% Colors=cell(3,1); Colors{1}='b'; Colors{2}='magenta'; Colors{3}='r';
% subplot(row,col,4); MS=8; LW=1.5; hold on;
% for d=1:3
%     Abs=MeanStdIntCorrVxVy_TS{t}(:,1);
%     Ord=-MaxCurvatures(:,t,d);
%     plot(Abs,Ord,Markers{d},'LineWidth',LW,'MarkerSize',MS,'color',Colors{d});
%     if d==1
%         MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%     else
%         MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%         MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
%     end
% end
% NinOrd=0; axis([MinAbs MaxAbs MinOrd MaxOrd]);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1)); hold off;
% MyFigStyleLaTeXSave('$\log I$','$-C$',0,['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'],0,0,[1 FactorAR*AR 1],FontSize);
% leg=legend('$C_{\parallel}$','$C_{\perp}$','$C_{z}$','Location','North','Orientation','horizontal');
% set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
% 
% subplot(row,col,5);
% Abs=MeanStdIntCorrVxVy_TS{t}(:,2).^2;
% Ord=(MaxCurvatures(:,t,2)./MaxCurvatures(:,t,1)-1)./MaxCurvatures(:,t,2).^2;
% plot(Abs,Ord,Markers{d},'LineWidth',LW,'MarkerSize',MS,'color','black');
% MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
% axis([MinAbs MaxAbs MinOrd MaxOrd]);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
% MyFigStyleLaTeXSave('$v_{\parallel}^2$','$\left(\frac{C_{perp}}{C_{\parallel}}-1\right)\times\frac{1}{C_{perp}^2}$',0,['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'],0,0,[1 FactorAR*AR 1],FontSize);

% %% Diffusion coeficient for first time step
% 
% t=1; ZmaxFit=10; ExpPe=2; SaveFig=1;
% LinearEq=@(c,x)c(1)*x;
% Lc=100e-3; % Characteristic Length = particle diameter
% Part=MeanStdIntCorrVxVy_TS{t}(:,9);
% U=MeanStdIntCorrVxVy_TS{t}(:,2)/NpartTotal(t,1);
% Dx=MeanStdIntCorrVxVy_TS{t}(:,6).^2/NpartTotal(t,1);
% Dy=MeanStdIntCorrVxVy_TS{t}(:,7).^2/NpartTotal(t,1);
% Peclet=Lc*U./Dy; Abs=Peclet.^ExpPe; Ord=(Dx./Dy-1);
% [~,Index]=sort(Part); Abs=Abs(Index); Ord=Ord(Index);
% Abs_loc=Abs(1:ZmaxFit); Ord_loc=Ord(1:ZmaxFit); I=isnan(Ord_loc)==0;
% p=polyfit(Abs_loc(I==1),Ord_loc(I==1),1); c0=p(1); cinf=0; csup=4*c0;
% CoefPe=lsqcurvefit(LinearEq,c0,Abs_loc(I==1),Ord_loc(I==1),cinf,csup);
% AbsFit=linspace(0,max(Abs),100)'; OrdFit=LinearEq(CoefPe,AbsFit);
% 
% Fig=figure('name','Velocity curvatures','NumberTitle','off');
% FactorAR=4/3; FontSize=14; LW=1; MS=12;
% set(Fig,'Position',scrsz); row=1; col=2;
% subplot(row,col,1);
% plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','r','MarkerEdgeColor','black');
% hold on; plot(AbsFit,OrdFit,'--','LineWidth',2*LW,'color','black'); hold off;
% MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
% if MinOrd>0; MinOrd=0; else MaxOrd=0; end; MinAbs=0;
% axis([MinAbs MaxAbs MinOrd MaxOrd]);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
% MyFigStyleLaTeXSave('$Pe^2$','$D_{\parallel}/D_{\perp}-1$',0,['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'],0,0,[1 FactorAR*AR 1],FontSize);
% text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,'$D_i=\sigma_i/\sqrt{\tau}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,'$Pe=UL_c/D_{\perp}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% text(Ax(1)+(Ax(2)-Ax(1))*0.6,Ax(3)+(Ax(4)-Ax(3))*0.05,['$L_c=' num2str(Lc*1e3) '$ nm'],...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% ARscreen=(scrsz(3)-scrsz(1))/(scrsz(4)-scrsz(2)); AngleDeg=atan(CoefPe/(FactorAR*AR))*180/pi;
% x1=Ax(1)+(Ax(2)-Ax(1))*0.5; y1=CoefPe(1)*x1;
% text(x1+(Ax(2)-Ax(1))*0.05*cos(AngleDeg*pi/180),y1-(Ax(4)-Ax(3))*(0.1+0.05*sin(AngleDeg*pi/180)),...
%     ['$\frac{D_{\parallel}}{D_{\perp}}-1=\frac{Pe^2}{' num2str(1/CoefPe,3) '}$'],'FontSize',FontSize,...
%     'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom','Rotation',AngleDeg);
% 
% Dx=1./(abs(MaxCurvatures(:,t,1))*NpartTotal(t,1));
% Dy=1./(abs(MaxCurvatures(:,t,2))*NpartTotal(t,1));
% Peclet=Lc*U./Dy; Abs=Peclet.^ExpPe; Ord=(Dx./Dy-1);
% [~,Index]=sort(Part); Abs=Abs(Index); Ord=Ord(Index);
% Abs_loc=Abs(1:ZmaxFit); Ord_loc=Ord(1:ZmaxFit); I=isnan(Ord_loc)==0;
% p=polyfit(Abs_loc(I==1),Ord_loc(I==1),1); c0=p(1); cinf=0; csup=4*c0;
% CoefPeCurv=lsqcurvefit(LinearEq,c0,Abs_loc(I==1),Ord_loc(I==1),cinf,csup);
% AbsFit=linspace(0,max(Abs),100)'; OrdFit=LinearEq(CoefPeCurv,AbsFit);
% 
% subplot(row,col,2);
% plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor','b','MarkerEdgeColor','black');
% hold on; plot(AbsFit,OrdFit,'--','LineWidth',2*LW,'color','black'); hold off;
% MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
% if MinOrd>0; MinOrd=0; else MaxOrd=0; end; MinAbs=0;
% axis([MinAbs MaxAbs MinOrd MaxOrd]);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
% MyFigStyleLaTeXSave('$Pe^2$','$D_{\parallel}/D_{\perp}-1$',0,['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'],0,0,[1 FactorAR*AR 1],FontSize);
% text(Ax(1)+(Ax(2)-Ax(1))*0.05,Ax(3)+(Ax(4)-Ax(3))*0.95,'$D_i=1/\sqrt{C_i\tau}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','left','VerticalAlignment','top');
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,'$Pe=UL_c/D_{\perp}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% text(Ax(1)+(Ax(2)-Ax(1))*0.6,Ax(3)+(Ax(4)-Ax(3))*0.05,['$L_c=' num2str(Lc*1e3) '$ nm'],...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% ARscreen=(scrsz(3)-scrsz(1))/(scrsz(4)-scrsz(2)); AngleDeg=atan(CoefPeCurv/(FactorAR*AR))*180/pi;
% x1=Ax(1)+(Ax(2)-Ax(1))*0.5; y1=CoefPeCurv(1)*x1;
% text(x1+(Ax(2)-Ax(1))*0.05*cos(AngleDeg*pi/180),y1-(Ax(4)-Ax(3))*(0.1+0.05*sin(AngleDeg*pi/180)),...
%     ['$\frac{D_{\parallel}}{D_{\perp}}-1=\frac{Pe^2}{' num2str(1/CoefPeCurv,3) '}$'],'FontSize',FontSize,...
%     'Interpreter','latex','HorizontalAlignment','center','VerticalAlignment','bottom','Rotation',AngleDeg);
% 
% if SaveFig==1
%     saveas(Fig,[FolderResults filesep 'DiffusionAnisotropy_' MovieNumbers '.fig']);
%     export_fig([FolderResults filesep 'DiffusionAnisotropy_' MovieNumbers], '-pdf');
%     close(Fig);
% end

% %% Diffusion anisotropy for different time steps
% TSmax=4; ZmaxFit=10; Mode=1; SaveFig=1;
% Colors=[linspace(1,0,TSmax)' zeros(TSmax,1) linspace(0,1,TSmax)'];
% if Mode==2
%     Legends=cell(TSmax,1); Markers=cell(TSmax,1);
%     Markers{1}='o'; Markers{2}='^'; Markers{3}='s'; Markers{4}='v';
% end
% 
% Fig=figure('name','Diffusion anisotropy','NumberTitle','off');
% FactorAR=4/3; FontSize=14; LW=1; MS=12;
% set(Fig,'Position',scrsz); row=1; col=2; LegendLoc='NorthWest';
% 
% subplot(row,col,1); hold on;
% for t=1:TSmax
%     
%     Part=MeanStdIntCorrVxVy_TS{t}(:,9);
%     U=MeanStdIntCorrVxVy_TS{t}(:,2)/NpartTotal(t,1);
%     Dx=MeanStdIntCorrVxVy_TS{t}(:,6).^2/NpartTotal(t,1);
%     Dy=MeanStdIntCorrVxVy_TS{t}(:,7).^2/NpartTotal(t,1);
%     Peclet=Lc*U./Dy; Abs=Peclet.^2; Ord=(Dx./Dy-1);
%     
%     if Mode==1
%         plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors(t,:),'MarkerEdgeColor','black');
%     elseif Mode==2
%         plot(Abs,Ord,Markers{t},'LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors(t,:),'MarkerEdgeColor','black');
%         Legends{t}=['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'];
%     end
%     
%     if t==1
%         [~,Index]=sort(Part); Abs=Abs(Index); Ord=Ord(Index);
%         Abs_loc=Abs(1:ZmaxFit); Ord_loc=Ord(1:ZmaxFit); I=isnan(Ord_loc)==0;
%         p=polyfit(Abs_loc(I==1),Ord_loc(I==1),1); c0=p(1); cinf=0; csup=4*c0;
%         CoefPe=lsqcurvefit(LinearEq,c0,Abs_loc(I==1),Ord_loc(I==1),cinf,csup);
%         AbsFit=linspace(0,max(Abs),100)'; OrdFit=LinearEq(CoefPe,AbsFit);
%         OrdFitCurv=LinearEq(CoefPeCurv,AbsFit);
%         MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%     else
%         MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%         MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
%     end
%     
% end
% plot(AbsFit,OrdFit,'--','LineWidth',2*LW,'color','black');
% plot(AbsFit,OrdFitCurv,'--','LineWidth',2*LW,'color','b');
% if MinOrd>0; MinOrd=0; else MaxOrd=0; end; MinAbs=0;
% axis([MinAbs MaxAbs MinOrd MaxOrd]); hold off;
% caxis([min(NpartTotal(1:TSmax,1)) max(NpartTotal(1:TSmax,1))]*1e3);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
% if Mode==1
%     colormap(Colors);
%     MyFigStyleLaTeXSave('$Pe^2$','$D_{\parallel}/D_{\perp}-1$',0,0,1,'$\tau$ ms',[1 FactorAR*AR 1],FontSize);
% elseif Mode==2
%     MyFigStyleLaTeXSave('$Pe^2$','$D_{\parallel}/D_{\perp}-1$',0,0,0,0,[1 FactorAR*AR 1],FontSize);
%     leg=legend(Legends{:},'Location',LegendLoc);
%     set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
% end
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.20,'$D_i=\sigma_i/\sqrt{\tau}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,'$Pe=UL_c/D_{\perp}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% text(Ax(1)+(Ax(2)-Ax(1))*0.6,Ax(3)+(Ax(4)-Ax(3))*0.05,['$L_c=' num2str(Lc*1e3) '$ nm'],...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% x1=Ax(1)+(Ax(2)-Ax(1))*0.90; y1=CoefPe*x1; AngleDeg=atan(CoefPe/(FactorAR*AR))*180/pi;
% text(x1+(Ax(2)-Ax(1))*0.05*cos(AngleDeg*pi/180),y1-(Ax(4)-Ax(3))*(0.1+0.05*sin(AngleDeg*pi/180)),...
%     ['$\frac{D_{\parallel}}{D_{\perp}}-1=\frac{Pe^2}{' num2str(1/CoefPe,3) '}$'],'FontSize',FontSize,...
%     'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom','Rotation',AngleDeg);
% x1=Ax(1)+(Ax(2)-Ax(1))*0.70; y1=CoefPeCurv*x1; AngleDeg=atan(CoefPeCurv/(FactorAR*AR))*180/pi;
% text(x1+(Ax(2)-Ax(1))*0.05*cos(AngleDeg*pi/180),y1-(Ax(4)-Ax(3))*(-0.15+0.05*sin(AngleDeg*pi/180)),...
%     ['$\frac{D_{\parallel}}{D_{\perp}}-1=\frac{Pe^2}{' num2str(1/CoefPeCurv,3) '}$'],'FontSize',FontSize,...
%     'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom','Rotation',AngleDeg,'color','b');
% 
% subplot(row,col,2); hold on;
% for t=1:TSmax
%     
%     Part=MeanStdIntCorrVxVy_TS{t}(:,9);
%     U=MeanStdIntCorrVxVy_TS{t}(:,2)/NpartTotal(t,1);
%     Dx=1./(abs(MaxCurvatures(:,t,1))*NpartTotal(t,1));
%     Dy=1./(abs(MaxCurvatures(:,t,2))*NpartTotal(t,1));
%     Peclet=Lc*U./Dy; Abs=Peclet.^2; Ord=(Dx./Dy-1);
%     
%     if Mode==1
%         plot(Abs,Ord,'o','LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors(t,:),'MarkerEdgeColor','black');
%     elseif Mode==2
%         plot(Abs,Ord,Markers{t},'LineWidth',LW,'MarkerSize',MS,'MarkerFaceColor',Colors(t,:),'MarkerEdgeColor','black');
%         Legends{t}=['$\tau=' num2str(NpartTotal(t)*1e3) '$ ms'];
%     end
%     
%     if t==1
%         [~,Index]=sort(Part); Abs=Abs(Index); Ord=Ord(Index);
%         Abs_loc=Abs(1:ZmaxFit); Ord_loc=Ord(1:ZmaxFit); I=isnan(Ord_loc)==0;
%         p=polyfit(Abs_loc(I==1),Ord_loc(I==1),1); c0=p(1); cinf=0; csup=4*c0;
%         CoefPeCurv=lsqcurvefit(LinearEq,c0,Abs_loc(I==1),Ord_loc(I==1),cinf,csup);
%         AbsFit=linspace(0,max(Abs),100)'; OrdFit=LinearEq(CoefPeCurv,AbsFit);
%         MinAbs=min(Abs); MaxAbs=max(Abs); MinOrd=min(Ord); MaxOrd=max(Ord);
%     else
%         MinAbs=min(MinAbs,min(Abs)); MaxAbs=max(MaxAbs,max(Abs));
%         MinOrd=min(MinOrd,min(Ord)); MaxOrd=max(MaxOrd,max(Ord));
%     end
%     
% end
% plot(AbsFit,OrdFit,'--','LineWidth',2*LW,'color','black');
% if MinOrd>0; MinOrd=0; else MaxOrd=0; end; MinAbs=0;
% axis([MinAbs MaxAbs MinOrd MaxOrd]); hold off;
% caxis([min(NpartTotal(1:TSmax,1)) max(NpartTotal(1:TSmax,1))]*1e3);
% Ax=axis; AR=(Ax(4)-Ax(3))/(Ax(2)-Ax(1));
% if Mode==1
%     colormap(Colors);
%     MyFigStyleLaTeXSave('$Pe^2$','$D_{\parallel}/D_{\perp}-1$',0,0,1,'$\tau$ ms',[1 FactorAR*AR 1],FontSize);
% elseif Mode==2
%     MyFigStyleLaTeXSave('$Pe^2$','$D_{\parallel}/D_{\perp}-1$',0,0,0,0,[1 FactorAR*AR 1],FontSize);
%     leg=legend(Legends{:},'Location',LegendLoc);
%     set(leg,'Interpreter','Latex','box','off','FontSize',FontSize);
% end
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.20,'$D_i=1/\sqrt{C_i\tau}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','top');
% text(Ax(1)+(Ax(2)-Ax(1))*0.95,Ax(3)+(Ax(4)-Ax(3))*0.05,'$Pe=UL_c/D_{\perp}$',...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% text(Ax(1)+(Ax(2)-Ax(1))*0.6,Ax(3)+(Ax(4)-Ax(3))*0.05,['$L_c=' num2str(Lc*1e3) '$ nm'],...
%     'FontSize',FontSize,'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom');
% x1=Ax(1)+(Ax(2)-Ax(1))*0.90; y1=CoefPeCurv(1)*x1; AngleDeg=atan(CoefPeCurv/(FactorAR*AR))*180/pi;
% text(x1+(Ax(2)-Ax(1))*0.05*cos(AngleDeg*pi/180),y1-(Ax(4)-Ax(3))*(0.1+0.05*sin(AngleDeg*pi/180)),...
%     ['$\frac{D_{\parallel}}{D_{\perp}}-1=\frac{Pe^2}{' num2str(1/CoefPeCurv,3) '}$'],'FontSize',FontSize,...
%     'Interpreter','latex','HorizontalAlignment','right','VerticalAlignment','bottom','Rotation',AngleDeg);
% 
% if SaveFig==1
%     saveas(Fig,[FolderResults filesep 'DiffusionAnisotropyTmax' num2str(TSmax) 'im_' MovieNumbers '.fig']);
%     export_fig([FolderResults filesep 'DiffusionAnisotropyTmax' num2str(TSmax) 'im_' MovieNumbers], '-pdf');
%     close(Fig);
% end


%% Save Results
I=strfind(MainFolder,filesep);
FileName=[MainFolder(I(end)+1:end) '_' MovieNumbers];
if exist(FolderResults,'dir')==0
    mkdir(FolderResults);
end
% save(fullfile(FolderResults,[FileName '_AllTS.mat']),'MainFolder',...
%     'ListSubFolders','Infos','FolderResults','MovieNumbers','Nfiles',...
%     'FinalSubFolderList','FinalInfos','FileName','UnitsSpace','UnitsTime',...
%     'Filtering','MinPixel','MaxPixel','GaussBlur','ThresholdPart','Method',...
%     'TolArea','ROI','AirInf','AirSup','ErrorPos','ImaxInf','ColXpos','ColYpos',...
%     'max_linking_distance_Xn','max_linking_distance_Xp','max_linking_distance_Yn',...
%     'max_linking_distance_Yp','max_gap_closing','Dmin','Tmin','Tmax','Lmin',...
%     'Method_Intensity','UnitsVelocity','VelocityIntensityAll',...
%     'Scales','FrameRates','NpartVelocities',...
%     'MeanStdIntVxVyAll_Repro','MaxNpartTot','NpartAll','NpartTotal',...
%     'PosVelocity_TimeStepTot','NpartMin','Nclass','PDF_Pos_TS',...
%     'MeanStdIntCorrVxVy_TS','CoefsFitsVpara_TS','Nmin','NpFit','Lmin',...
%     'CoefsSTDFit','STD_Neff_Maps_ZTS','Zmap','Std_Exp_TS_Eff',...
%     'Std_TS_GaussLin','Std_TS_GaussLog','Std_TS_ExpNLin','Exp_TS_ExpNLin',...
%     'Std_TS_ExpNLog','Exp_TS_ExpNLog','Std_TS_ExpNfixLin','Exp_TS_ExpNfixLin',...
%     'Std_TS_ExpNfixLog','Exp_TS_ExpNfixLog','FitDegree','Np','MaxCurvatures',...
%     'InfosFile');

save(fullfile(FolderResults,[FileName '_AllTS.mat']),'MainFolder',...
    'ListSubFolders','Infos','FolderResults','MovieNumbers','Nfiles',...
    'FinalSubFolderList','FinalInfos','FileName','UnitsSpace','UnitsTime',...
    'Filtering','MinPixel','MaxPixel','GaussBlur','ThresholdPart','Method',...
    'TolArea','ROI','AirInf','AirSup','ErrorPos','ImaxInf','ColXpos','ColYpos',...
    'max_linking_distance_Xn','max_linking_distance_Xp','max_linking_distance_Yn',...
    'max_linking_distance_Yp','max_gap_closing','Dmin','Tmin','Tmax','Lmin',...
    'Method_Intensity','UnitsVelocity','VelocityIntensityAll',...
    'Scales','FrameRates','NpartVelocities',...
    'MeanStdIntVxVyAll_Repro','MaxNpartTot','NpartAll','NpartTotal',...
    'PosVelocity_TimeStepTot','NpartMin','Nclass','PDF_Pos_TS',...
    'MeanStdIntCorrVxVy_TS','CoefsFitsVpara_TS','Nmin','NpFit','Lmin',...
    'CoefsSTDFit','STD_Neff_Maps_ZTS','Zmap',...
    'InfosFile');


disp('Variables Saved');



end

