function StackFrames=ZstackFrames(Folder,Format,dt,NpartRow,NpartCol,Display)

%% Example
% Folder='D:\Work\2018-2019-IPGG\Projects\Richards\p1_400_0_p2_35_00_125fps_repeat_cropped_oritentedJ2_Green';
% Format='tif'; dt=1; Display=1; NpartRow=1; NpartCol=4;

%% Import frames and get stack frames
ListeFrames=dir([Folder filesep '*' Format]); Nfiles=numel(ListeFrames);
Frame=imread([Folder filesep ListeFrames(1).name]);
[nr,nc]=size(Frame); StackFrames=zeros(nr,nc,6);
Index=fix(linspace(1,Nfiles,Nfiles/dt))'; NframesReal=length(Index);

IndexRow=fix(linspace(1,nr,NpartRow+1)); IndexRow_i=IndexRow(1:end-1);
IndexRow_f=IndexRow(2:end); IndexRow_f=IndexRow_f-1; IndexRow_f(end)=nr;
IndexCol=fix(linspace(1,nc,NpartCol+1)); IndexCol_i=IndexCol(1:end-1);
IndexCol_f=IndexCol(2:end); IndexCol_f=IndexCol_f-1; IndexCol_f(end)=nc;

for r=1:NpartRow
    ri=IndexRow_i(r); rf=IndexRow_f(r); nrloc=rf-ri+1;
    
    for c=1:NpartCol
        ci=IndexCol_i(c); cf=IndexCol_f(c); ncloc=cf-ci+1;
        
        StackPart=zeros(nrloc,ncloc,NframesReal);
        for j=1:NframesReal    
            t=Index(j);
            Frame=imread([Folder filesep ListeFrames(t).name]);
            StackPart(:,:,j)=Frame(ri:rf,ci:cf);
        end

        StackFrames(ri:rf,ci:cf,1)=mean(StackPart,3);
        StackFrames(ri:rf,ci:cf,2)=median(StackPart,3);
        StackFrames(ri:rf,ci:cf,3)=std(StackPart,1,3);
        StackFrames(ri:rf,ci:cf,4)=min(StackPart,[],3);
        StackFrames(ri:rf,ci:cf,5)=max(StackPart,[],3);
        StackFrames(ri:rf,ci:cf,6)=mode(StackPart,3);
        
        disp(['Row part ' num2str(r) '/' num2str(NpartRow) ' and colum part ' num2str(c) '/' num2str(NpartCol) ' done']);
    end
    
end

if Display==1
    
    Threshold=0.999;
    scrsz=get(0,'ScreenSize');
    Titles=cell(6,1); Titles{1}='Mean';  Titles{2}='Median'; 
    Titles{3}='Standard deviation';  Titles{4}='Minimum';
    Titles{5}='Maximum'; Titles{6}='Mode';
    
    figure('name','Minimum and maximum intensity for a temporal stack','NumberTitle','off')
    set(gcf,'Position',scrsz); row=3; col=2;
    for i=1:6
        [MinI,MaxI]=Decil(StackFrames(:,:,i),1-Threshold,Threshold);        
        subplot(row,col,i); imagesc(StackFrames(:,:,i),[MinI MaxI]);
        colormap gray; daspect([1 1 1]); c=colorbar;
        set(c,'TickLabelInterpreter', 'latex');
        title(Titles{i},'Interpreter','latex');
        set(gca,'TickLabelInterpreter', 'latex');
        set(gcf,'Color',[1 1 1]);
        set(gca, 'box', 'on');
    end
    
end



end