function [MinFrames,MaxFrames,MeanFrames,MeanMedInt]=ZstackFramesFast_for_GUI(FolderOrFile,FormatOrChannel,dt,Display,SaveStacks)

%% Example
% FolderOrFile='D:\Work\2017-2018-LOMA\ManipsTurbulence\2018-02-16-SoapFilmsColor\01-2wiresPump12u05teeth4mmf2000fpsExp300Obt2u8.cine';
% FolderOrFile='D:\Work\2017-2018-LOMA\ManipsSpiro\2017-10-05-Spiro\5-0u05MC_12microL_15fps.avi';
% FolderOrFile='F:\AlexVilquin\2019-02-19-Channel8cm8_SideCam\09-Motor20000_Plaser50mW_WaterRhod0_f10fps';
% FormatOrChannel=2; dt=1; Display=1;

%% Obtain Min, Max and Mean from frame sequence
[~,~,Ext]=fileparts(FolderOrFile);
if isempty(Ext)==1
    ListeFrames=dir([FolderOrFile filesep '*' FormatOrChannel]); Nfiles=numel(ListeFrames);
    if strcmpi(FormatOrChannel,'.tif')==1
        MinFrames=imread([FolderOrFile filesep ListeFrames(1).name]);
    elseif strcmpi(FormatOrChannel,'.mat')==1
        MinFrames=load([FolderOrFile filesep ListeFrames(1).name]);
    end
elseif isempty(Ext)==0
    if strcmpi(Ext,'.cine')==1
        VideoFile=CineReader(FolderOrFile);
        MinFrames=VideoFile.read(1); Nfiles=VideoFile.NumberOfFrames;
    elseif strcmpi(Ext,'.avi')==1 || strcmpi(Ext,'.mp4')==1
        VideoFile=VideoReader(FolderOrFile);
        MinFrames=readFrame(VideoFile);
    end
    MinFrames=MinFrames(:,:,FormatOrChannel);
end
MaxFrames=MinFrames; MeanFrames=MinFrames;

z=reshape(double(MinFrames),[numel(MinFrames) 1 1]);
Index=fix(linspace(1,Nfiles,Nfiles/dt))'; Nreal=length(Index);
MeanMedInt=zeros(Nreal,3); MeanMedInt(1,:)=[1 mean(z) median(z)];

hh = waitbar(0,'Stacking in progress...');
if ischar(FormatOrChannel)==1 || strcmpi(Ext,'.cine')==1
    for i=2:Nreal

        clc;
        t=Index(i);
        disp([num2str(t) '/' num2str(Nfiles)]);
        
        if isempty(Ext)==1
            if strcmpi(FormatOrChannel,'.tif')==1
                im=imread([FolderOrFile filesep ListeFrames(t).name]);
            elseif strcmpi(FormatOrChannel,'.mat')==1
                im=load([FolderOrFile filesep ListeFrames(t).name]);
            end
        elseif strcmpi(Ext,'.cine')==1
            im=VideoFile.read(t); im=im(:,:,FormatOrChannel);
        end

        MinFrames=min(cat(3,MinFrames,im),[],3);
        MaxFrames=max(cat(3,MaxFrames,im),[],3);
        Coef1=(i-1)/i; Coef2=1/i;
        MeanFrames=Coef1*MeanFrames+Coef2*im;

        z=reshape(double(im),[numel(im) 1 1]);
        MeanMedInt(i,:)=[t mean(z) median(z)];
        
        waitbar(i/Nreal,hh);
    end
elseif strcmpi(Ext,'.avi')==1 || strcmpi(Ext,'.mp4')==1
    while hasFrame(VideoFile)
        disp([num2str(VideoFile.CurrentTime) '/' num2str(VideoFile.Duration)]);
        im=readFrame(VideoFile); im=im(:,:,FormatOrChannel);
        
        MinFrames=min(cat(3,MinFrames,im),[],3);
        MaxFrames=max(cat(3,MaxFrames,im),[],3);
        Coef1=(i-1)/i; Coef2=1/i;
        MeanFrames=Coef1*MeanFrames+Coef2*im;

        z=reshape(double(im),[numel(im) 1 1]);
        MeanMedInt(i,:)=[t mean(z) median(z)];
    end
end

%% Save frame stacks
if strcmpi(SaveStacks,'none')==0
    if isempty(Ext)==1
        FolderStacks=[FolderOrFile filesep 'Stacks'];
    elseif isempty(Ext)==0
        I=strfind(FolderOrFile,filesep);
        FolderStacks=[FolderOrFile(1:I(end)) 'Stacks'];
    end
    if exist('FolderStacks','dir')==0
        mkdir(FolderStacks);
    end
    if strcmpi(SaveStacks,'.tif')==1
        imwrite(MinFrames,[FolderStacks filesep 'MinFrames' SaveStacks]);
        imwrite(MaxFrames,[FolderStacks filesep 'MaxFrames' SaveStacks]);
        imwrite(MeanFrames,[FolderStacks filesep 'MeanFrames' SaveStacks]);
    elseif strcmpi(SaveStacks,'.mat')==1
        save([FolderStacks filesep 'MinFrames' SaveStacks],'MinFrames');
        save([FolderStacks filesep 'MaxFrames' SaveStacks],'MaxFrames');
        save([FolderStacks filesep 'MeanFrames' SaveStacks],'MeanFrames');
    end
end


%% Figure
if Display==1
    
    Threshold=0.999;
    [MinImin,MaxImin]=Decil(double(MinFrames),1-Threshold,Threshold);
    [MinImax,MaxImax]=Decil(double(MaxFrames),1-Threshold,Threshold);
    [MinImean,MaxImean]=Decil(double(MeanFrames),1-Threshold,Threshold);
    scrsz=get(0,'ScreenSize'); % Problems if you change your screen
    figure('name','Minimum and maximum intensity for a temporal stack','NumberTitle','off')
    set(gcf,'Position',scrsz); row=2; col=2; FontSize=12;
    subplot(row,col,1); imagesc(MinFrames,[MinImin MaxImin]);
    MyFigStyleLaTeXSave('$x$','$y$',0,'Minimum',2,'I',[1 1 1],FontSize);
    subplot(row,col,2); imagesc(MaxFrames,[MinImax MaxImax]);
    MyFigStyleLaTeXSave('$x$','$y$',0,'Maximum',2,'I',[1 1 1],FontSize);
    subplot(row,col,3); imagesc(MeanFrames,[MinImean MaxImean]);
    MyFigStyleLaTeXSave('$x$','$y$',0,'Mean',2,'I',[1 1 1],FontSize);
    subplot(row,col,4);
    [hAx,Color1,Color2]=MyFigStyleLaTeX_2Y(MeanMedInt(:,1),MeanMedInt(:,2),MeanMedInt(:,3),'$t$','$\left<I\right>$','Median',...
        'Mean and Median',4/3,FontSize,[1 Nfiles],0,0,...
        '-',1,'o',6,'s',6);
    colormap gray;
    
end
close(hh);
end