function [Mijd,Npart,Nframes] = traj_exp(freq,serie)


FolderMatlab='E:\PSE21\Functions'; % path to the functions
addpath(genpath(FolderMatlab));

path_data = strcat('E:\PSE21\Videos_freqs',filesep,num2str(serie),filesep,num2str(freq)); % path to data
format = '.tiff'; % picture format

minpixel = 1; % lower end of band pass filter
maxpixel = 20; % upper e,d of the band pass filter
thres = 15; % threshold for image processing


%% detection for 1 frame
A = dir([path_data filesep '*' format]);N=length(A);

k = floor(rand(1)*(N-1))+1;
M = imread([A(k).folder filesep A(k).name]);
Mfilt = bpass(M,minpixel,maxpixel);
Mthres = (Mfilt>thres);
Mfilt = Mfilt.*Mthres;

Properties={'Centroid','WeightedCentroid',...
    'Area','Perimeter','MinorAxisLength','MajorAxisLength',...
    'Eccentricity','MeanIntensity','MaxIntensity','Orientation'};

s=regionprops(Mthres,Mfilt,Properties);
s = s([s.Area]>0);

Positions = reshape([s.WeightedCentroid],[2, length(s)])';
% figure(1),clf,subplot(221),imagesc(M),axis image,colorbar,colormap gray
% title('Raw Image'),GG_Figstyle
% subplot(222),imagesc(Mthres),axis image,colorbar,colormap gray
% title('Binarized Image'),GG_Figstyle
% subplot(223),imagesc(Mfilt),axis image,colorbar,colormap gray
% title('Processed Image'),GG_Figstyle
% set(gcf,'Position',[330 134 1094 855])
% subplot(224),imagesc(M),axis image,colorbar,colormap gray
% title('Detection'),GG_Figstyle
% hold on, plot(Positions(:,1),Positions(:,2),'ro','MarkerSize',8)
% 
% set(gcf,'Position',[330 134 1094 855])
%% detection for N frames
clear('Positions','Particle_list')
h = waitbar(0,'Detection in progress');
index=0;
tic
for k=1:N
    M = imread([A(k).folder filesep A(k).name]);
    Mfilt = bpass(M,minpixel,maxpixel);
    Mthres = (Mfilt>thres);
    Mfilt = Mfilt.*Mthres;   
    s=regionprops(Mthres,Mfilt,Properties);
    s = s([s.Area]>0);   
    Positions{k} = reshape([s.WeightedCentroid],[2, length(s)])';
    for p = 1:length(s)
        Particle_list(index + p).X = Positions{k}(p,1);
        Particle_list(index + p).Y = Positions{k}(p,2);
        Particle_list(index + p).frame = k;
    end
    index = index+length(s);
    waitbar(k/N)
end
close(h)
t=toc;
disp(['Particle detected for ' num2str(N) ' frames in ' num2str(t) ' seconds'])


%% trajectories

method='Hungarian';
debug = true;
max_gap_closing = 0;

max_linking_distance_Xn = -30;
max_linking_distance_Xp = 30;
max_linking_distance_Yn = -30;
max_linking_distance_Yp = 30;

% Tracking calculations
[Tracks Adjacency_Tracks] = simpletracker_distXnpYnp(Positions,...
    'Method',method,...
    'MaxLinkingDistanceXn',max_linking_distance_Xn,...
    'MaxLinkingDistanceXp',max_linking_distance_Xp,...
    'MaxLinkingDistanceYn',max_linking_distance_Yn,...
    'MaxLinkingDistanceYp',max_linking_distance_Yp,...
    'MaxGapClosing',max_gap_closing,...
    'Debug',debug);

%% movie
n=length(Adjacency_Tracks);
frames_particles=zeros(N,n);
for p=1:n
    traj1{p} = Particle_list(Adjacency_Tracks{p});
    frames_particles([traj1{p}.frame],p)=[traj1{p}.frame];
end

Mijd = zeros(N,n,4); % N frames , n trajectoires

for i=1:n
    
    XX = extractfield(traj1{1,i},'X');
    YY = extractfield(traj1{1,i},'Y');
    NX = length(XX);
    NY = length(YY);
    
    if NX>30 
    
    Mijd(1:NX,i,1) = XX;
    Mijd(1:NY,i,2) = YY;
    Mijd(1:NX-1,i,3) = diff(XX);
    Mijd(1:NY-1,i,4) = diff(YY);
    
    end
end

Npart = n;
Nframes = N;

end

